#
# spec file for package kernel-firmware-prestera
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _firmwaredir /lib/firmware
%endif
%define __ksyms_path ^%{_firmwaredir}
%define git_version aaae2fb60f75b07d9c249ebe668524f7ddf51243

Name:           kernel-firmware-prestera
Version:        20250206
Release:        1.1
Summary:        Kernel firmware files for Marvell Prestera ASIC driver
License:        SUSE-Firmware AND GPL-2.0-or-later
Group:          System/Kernel
URL:            https://git.kernel.org/cgit/linux/kernel/git/firmware/linux-firmware.git/
Source0:        %{name}-%{version}.tar.xz
# URL:          https://github.com/openSUSE/kernel-firmware-tools/
Source1:        kernel-firmware-tools-20250211.tar.xz
Source2:        %{name}-rpmlintrc
Source3:        git_id
BuildRequires:  suse-module-tools
Requires(post): %{_bindir}/mkdir
Requires(post): %{_bindir}/touch
Requires(postun):%{_bindir}/mkdir
Requires(postun):%{_bindir}/touch
Requires(post): dracut >= 049
Conflicts:      kernel < 5.3
Conflicts:      kernel-firmware-uncompressed
BuildArch:      noarch
%if 0%{?suse_version} >= 1550
# make sure we have post-usrmerge filesystem package on TW
Conflicts:      filesystem < 84
%endif

%description
This package contains kernel firmware files for Marvell Prestera ASIC driver.


%prep
%autosetup -a1 -p1
# strip down WHENCE for the topic
scripts/strip-topic-whence.sh prestera < WHENCE > WHENCE.new
mv WHENCE.new WHENCE

%build
# nothing to do

%install
./copy-firmware.sh -v --xz -j1 %{buildroot}%{_firmwaredir}
scripts/install-licenses.sh prestera %{buildroot}%{_licensedir}/%{name}
install -c -D -m 0644 WHENCE %{buildroot}%{_licensedir}/%{name}/WHENCE
install -c -D -m 0644 README.md %{buildroot}%{_docdir}/%{name}/README.md

%post
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%doc %{_docdir}/%{name}
%license %{_licensedir}/%{name}
%{_firmwaredir}

%changelog
* Tue Feb 11 2025 Takashi Iwai <tiwai@suse.com>
- Fix license description for kernel-firmware-tools package
- Clean up spec file
* Fri Feb  7 2025 Takashi Iwai <tiwai@suse.com>
- Update to version 20250206 (git commit aaae2fb60f75):
  just a version bump without content changes for making the smooth
  repo transition
* Thu Feb  6 2025 Takashi Iwai <tiwai@suse.com>
- Split to each indiviaul build for each topic (bsc#1236966):
  the uncompressed big kernel-firmware package is deprecated now
* Thu Feb  6 2025 tiwai@suse.com
- Update to version 20250205 (git commit 429bdd620eb1):
  * amdgpu: DMCUB update for DCN401
  * ath12k: WCN7850 hw2.0: update board-2.bin
  * ath12k: QCN9274 hw2.0: update to WLAN.WBE.1.4.1-00199-QCAHKSWPL_SILICONZ-1
  * ath12k: QCN9274 hw2.0: update board-2.bin
  * ath11k: WCN6750 hw1.0: update board-2.bin
  * ath11k: QCN9074 hw1.0: update to WLAN.HK.2.9.0.1-02146-QCAHKSWPL_SILICONZ-1
  * ath11k: QCA6698AQ hw2.1: add to WLAN.HSP.1.1-04479-QCAHSPSWPL_V1_V2_SILICONZ_IOE-1
  * ath11k: QCA6698AQ hw2.1: add board-2.bin
  * ath11k: QCA6390 hw2.0: update board-2.bin
  * ath11k: QCA2066 hw2.1: update to WLAN.HSP.1.1-03926.13-QCAHSPSWPL_V2_SILICONZ_CE-2.52297.6
  * ath11k: QCA2066 hw2.1: update board-2.bin
  * ath11k: IPQ8074 hw2.0: update to WLAN.HK.2.9.0.1-02146-QCAHKSWPL_SILICONZ-1
  * ath11k: IPQ6018 hw1.0: update to WLAN.HK.2.7.0.1-02409-QCAHKSWPL_SILICONZ-1
  * copy-firmware: Fix 'No such file or directory' error.
  * ath11k: add device-specific firmware for QCM6490 boards
  * qca: add more WCN3950 1.3 NVM files
  * qca: add firmware for WCN3950 chips
  * qca: move QCA6390 firmware to separate section
  * qca: restore licence information for WCN399x firmware
  * amdgpu: DMCUB updates for various ASICs
  * amdgpu: DMCUB updates forvarious AMDGPU ASICs
  * qca: Update Bluetooth WCN6750 1.1.0-00476 firmware to 1.1.3-00069
  * qcom:x1e80100: Support for Lenovo T14s G6 Qualcomm platform
  * qcom:x1e80100: Support for Lenovo T14s G6 Qualcomm platform
- Update aliases from 6.13
* Thu Jan 30 2025 tiwai@suse.com
- Update to version 20250129 (git commit 211fbc287a0b):
  * linux-firmware: Update FW files for MRVL SD8997 chips
  * i915: Update Xe2LPD DMC to v2.27
  * qca: Update Bluetooth WCN6856 firmware 2.1.0-00642 to 2.1.0-00650
  * rtl_bt: Update RTL8852B BT USB FW to 0x049B_5037
  * amdgpu: Update ISP FW for isp v4.1.1
  * trivial: contrib: wrap the process in try/except to catch server issues
  * trivial: contrib: use python-magic to detect encoding of emails
  * QCA: Add Bluetooth firmware for QCA6698
- Drop the versions in Requires in kernel-firmare-all meta package
- Fix a minor bug in the check script
* Thu Jan 23 2025 tiwai@suse.com
- Update to version 20250122 (git commit 0e16f416fa29):
  * amdgpu: revert DMCUB 3.1.4 firmware (bsc#1236196)
  * amlogic: update firmware for w265s2
* Tue Jan 21 2025 tiwai@suse.com
- Update to version 20250120 (git commit 634d0a0aa07b):
  * mediatek MT7925: update bluetooth firmware to 20250113153307
  * linux-firmware: update firmware for MT7925 WiFi device
  * amdgpu: update psp 13.0.10 firmware
  * amdgpu: update gc 11.0.3 firmware
  * amdgpu: update psp 13.0.8 firmware
  * amdgpu: update psp 13.0.5 firmware
  * amdgpu: update vcn 4.0.0 firmware
  * amdgpu: update psp 13.0.0 firmware
  * amdgpu: update gc 11.0.0 firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update smu 14.0.3 firmware
  * amdgpu: update psp 14.0.3 firmware
  * amdgpu: update gc 12.0.1 firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update smu 14.0.2 firmware
  * amdgpu: update psp 14.0.2 firmware
  * amdgpu: update gc 12.0.0 firmware
  * amdgpu: update gc 9.4.3 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update vcn 4.0.4 firmware
  * amdgpu: update psp 13.0.7 firmware
  * amdgpu: update gc 11.0.2 firmware
  * amdgpu: update yellow carp firmware
  * qcom: correct licence information for SA8775P binaries
  * qcom: update SLPI firmware for RB5 board
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * qcom: add DSP firmware for SA8775p platform
  * qcom: correct venus firmware versions
  * qcom: add missing version information
  * linux-firmware: Update firmware (v10) for mt7988 internal
  * iwlwifi: add Bz FW for core90-93 release
  * linux-firmware: wilc3000: add firmware for WILC3000 WiFi device
  * rtw89: 8852b: update fw to v0.29.29.8
  * rtw89: 8852c: update fw to v0.27.122.0
  * rtw89: 8922a: update fw to v0.35.54.0
  * rtw89: 8922a: update fw to v0.35.52.1 and stuffs
  * rtw89: 8852bt: update fw to v0.29.110.0
  * rtw89: 8852b: update fw to v0.29.29.7
- Fix license for qcom_q6v5_pas
- Update aliases from 6.13
* Mon Jan 13 2025 tiwai@suse.com
- Update to version 20250111 (git commit b3049665a5d0):
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * amdgpu: update sdma 6.0.3 firmware
  * amdgpu: update psp 13.0.10 firmware
  * amdgpu: update gc 11.0.3 firmware
  * amdgpu: update sdma 4.4.5 firmware
  * amdgpu: update psp 13.0.14 firmware
  * amdgpu: update gc 9.4.4 firmware
  * amdgpu: update psp 13.0.5 firmware
  * amdgpu: update vega20 firmware
  * amdgpu: update vega12 firmware
  * amdgpu: update vega10 firmware
  * amdgpu: update vcn 4.0.0 firmware
  * amdgpu: update psp 13.0.0 firmware
  * amdgpu: update gc 11.0.0 firmware
  * amdgpu: update picasso firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update psp 13.0.11 firmware
  * amdgpu: update gc 11.0.4 firmware
  * amdgpu: update vcn 4.0.2 firmware
  * amdgpu: update psp 13.0.4 firmware
  * amdgpu: update gc 11.0.1 firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update vcn 4.0.6 firmware
  * amdgpu: update psp 14.0.1 firmware
  * amdgpu: update vcn 4.0.5 firmware
  * amdgpu: update gc 11.5.0 firmware
  * amdgpu: update vcn 5.0.0 firmware
  * amdgpu: update smu 14.0.3 firmware
  * amdgpu: update psp 14.0.3 firmware
  * amdgpu: update gc 12.0.1 firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update arcturus firmware
  * amdgpu: update renoir firmware
  * amdgpu: update smu 14.0.2 firmware
  * amdgpu: update psp 14.0.2 firmware
  * amdgpu: update gc 12.0.0 firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update vcn 4.0.3 firmware
  * amdgpu: update sdma 4.4.2 firmware
  * amdgpu: update psp 13.0.6 firmware
  * amdgpu: update gc 9.4.3 firmware
  * amdgpu: update yellow carp firmware
  * amdgpu: update vcn 4.0.4 firmware
  * amdgpu: update psp 13.0.7 firmware
  * amdgpu: update gc 11.0.2 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update aldebaran firmware
  * cirrus: cs35l56: Correct some links to address the correct amp instance
  * linux-firmware: Update firmware file for Intel Bluetooth Magnetar core
  * linux-firmware: Update firmware file for Intel BlazarU core
  * linux-firmware: Update firmware file for Intel Bluetooth Solar core
  * cirrus: cs35l41: Add Firmware for Ayaneo system 1f660105
  * Fix has_gnu_parallel function
* Tue Jan  7 2025 tiwai@suse.com
- Update to version 20250106 (git commit e39831b1a9d7):
  * rtl_bt: Add separate config for RLT8723CS Bluetooth part
  * amdgpu: revert VCN 3.1.2 firmware
  * amdgpu: revert yellow carp VCN firmware
  * amdgpu: revert sienna cichlid VCN firmware
  * amdgpu: revert navy flounder VCN firmware
  * amdgpu: revert dimgrey cavefish VCN firmware
  * WHENCE: Link the Raspberry Pi CM5 and 500 to the 4B
  * copy-firmware.sh: Fix typo in error message.
  * Add support to install files/symlinks in parallel.
  * Makefile: Remove obsolete/broken reference.
  * check_whence.py: Use a more portable shebang.
  * rtl_bt: Update RTL8852B BT USB FW to 0x04BE_1F5E
* Wed Jan  1 2025 tiwai@suse.com
- Update to version 20241220 (git commit 9cf329b39cf1):
  * cnm: update chips&media wave521c firmware.
  * WHENCE: Add "Info:" tag to text that's clearly not part of the license
  * rtl_nic: add firmware rtl8125bp-2
  * qcom: venus-5.4: update firmware binary for sc7180 and qcs615
  * cirrus: cs35l56: Correct filenames of SSID 17aa3832
  * cirrus: cs35l56: Add and update firmware for various Cirrus CS35L54 and CS35L56 laptops
  * cirrus: cs35l56: Correct SSID order for 103c8d01 103c8d08 10431f43
* Wed Dec 11 2024 tiwai@suse.com
- Update to version 20241211 (git commit 163296523cd4):
  * rtl_nic: add firmware rtl8125d-2
  * linux-firmware: Update firmware file for Intel BlazarU core
  * QCA: Add Bluetooth nvm files for WCN785x
  * QCA: Update Bluetooth WCN785x firmware to 2.0.0-00515-2
* Sun Dec  8 2024 tiwai@suse.com
- Update to version 20241206 (git commit 209c18b0e7cd):
  * amdgpu: update dmcub 0.0.246.0 firmware
  * Add top level license file.
* Thu Dec  5 2024 tiwai@suse.com
- Update to version 20241203 (git commit f5aeeb47697c):
  * amdgpu: update raven firmware
  * amdgpu: update gc 11.0.3 firmware
  * amdgpu: update psp 13.0.14 firmware
  * amdgpu: update vcn 3.1.2 firmware
  * amdgpu: update vpe 6.1.3 firmware
  * amdgpu: update psp 14.0.4 firmware
  * amdgpu: update gc 11.5.2 firmware
  * amdgpu: update vcn 4.0.0 firmware
  * amdgpu: update gc 11.0.0 firmware
  * amdgpu: update picasso firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update gc 11.0.4 firmware
  * amdgpu: update green sardine firmware
  * amdgpu: update vcn 4.0.2 firmware
  * amdgpu: update gc 11.0.1 firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update vcn 4.0.6 firmware
  * amdgpu: update gc 11.5.1 firmware
  * amdgpu: update vcn 4.0.5 firmware
  * amdgpu: update psp 14.0.0 firmware
  * amdgpu: add vcn 5.0.0 firmware
  * amdgpu: add smu 14.0.3 firmware
  * amdgpu: add sdma 7.0.1 firmware
  * amdgpu: add psp 14.0.3 firmware
  * amdgpu: add gc 12.0.1 firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update renoir firmware
  * amdgpu: add smu 14.0.2 firmware
  * amdgpu: add sdma 7.0.0 firmware
  * amdgpu: add psp 14.0.2 firmware
  * amdgpu: add gc 12.0.0 firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update psp 13.0.6 firmware
  * amdgpu: update yellow carp firmware
  * amdgpu: update vcn 4.0.4 firmware
  * amdgpu: update gc 11.0.2 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update aldebaran firmware
  * upstream amdnpu firmware
- Add amdnpu entries
- Add missing license entry for amd_pmf
* Mon Dec  2 2024 tiwai@suse.com
- Update to version 20241128 (git commit ea71da6f0690):
  * i915: Update Xe2LPD DMC to v2.24
  * cirrus: cs35l56: Add firmware for Cirrus CS35L56 for various Dell laptops
  * iwlwifi: add Bz-gf FW for core89-91 release
  * amdgpu: update smu 13.0.10 firmware
  * amdgpu: update sdma 6.0.3 firmware
  * amdgpu: update psp 13.0.10 firmware
  * amdgpu: update gc 11.0.3 firmware
  * amdgpu: add smu 13.0.14 firmware
  * amdgpu: add sdma 4.4.5 firmware
  * amdgpu: add psp 13.0.14 firmware
  * amdgpu: add gc 9.4.4 firmware
  * amdgpu: update vcn 3.1.2 firmware
  * amdgpu: update psp 13.0.5 firmware
  * amdgpu: update psp 13.0.8 firmware
  * amdgpu: update vega20 firmware
  * amdgpu: update vega12 firmware
  * amdgpu: update psp 14.0.4 firmware
  * amdgpu: update gc 11.5.2 firmware
  * amdgpu: update vega10 firmware
  * amdgpu: update vcn 4.0.0 firmware
  * amdgpu: update smu 13.0.0 firmware
  * amdgpu: update psp 13.0.0 firmware
  * amdgpu: update gc 11.0.0 firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update psp 13.0.11 firmware
  * amdgpu: update gc 11.0.4 firmware
  * amdgpu: update vcn 4.0.2 firmware
  * amdgpu: update psp 13.0.4 firmware
  * amdgpu: update gc 11.0.1 firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update vpe 6.1.1 firmware
  * amdgpu: update vcn 4.0.6 firmware
  * amdgpu: update psp 14.0.1 firmware
  * amdgpu: update gc 11.5.1 firmware
  * amdgpu: update vcn 4.0.5 firmware
  * amdgpu: update psp 14.0.0 firmware
  * amdgpu: update gc 11.5.0 firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update arcturus firmware
  * amdgpu: update renoir firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update sdma 4.4.2 firmware
  * amdgpu: update psp 13.0.6 firmware
  * amdgpu: update gc 9.4.3 firmware
  * amdgpu: update vcn 4.0.4 firmware
  * amdgpu: update psp 13.0.7 firmware
  * amdgpu: update gc 11.0.2 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update aldebaran firmware
- Update aliases from 6.13-rc1
* Mon Nov 25 2024 tiwai@suse.com
- Update to version 20241125 (git commit 508d770ee6f3):
  * ice: update ice DDP wireless_edge package to 1.3.20.0
  * ice: update ice DDP comms package to 1.3.52.0
  * ice: update ice DDP package to ice-1.3.41.0
  * amdgpu: update DMCUB to v9.0.10.0 for DCN314
  * amdgpu: update DMCUB to v9.0.10.0 for DCN351
* Fri Nov 22 2024 tiwai@suse.com
- Update to version 20241121 (git commit 48bb90cceb88):
  * linux-firmware: Update AMD cpu microcode
  * xe: Update GUC to v70.36.0 for BMG, LNL
  * i915: Update GUC to v70.36.0 for ADL-P, DG1, DG2, MTL, TGL
* Wed Nov 20 2024 tiwai@suse.com
- Update to version 20241119 (git commit 60cdfe1831e8):
  * iwlwifi: add Bz-gf FW for core91-69 release
- Update aliases from 6.12
* Wed Nov 13 2024 tiwai@suse.com
- Update to version 20241113 (git commit 1727aceef4d2):
  * qcom: venus-5.4: add venus firmware file for qcs615
  * qcom: update venus firmware file for SC7280
  * QCA: Add 22 bluetooth firmware nvm files for QCA2066
* Tue Nov 12 2024 tiwai@suse.com
- Update to version 20241112 (git commit c57a0a42468b):
  * mediatek MT7922: update bluetooth firmware to 20241106163512
  * mediatek MT7921: update bluetooth firmware to 20241106151414
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for MT7921 WiFi device
  * qcom: Add QDU100 firmware image files.
  * qcom: Update aic100 firmware files
  * dedup-firmware.sh: fix infinite loop for --verbose
  * rtl_bt: Update RTL8852BT/RTL8852BE-VT BT USB FW to 0x04D7_63F7
  * cnm: update chips&media wave521c firmware.
  * mediatek MT7920: update bluetooth firmware to 20241104091246
  * linux-firmware: update firmware for MT7920 WiFi device
  * copy-firmware.sh: Run check_whence.py only if in a git repo
  * cirrus: cs35l56: Add firmware for Cirrus CS35L56 for various Dell laptops
  * amdgpu: update DMCUB to v9.0.10.0 for DCN351
  * rtw89: 8852a: update fw to v0.13.36.2
  * rtw88: Add firmware v52.14.0 for RTL8812AU
  * i915: Update Xe2LPD DMC to v2.23
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7925)
  * linux-firmware: update firmware for MT7925 WiFi device
  * WHENCE: Add sof-tolg for mt8195
  * linux-firmware: Update firmware file for Intel BlazarI core
  * qcom: Add link for QCS6490 GPU firmware
  * qcom: update gpu firmwares for qcs615 chipset
  * cirrus: cs35l56: Update firmware for Cirrus Amps for some HP laptops
  * mediatek: Add sof-tolg for mt8195
- Drop obsoleted workaround patch: copy-file-skip-check.patch
* Thu Oct 31 2024 tiwai@suse.com
- Update to version 20241029 (git commit 048795eef350):
  * ath11k: move WCN6750 firmware to the device-specific subdir
  * xe: Update LNL GSC to v104.0.0.1263
  * i915: Update MTL/ARL GSC to v102.1.15.1926
* Mon Oct 28 2024 tiwai@suse.com
- Update to version 20241028 (git commit 987607d681cb):
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * i915: Add Xe3LPD DMC
  * cnm: update chips&media wave521c firmware.
  * linux-firmware: Add firmware for Cirrus CS35L41
  * linux-firmware: Update firmware file for Intel BlazarU core
  * Makefile: error out of 'install' if COPYOPTS is set
* Mon Oct 21 2024 tiwai@suse.com
- Update to version 20241018 (git commit 2f0464118f40):
  * check_whence.py: skip some validation if git ls-files fails
  * qcom: Add Audio firmware for X1E80100 CRD/QCPs
  * amdgpu: DMCUB updates forvarious AMDGPU ASICs
  * brcm: replace NVRAM for Jetson TX1
  * rtlwifi: Update firmware for RTL8192FU to v7.3
  * make: separate installation and de-duplication targets
  * check_whence.py: check the permissions
  * Remove execute bit from firmware files
  * configure: remove unused file
  * rtl_nic: add firmware rtl8125d-1
* Tue Oct 15 2024 tiwai@suse.com
- Update to version 20241014 (git commit 99f9c7ed1f4a):
  * iwlwifi: add gl/Bz FW for core91-69 release
  * iwlwifi: update ty/So/Ma firmwares for core91-69 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core91-69 release
  * cirrus: cs35l56: Add firmware for Cirrus CS35L56 for a Lenovo Laptop
  * cirrus: cs35l56: Add firmware for Cirrus CS35L56 for some ASUS laptops
  * cirrus: cs35l56: Add firmware for Cirrus Amps for some HP laptops
  * linux-firmware: update firmware for en8811h 2.5G ethernet phy
  * QCA: Add Bluetooth firmwares for WCN785x with UART transport
* Mon Oct 14 2024 tiwai@suse.com
- Update to version 20241011 (git commit 808cba847c70):
  * mtk_wed: add firmware for mt7988 Wireless Ethernet Dispatcher
  * ath12k: WCN7850 hw2.0: update board-2.bin (bsc#1230596)
  * ath12k: QCN9274 hw2.0: add to WLAN.WBE.1.3.1-00162-QCAHKSWPL_SILICONZ-1
  * ath12k: QCN9274 hw2.0: add board-2.bin
  * copy-firmware.sh: rename variables in symlink hanlding
  * copy-firmware.sh: remove no longer reachable test -L
  * copy-firmware.sh: remove no longer reachable test -f
  * copy-firmware.sh: call ./check_whence.py before parsing the file
  * copy-firmware.sh: warn if the destination folder is not empty
  * copy-firmware.sh: add err() helper
  * copy-firmware.sh: fix indentation
  * copy-firmware.sh: reset and consistently handle destdir
  * Revert "copy-firmware: Support additional compressor options"
  * copy-firmware.sh: flesh out and fix dedup-firmware.sh
  * Style update yaml files
  * editorconfig: add initial config file
  * check_whence.py: annotate replacement strings as raw
  * check_whence.py: LC_ALL=C sort -u the filelist
  * check_whence.py: ban link-to-a-link
  * check_whence.py: use consistent naming
  * Add a link from TAS2XXX1EB3.bin -> ti/tas2781/TAS2XXX1EB30.bin
  * tas2781: Upload dsp firmware for ASUS laptop 1EB30 & 1EB31
- Skip invocation of check_whence.py at copying:
  copy-file-skip-check.patch
- Refresh copy-file-ignore-README.patch
- Drop obsoleted --ignore-duplicates option to copy-firmware.sh
- Drop the ath12k workaround again
* Thu Oct 10 2024 tiwai@suse.com
- Update to version 20241010 (git commit d4e688aa74a0):
  * rtlwifi: Add firmware v39.0 for RTL8192DU
  * Revert "ath12k: WCN7850 hw2.0: update board-2.bin"
    (replaced with a newer firmware in this package instead)
- update aliases
* Tue Oct  8 2024 tiwai@suse.com
- Update to version 20241004 (git commit bbb77872a8a7):
  * amdgpu: DMCUB DCN35 update
  * brcm: Add BCM4354 NVRAM for Jetson TX1
  * brcm: Link FriendlyElec NanoPi M4 to AP6356S nvram
* Tue Oct  1 2024 tiwai@suse.com
- Update to version 20241001 (git commit 51e5af813eaf):
  * linux-firmware: add firmware for MediaTek Bluetooth chip (MT7920)
  * linux-firmware: add firmware for MT7920
  * amdgpu: update raven firmware
  * amdgpu: update SMU 13.0.10 firmware
  * amdgpu: update PSP 13.0.10 firmware
  * amdgpu: update GC 11.0.3 firmware
  * amdgpu: update VCN 3.1.2 firmware
  * amdgpu: update PSP 13.0.5 firmware
  * amdgpu: update PSP 13.0.8 firmware
  * amdgpu: update vega12 firmware
  * amdgpu: update PSP 14.0.4 firmware
  * amdgpu: update GC 11.5.2 firmware
  * amdgpu: update vega10 firmware
  * amdgpu: update VCN 4.0.0 firmware
  * amdgpu: update PSP 13.0.0 firmware
  * amdgpu: update GC 11.0.0 firmware
  * amdgpu: update picasso firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update green sardine firmware
  * amdgpu: update VCN 4.0.2 firmware
  * amdgpu: update PSP 13.0.4 firmware
  * amdgpu: update GC 11.0.1 firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update VCN 4.0.6 firmware
  * amdgpu: update PSP 14.0.1 firmware
  * amdgpu: update GC 11.5.1 firmware
  * amdgpu: update VCN 4.0.5 firmware
  * amdgpu: update PSP 14.0.0 firmware
  * amdgpu: update GC 11.5.0 firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update renoir firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update SMU 13.0.6 firmware
  * amdgpu: update SDMA 4.4.2 firmware
  * amdgpu: update PSP 13.0.6 firmware
  * amdgpu: update GC 9.4.3 firmware
  * amdgpu: update yellow carp firmware
  * amdgpu: update VCN 4.0.4 firmware
  * amdgpu: update PSP 13.0.7 firmware
  * amdgpu: update GC 11.0.2 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update aldebaran firmware
  * qcom: update gpu firmwares for qcm6490 chipset
  * mt76: mt7996: add firmware files for mt7992 chipset
  * mt76: mt7996: add firmware files for mt7996 chipset variants
  * qcom: add gpu firmwares for sa8775p chipset
  * rtw89: 8922a: add fw format-2 v0.35.42.1
- Pick up the fixed ath12k firmware from
  https://git.codelinaro.org/clo/ath-firmware/ath12k-firmware
  (bsc#1230596)
- Update aliases from 6.11.x and 6.12-rc1
* Mon Sep 16 2024 tiwai@suse.com
- Update to version 20240913 (git commit bcbdd1670bc3):
  * amdgpu: update DMCUB to v0.0.233.0 DCN351
  * copy-firmware: Handle links to uncompressed files
  * WHENCE: Fix battmgr.jsn entry type
- Drop obsoleted workaround patch:
  copy-firmware-fix-symlink-without-compress.patch
- Temporary revert for ath12k firmware (bsc#1230596)
* Fri Sep 13 2024 tiwai@suse.com
- Update to version 20240912 (git commit 47c72fee8fe3):
  * amdgpu: Add VPE 6.1.3 microcode
  * amdgpu: add SDMA 6.1.2 microcode
  * amdgpu: Add support for PSP 14.0.4
  * amdgpu: add GC 11.5.2 microcode
  * qcom: qcm6490: add ADSP and CDSP firmware
  * linux-firmware: Update firmware file for Intel Bluetooth Magnetor core
  * linux-firmware: Update firmware file for Intel BlazarU core
  * linux-firmware: Update firmware file for Intel Bluetooth Solar core
- Temporary fix for the missing symlink installations:
  copy-firmware-fix-symlink-without-compress.patch
* Wed Sep 11 2024 tiwai@suse.com
- Update to version 20240911 (git commit 59def907425d):
  * rtl_bt: Update RTL8852B BT USB FW to 0x0447_9301 (bsc#1229272)
* Tue Sep 10 2024 tiwai@suse.com
- Update to version 20240910 (git commit 2a7b69a3fa30):
  * realtek: rt1320: Add patch firmware of MCU
  * i915: Update MTL DMC v2.23
  * cirrus: cs35l56: Add firmware for Cirrus CS35L54 for some HP laptops
* Wed Sep  4 2024 tiwai@suse.com
- Update to version 20240903 (git commit 96af55bd3d0b):
  * amdgpu: Revert sienna cichlid dmcub firmware update (bsc#1230007)
  * iwlwifi: add Bz FW for core89-58 release
  * rtl_nic: add firmware rtl8126a-3
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
* Tue Sep  3 2024 tiwai@suse.com
- Update to version 20240830 (git commit d6c600d46981):
  * amdgpu: update DMCUB to v0.0.232.0 for DCN314 and DCN351
  * qcom: vpu: restore compatibility with kernels before 6.6
* Wed Aug 28 2024 tiwai@suse.com
- Update to version 20240826 (git commit bec4fd18cc57):
  (including ath11k f/w updates for bsc#1234027)
  * amdgpu: DMCUB updates forvarious AMDGPU ASICs
  * rtw89: 8922a: add fw format-1 v0.35.41.0
  * linux-firmware: update firmware for MT7925 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7925)
  * rtl_bt: Add firmware and config files for RTL8922A
  * rtl_bt: Add firmware file for the the RTL8723CS Bluetooth part
  * rtl_bt: de-dupe identical config.bin files
  * rename rtl8723bs_config-OBDA8723.bin -> rtl_bt/rtl8723bs_config.bin
  * linux-firmware: Update AMD SEV firmware
  * linux-firmware: update firmware for MT7996
  * Revert "i915: Update MTL DMC v2.22"
  * ath12k: WCN7850 hw2.0: update board-2.bin
  * ath11k: WCN6855 hw2.0: update to WLAN.HSP.1.1-03125-QCAHSPSWPL_V1_V2_SILICONZ_LITE-3.6510.41
  * ath11k: WCN6855 hw2.0: update board-2.bin
  * ath11k: QCA2066 hw2.1: add to WLAN.HSP.1.1-03926.13-QCAHSPSWPL_V2_SILICONZ_CE-2.52297.3
  * ath11k: QCA2066 hw2.1: add board-2.bin
  * ath11k: IPQ5018 hw1.0: update to WLAN.HK.2.6.0.1-01291-QCAHKSWPL_SILICONZ-1
  * qcom: vpu: add video firmware for sa8775p
  * amdgpu: DMCUB updates for various AMDGPU ASICs
* Tue Aug 13 2024 tiwai@suse.com
- Update to version 20240809 (git commit 36db650dae03):
  * qcom: update path for video firmware for vpu-1/2/3.0
  * QCA: Update Bluetooth WCN685x 2.1 firmware to 2.1.0-00642
  * rtw89: 8852c: add fw format-1 v0.27.97.0
  * rtw89: 8852bt: add firmware 0.29.91.0
  * amdgpu: Update ISP FW for isp v4.1.1
  * mediatek: Update mt8195 SOF firmware
  * amdgpu: DMCUB updates for DCN314
  * xe: First GuC release v70.29.2 for BMG
  * xe: Add GuC v70.29.2 for LNL
  * i915: Add GuC v70.29.2 for ADL-P, DG1, DG2, MTL, and TGL
  * i915: Update MTL DMC v2.22
  * i915: update MTL GSC to v102.0.10.1878
  * xe: Add BMG HuC 8.2.10
  * xe: Add GSC 104.0.0.1161 for LNL
  * xe: Add LNL HuC 9.4.13
  * i915: update DG2 HuC to v7.10.16
  * amdgpu: Update ISP FW for isp v4.1.1
  * QCA: Update Bluetooth QCA2066 firmware to 2.1.0-00641
* Wed Jul 31 2024 tiwai@suse.com
- Update to version 20240728 (git commit bcd040c21dc9):
  * amdgpu: update DMCUB to v0.0.227.0 for DCN35 and DCN351
  * Revert "iwlwifi: update ty/So/Ma firmwares for core89-58 release"
    (CVE-2023-47210, bsc#1225601, CVE-2023-38417, bsc#1225600)
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * iwlwifi: add gl FW for core89-58 release
  * iwlwifi: update ty/So/Ma firmwares for core89-58 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core89-58 release
  * mediatek: Update mt8195 SOF firmware and sof-tplg
  * ASoC: tas2781: fix the license issue for tas781 firmware
  * rtl_bt: Update RTL8852B BT USB FW to 0x048F_4008
  * .gitignore: Ignore intermediate files
  * i915: Update Xe2LPD DMC to v2.21
  * qcom: move signed x1e80100 signed firmware to the SoC subdir
  * qcom: add video firmware file for vpu-3.0
  * intel: avs: Add topology file for I2S Analog Devices 4567
  * intel: avs: Add topology file for I2S Nuvoton 8825
  * intel: avs: Add topology file for I2S Maxim 98927
  * intel: avs: Add topology file for I2S Maxim 98373
  * intel: avs: Add topology file for I2S Maxim 98357a
  * intel: avs: Add topology file for I2S Dialog 7219
  * intel: avs: Add topology file for I2S Realtek 5663
  * intel: avs: Add topology file for I2S Realtek 5640
  * intel: avs: Add topology file for I2S Realtek 5514
  * intel: avs: Add topology file for I2S Realtek 298
  * intel: avs: Add topology file for I2S Realtek 286
  * intel: avs: Add topology file for I2S Realtek 274
  * intel: avs: Add topology file for Digital Microphone Array
  * intel: avs: Add topology file for HDMI codecs
  * intel: avs: Add topology file for HDAudio codecs
  * Add a copy of Apache-2.0
  * intel: avs: Update AudioDSP base firmware for APL-based platforms
- Update aliases from 6.10.y and 6.11-rc1
- Add the Provides/Obsoletes for avs-topology-firmware, as now the
  firmware files are provided in this package
* Sat Jul 13 2024 tiwai@suse.com
- Update to version 20240712 (git commit ed874ed83cac):
  (bsc#1229069, CVE-2023-31315)
  * amdgpu: update DMCUB to v0.0.225.0 for Various AMDGPU Asics
  * qcom: add gpu firmwares for x1e80100 chipset (bsc#1219458)
  * linux-firmware: add firmware for qat_402xx devices
  * amdgpu: update raven firmware
  * amdgpu: update SMU 13.0.10 firmware
  * amdgpu: update SDMA 6.0.3 firmware
  * amdgpu: update PSP 13.0.10 firmware
  * amdgpu: update GC 11.0.3 firmware
  * amdgpu: update vega20 firmware
  * amdgpu: update PSP 13.0.5 firmware
  * amdgpu: update PSP 13.0.8 firmware
  * amdgpu: update vega12 firmware
  * amdgpu: update vega10 firmware
  * amdgpu: update VCN 4.0.0 firmware
  * amdgpu: update SDMA 6.0.0 firmware
  * amdgpu: update PSP 13.0.0 firmware
  * amdgpu: update GC 11.0.0 firmware
  * amdgpu: update picasso firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update PSP 13.0.11 firmware
  * amdgpu: update GC 11.0.4 firmware
  * amdgpu: update green sardine firmware
  * amdgpu: update VCN 4.0.2 firmware
  * amdgpu: update SDMA 6.0.1 firmware
  * amdgpu: update PSP 13.0.4 firmware
  * amdgpu: update GC 11.0.1 firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update VPE 6.1.1 firmware
  * amdgpu: update VCN 4.0.6 firmware
  * amdgpu: update SDMA 6.1.1 firmware
  * amdgpu: update PSP 14.0.1 firmware
  * amdgpu: update GC 11.5.1 firmware
  * amdgpu: update VCN 4.0.5 firmware
  * amdgpu: update SDMA 6.1.0 firmware
  * amdgpu: update PSP 14.0.0 firmware
  * amdgpu: update GC 11.5.0 firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update renoir firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update PSP 13.0.6 firmware
  * amdgpu: update GC 9.4.3 firmware
  * amdgpu: update yellow carp firmware
  * amdgpu: update VCN 4.0.4 firmware
  * amdgpu: update SMU 13.0.7 firmware
  * amdgpu: update SDMA 6.0.2 firmware
  * amdgpu: update PSP 13.0.7 firmware
  * amdgpu: update GC 11.0.2 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update raven2 firmware
  * amdgpu: update aldebaran firmware
  * linux-firmware: Update AMD cpu microcode
  * linux-firmware: Add ISH firmware file for Intel Lunar Lake platform
  * amdgpu: update DMCUB to v0.0.224.0 for Various AMDGPU Asics
  * cirrus: cs35l41: Update various firmware for ASUS laptops using CS35L41
  * amdgpu: Update ISP FW for isp v4.1.1
* Wed Jun 26 2024 tiwai@suse.com
- Update to version 20240622 (git commit 7d931f8afa51):
  * linux-firmware: mediatek: Update MT8173 VPU firmware to v1.2.0
  * qcom: Add AIC100 firmware files
* Tue Jun 18 2024 tiwai@suse.com
- Update to version 20240618 (git commit 7d931f8afa51):
  * amlogic: Update bluetooth firmware binary
  * linux-firmware: Update firmware file for Intel BlazarU core
  * linux-firmware: Update firmware file for Intel Bluetooth Magnetor core
  * linux-firmware: Update firmware file for Intel Bluetooth Solar core
  * linux-firmware: Update firmware file for Intel Bluetooth Pulsar core
  * rtl_bt: Update RTL8822C BT UART firmware to 0xB5D6_6DCB
  * rtl_bt: Update RTL8822C BT USB firmware to 0xAED6_6DCB
  * amdgpu: update DMCUB to v0.0.222.0 for DCN314
  * iwlwifi: add ty/So/Ma firmwares for core88-87 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core88-87 release
  * linux-firmware: add new cc33xx firmware for cc33xx chips
  * cirrus: cs35l56: Update firmware for Cirrus CS35L56 for ASUS UM5606 laptop
  * cirrus: cs35l56: Update firmware for Cirrus CS35L56 for various ASUS laptops
  * linux-firmware: Add firmware for Lenovo Thinkbooks
  * amdgpu: update yellow carp firmware
  * amdgpu: update VCN 4.0.4 firmware
  * amdgpu: update SDMA 6.0.2 firmware
  * amdgpu: update PSP 13.0.7 firmware
  * amdgpu: update GC 11.0.2 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update raven2 firmware
  * amdgpu: update raven firmware
  * amdgpu: update SMU 13.0.10 firmware
  * amdgpu: update SDMA 6.0.3 firmware
  * amdgpu: update PSP 13.0.10 firmware
  * amdgpu: update GC 11.0.3 firmware
  * amdgpu: update VCN 3.1.2 firmware
  * amdgpu: update PSP 13.0.5 firmware
  * amdgpu: update psp 13.0.8 firmware
  * amdgpu: update vega20 firmware
  * amdgpu: update vega12 firmware
  * amdgpu: update vega10 firmware
  * amdgpu: update VCN 4.0.0 firmware
  * amdgpu: update smu 13.0.0 firmware
  * amdgpu: update SDMA 6.0.0 firmware
  * amdgpu: update PSP 13.0.0 firmware
  * amdgpu: update GC 11.0.0 firmware
  * amdgpu: update picasso firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update green sardine firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update PSP 13.0.11 firmware
  * amdgpu: update GC 11.0.4 firmware
  * amdgpu: update VCN 4.0.2 firmware
  * amdgpu: update SDMA 6.0.1 firmware
  * amdgpu: update PSP 13.0.4 firmware
  * amdgpu: update GC 11.0.1 firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update VCN 4.0.5 firmware
  * amdgpu: update PSP 14.0.0 firmware
  * amdgpu: update GC 11.5.0 firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update SMU 13.0.6 firmware
  * amdgpu: update PSP 13.0.6 firmware
  * amdgpu: update GC 9.4.3 firmware
  * amdgpu: update renoir firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update aldebaran firmware
  * amdgpu: add support for PSP 14.0.1
  * amdgpu: add support for VPE 6.1.1
  * amdgpu: add support for VCN 4.0.6
  * amdgpu: add support for SDMA 6.1.1
  * amdgpu: add support for GC 11.5.1
  * amdgpu: Add support for DCN 3.5.1
  * QCA: Update Bluetooth QCA2066 firmware to 2.1.0-00639
  * cnm: update chips&media wave521c firmware.
  * linux-firmware: Add ordinary firmware for RTL8821AU device
* Tue May 21 2024 tiwai@suse.com
- Update to version 20240519 (git commit aae8224390e2):
  * amdgpu: add new ISP 4.1.1 firmware
* Thu May 16 2024 Takashi Iwai <tiwai@suse.com>
- Update aliases from 6.9 TW kernels
* Mon May 13 2024 tiwai@suse.com
- Update to version 20240510 (git commit 7c2303328d8e):
  * linux-firmware: Amphion: Update vpu firmware
  * linux-firmware: Update firmware file for Intel BlazarU core
  * linux-firmware: Update firmware file for Intel Bluetooth Magnetor core
  * linux-firmware: Update firmware file for Intel Bluetooth Solar core
  * linux-firmware: Update firmware file for Intel Bluetooth Solar core
  * i915: Add BMG DMC v2.06
  * linux-firmware: Add CS35L41 HDA Firmware for Asus HN7306
  * linux-firmware: Update firmware tuning for HP Consumer Laptop
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * rtl_bt: Update RTL8822C BT UART firmware to 0x0FD6_407B
  * rtl_bt: Update RTL8822C BT USB firmware to 0x0ED6_407B
  * cirrus: cs35l56: Add firmware for Cirrus CS35L56 for various ASUS laptops
  * linux-firmware: Add firmware and tuning for Lenovo Y770S
* Tue Apr 30 2024 tiwai@suse.com
- Update to version 20240426 (git commit 2398d264f953):
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * linux-firmware: Add firmware for Cirrus CS35L56 for various HP laptops
  * i915: Update Xe2LPD DMC to v2.20
  * linux-firmware: Remove Calibration Firmware and Tuning for CS35L41
  * linux-firmware: Add firmware for Lenovo Thinkbook 13X
  * ASoC: tas2781: Add dsp firmware for Thinkpad ICE-1 laptop
  * amdgpu: add DMCUB 3.5 firmware
  * amdgpu: add VPE 6.1.0 firmware
  * amdgpu: add VCN 4.0.5 firmware
  * amdgpu: add UMSCH 4.0.0 firmware
  * amdgpu: add SDMA 6.1.0 firmware
  * amdgpu: add PSP 14.0.0  firmware
  * amdgpu: add GC 11.5.0 firmware
  * amdgpu: update license date
* Fri Apr 19 2024 tiwai@suse.com
- Update to version 20240419 (git commit 7eab37522984):
  (CVE-2023-47210, bsc#1225601, CVE-2023-38417, bsc#1225600)
  * Montage: update firmware for Mont-TSSE
  * linux-firmware: Add tuning parameter configs for CS35L41 Firmware
  * linux-firmware: Fix firmware names for Laptop SSID 104316a3
  * linux-firmware: Add CS35L41 HDA Firmware for Lenovo Legion Slim 7 16ARHA7
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: update firmware for MT7922 WiFi device
  * iwlwifi: add gl FW for core87-44 release
  * iwlwifi: add ty/So/Ma firmwares for core87-44 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core87-44 release
  * nvidia: Update Tegra210 XUSB firmware to v50.29
  * amdgpu: update beige goby firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update psp 13.0.11 firmware
  * amdgpu: update gc 11.0.4 firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update renoir firmware
  * amdgpu: update vcn 4.0.2 firmware
  * amdgpu: update sdma 6.0.1 firmware
  * amdgpu: update psp 13.0.4 firmware
  * amdgpu: update gc 11.0.1 firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update vega20 firmware
  * amdgpu: update yellow carp firmware
  * amdgpu: update green sardine firmware
  * amdgpu: update vega12 firmware
  * amdgpu: update raven2 firmware
  * amdgpu: update vcn 4.0.4 firmware
  * amdgpu: update smu 13.0.7 firmware
  * amdgpu: update sdma 6.0.2 firmware
  * amdgpu: update ipsp 13.0.7 firmware
  * amdgpu: update gc 11.0.2 firmware
  * amdgpu: update vega10 firmware
  * amdgpu: update raven firmware
  * amdgpu: update navi14 firmware
  * amdgpu: update smu 13.0.10 firmware
  * amdgpu: update sdma 6.0.3 firmware
  * amdgpu: update psp 13.0.10 firmware
  * amdgpu: update gc 11.0.3 firmware
  * amdgpu: update vcn 3.1.2 firmware
  * amdgpu: update psp 13.0.5 firmware
  * amdgpu: update gc 10.3.6 firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update arcturus firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update vcn 4.0.3 firmware
  * amdgpu: update smu 13.0.6 firmware
  * amdgpu: update psp 13.0.6 firmware
  * amdgpu: update gc 9.4.3 firmware
  * amdgpu: update vcn 4.0.0 firmware
  * amdgpu: update smu 13.0.0 firmware
  * amdgpu: update sdma 6.0.0 firmware
  * amdgpu: update psp 13.0.0 firmware
  * amdgpu: update gc 11.0.0 firmware
  * amdgpu: update  firmware
  * amdgpu: update aldebaran firmware
  * amdgpu: update psp 13.0.8 firmware
  * amdgpu: update gc 10.3.7 firmware
  * linux-firmware: mediatek: Update MT8173 VPU firmware to v1.1.9
  * ath10k: WCN3990: hw1.0: add qcm2290 firmware API file
  * ath10k: WCN3990: hw1.0: move firmware back from qcom/ location
  * i915: Add DG2 HuC 7.10.15
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * linux-firmware: update firmware for en8811h 2.5G ethernet phy
  * rtw89: 8852c: update fw to v0.27.56.14
  * rtw89: 8922a: add firmware v0.35.18.0
  * rtw88: Add RTL8703B firmware v11.0.0
* Thu Apr  4 2024 Takashi Iwai <tiwai@suse.com>
- Drop duplicated WHENCE from kernel-firmware-* subpackages (bsc#1222319)
* Mon Mar 25 2024 tiwai@suse.com
- Update to version 20240322 (git commit 9a6a0cc195c1):
  * mekdiatek: Update mt8186 SOF firmware to v2.0.1
  * linux-firmware: Add firmware for Cirrus CS35L56 for Dell laptops
  * Montage: update firmware for Mont-TSSE
  * WHENCE: Link the Raspberry Pi CM4 and 5B to the 4B
  * Intel Bluetooth: Update firmware file for Intel Bluetooth BE200
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX210
  * Intel Bluetooth: Update firmware file for Intel Bluetooth AX200
  * Intel Bluetooth: Update firmware file for Intel Bluetooth AX201
  * Intel Bluetooth: Update firmware file for Intel Bluetooth 9560
  * Intel Bluetooth: Update firmware file for Intel Bluetooth 9260
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * linux-firmware: mediatek: Update MT8173 VPU firmware to v1.1.8
  * imx: sdma: update firmware to v3.6/v4.6
- Update aliases from 6.8 kernels
* Wed Mar 13 2024 tiwai@suse.com
- Update to version 20240312 (git commit 4a404b5bfdb9):
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * iwlwifi: update 9000-family firmwares to core85-89
  * rtl_bt: Update RTL8852A BT USB firmware to 0xD9D6_17DA
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: Add CS35L41 HDA Firmware for Lenovo Thinkbook 16P Laptops
* Fri Mar  1 2024 tiwai@suse.com
- Update to version 20240229 (git commit 977332782302):
  * amdgpu: Update VCN firmware binaries
  * Intel IPU2: Add firmware files
  * brcm: Add nvram for the Acer Iconia One 7 B1-750 tablet
  * i915: Add Xe2LPD DMC v2.18
  * i915: Update MTL DMC v2.21
* Thu Feb 22 2024 tiwai@suse.com
- Update to version 20240220 (git commit 73b4429fae36):
  * linux-firmware: update firmware for en8811h 2.5G ethernet phy
  * linux-firmware: add firmware for MT7996
  * xe: First GuC release for LNL and Xe
  * i915: Add GuC v70.20.0 for ADL-P, DG1, DG2, MTL and TGL
  * linux-firmware: Add CS35L41 firmware for Lenovo Legion 7i gen7 laptop (16IAX7)
  * brcm: Add nvram for the Asus Memo Pad 7 ME176C tablet
  * ice: update ice DDP package to 1.3.36.0
  * Intel IPU3 ImgU: Move firmware file under intel/ipu
  * Intel IPU6: Move firmware binaries under ipu/
  * check_whence: Add a check for duplicate link entries
  * WHENCE: Clean up section separators
  * linux-firmware: Add CS35L41 firmware for additional ASUS Zenbook 2023 models
  * panthor: Add initial firmware for Gen10 Arm Mali GPUs
  * amdgpu: DMCUB Updates for DCN321: 7.0.38.0
  * amdgpu: DMCUB updates for Yellow Carp: 4.0.68.0
  * qcom: update venus firmware file for v5.4
  * Montage: add firmware for Mont-TSSE
  * amdgpu: update DMCUB to v0.0.203.0 for DCN314 and DCN32
  * linux-firmware: Remove 2 HP laptops using CS35L41 Audio Firmware
  * linux-firmware: Fix filenames for some CS35L41 firmwares for HP
- Use patch macro -P option for RPM 4.20
* Fri Feb  2 2024 tiwai@suse.com
- More update on version 20240201 (git commit 3677750467cb):
  * linux-firmware: wilc1000: update WILC1000 firmware to v16.1.2
  * rtl_nic: add firmware for RTL8126A (bsc#1217417)
  * qcom: Add Audio firmware for SM8550 HDK
* Thu Feb  1 2024 tiwai@suse.com
- Update to version 20240201 (git commit 1b24d7d3379b):
  * linux-firmware: intel: Add IPU6 firmware binaries
  * ath11k: WCN6855 hw2.0: update to WLAN.HSP.1.1-03125-QCAHSPSWPL_V1_V2_SILICONZ_LITE-3.6510.37
  * Revert "amdgpu: DMCUB updates for various AMDGPU ASICs"
  * amdgpu: update SMU 13.0.0 firmware
  * amdgpu: update PSP 13.0.0 firmware
  * amdgpu: update GC 11.0.0 firmware
  * brcm: Add brcmfmac43430-sdio.xxx.txt nvram for the Chuwi Hi8 (CWI509) tablet
  * amdgpu: DMCUB updates for various AMDGPU ASICs
* Mon Jan 29 2024 tiwai@suse.com
- Update to version 20240126 (git commit 8fa621d2f9c1):
  * qcom: Add Audio firmware for SM8650 MTP
  * linux-firmware: Add firmware for Cirrus CS35L41 on HP Consumer Laptops
  * Intel Bluetooth: Make spacing consistent with rest of WHENCE
  * amdgpu: update raven2 firmware
  * amdgpu: update raven firmware
  * amdgpu: update SDMA 5.2.7 firmware
  * amdgpu: update PSP 13.0.8 firmware
  * amdgpu: update VCN 3.1.2 firmware
  * amdgpu: update SDMA 5.2.6 firmware
  * amdgpu: update PSP 13.0.5 firmware
  * amdgpu: update GC 10.3.6 firmware
  * amdgpu: add GC 11.0.1 rlc_1 firmware
  * amdgpu: update vega20 firmware
  * amdgpu: update VCN 4.0.0 firmware
  * amdgpu: update SMU 13.0.0 firmware
  * amdgpu: update PSP 13.0.0 firmware
  * amdgpu: update GC 11.0.0 firmware
  * amdgpu: update vega12 firmware
  * amdgpu: update vega10 firmware
  * amdgpu: update beige goby firmware
  * amdgpu: update picasso firmware
  * amdgpu: update dimgrey cavefish firmware
  * amdgpu: update vangogh firmware
  * amdgpu: update navy flounder firmware
  * amdgpu: update green sardine firmware
  * amdgpu: update sienna cichlid firmware
  * amdgpu: update PSP 13.0.11 firmware
  * amdgpu: update GC 11.0.4 firmware
  * amdgpu: update VCN 4.0.2 firmware
  * amdgpu: update PSP 13.0.4 firmware
  * amdgpu: update GC 11.0.1 firmware
  * amdgpu: update arcturus firmware
  * amdgpu: update navi14 firmware
  * amdgpu: add VCN 4.0.3 firmware
  * amdgpu: add SDMA 4.4.2 firmware
  * amdgpu: add SMU 13.0.6 firmware
  * amdgpu: add PSP 13.0.6 firmware
  * amdgpu: Add GC 9.4.3 firmware
  * amdgpu: update renoir firmware
  * amdgpu: update VCN 4.0.4 firmware
  * amdgpu: update SMU 13.0.7 firmware
  * amdgpu: update PSP 13.0.7 firmware
  * amdgpu: update GC 11.0.2 firmware
  * amdgpu: update navi12 firmware
  * amdgpu: update yellow carp firmware
  * amdgpu: update SMU 13.0.10 firmware
  * amdgpu: update SDMA 6.0.3 firmware
  * amdgpu: update PSP 13.0.10 firmware
  * amdgpu: update GC 11.0.3 firmware
  * amdgpu: update navi10 firmware
  * amdgpu: update aldebaran firmware
  * linux-firmware: Update AMD cpu microcode
  * RTL8192E: Remove old realtek WiFi firmware
- Update aliases
* Tue Jan 16 2024 tiwai@suse.com
- Update to version 20240115 (git commit efeb548d2a2b):
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX211
  * amdgpu: DMCUB updates for DCN314
  * cirrus: Add firmware file for cs42l43
  * amdgpu: DMCUB updates for DCN312
* Mon Jan 15 2024 tiwai@suse.com
- Update to version 20240111 (git commit b3132c18d0be):
  * qcom: Update the firmware for Adreno a630 family of GPUs
  * cirrus: Add CS35L41 firmware for Legion Slim 7 Gen 8 laptops
  * linux-firmware: Add firmware for Cirrus CS35L41 for various Dell laptops
* Wed Jan 10 2024 tiwai@suse.com
- Update to version 20240110 (git commit 31db82d69905):
  * linux-firmware: update firmware for qat_4xxx devices
  * linux-firmware: update firmware for w1u_uart
  * amdgpu: DMCUB updates for DCN314
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX210
* Mon Jan  8 2024 tiwai@suse.com
- Update to version 20240105 (git commit 5a6ae745d8a4):
  * amlogic/bluetooth: add firmware bin of W1 serial soc(w1u_uart)
- Drop superfluous Provides from uncompressed kernel-firmware package
  that may confuse dependencies (bsc#1218307)
- Minor adjustment and updates of scripts / templates
* Tue Jan  2 2024 tiwai@suse.com
- Update to version 20240102 (git commit b83108216200):
  * linux-firmware: add firmware for mediatek bluetooth chip (MT7925)
  * linux-firmware: add firmware for MT7925
  * ASoC: tas2563: Add dsp firmware for laptops or other mobile devices
  * QCA: Add bluetooth firmware nvm files for QCA2066
  * QCA: Update Bluetooth QCA2066 firmware to 2.1.0-00629
- Update aliases
* Sun Dec 31 2023 tiwai@suse.com
- Update to version 20231226 (git commit abfcad8b1405):
  * rtl_bt: Add firmware and config files for RTL8852BT/RTL8852BE-VT
  * ASoC: tas2781: Add dsp firmware for different laptops
  * ath11k: WCN6855 hw2.0: update to WLAN.HSP.1.1-03125-QCAHSPSWPL_V1_V2_SILICONZ_LITE-3.6510.36
  * ath11k: WCN6855 hw2.0: update board-2.bin
  * ath11k: WCN6750 hw1.0: update board-2.bin
  * ath11k: IPQ8074 hw2.0: update board-2.bin
  * ath10k: WCN3990 hw1.0: update board-2.bin
  * ath10k: QCA9888 hw2.0: update board-2.bin
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to WLAN.RM.4.4.1-00309-
  * ath12k: add new driver and firmware for WCN7850
  * iwlwifi: update gl FW for core80-165 release
  * intel: vsc: Add firmware for Visual Sensing Controller
  * cirrus: Add CS35L41 firmware and tunings for ASUS Zenbook 2023 Models
  * cirrus: Add CS35L41 firmware and tunings for ASUS Zenbook 2022 Models
  * amdgpu: DMCUB updates for various AMDGPU ASICs
- New subpackag kernel-firmware-ath12k
- Update aliases
* Fri Dec 15 2023 tiwai@suse.com
- Update to version 20231214 (git commit b80907ec3a81):
  * qcom: Add Audio firmware for SM8650 QRD
  * qcom: Add Audio firmware for SM8550 QRD
  * Add rdfind for deb/rpm build jobs
  * wfx: update to firmware 3.17
  * wfx: fix broken firmware
* Wed Dec  6 2023 tiwai@suse.com
- Update to version 20231205 (git commit bfc33c1e308e):
  * linux-firmware: Update AMD cpu microcode
  * cxgb4: Update firmware to revision 1.27.5.0
  * linux-firmware: add firmware for en8811h 2.5G ethernet phy
  * s5p-mfc: Add MFC v12 Firmware
  * qcom: update qrb4210 firmware
  * qcom: update qcm2290 firmware
  * qcom: update qcm2290/qrb4210 WiFi firmware file
  * qcom: update Venus firmware file for v6.0
* Wed Nov 29 2023 tiwai@suse.com
- Update to version 20231128 (git commit d9f6088f7e91):
  * Add a COPYOPTS variable
  * rtl_bt: Update RTL8852A BT USB firmware to 0xDFC8_145F
* Tue Nov 28 2023 tiwai@suse.com
- Update to version 20231127 (git commit 4124f8f928d5):
  * Make rdfind optional
  * ice: update ice DDP wireless_edge package to 1.3.13.0
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for MT7921 WiFi device
  * Makefile, copy-firmware: Use portable "command -v" to detect installed programs
  * amdgpu: update DMCUB firmware to 0.0.194.0 for DCN321 and DCN32
  * powervr: add firmware for Imagination Technologies AXE-1-16M GPU
  * ice: update ice DDP comms package to 1.3.45.0
  * ice: update ice DDP package to 1.3.35.0
  * mediatek: Remove an unused packed library
  * amdgpu: update DMCUB firmware to 0.0.193.0 for DCN31 and DCN314
- Drop obsoleted copy-file-skip-rdfind.patch; use --ignore-duplicates
* Tue Nov 21 2023 tiwai@suse.com
- Update to version 20231120 (git commit 9552083a783e):
  * mediatek: Sync shared memory structure changes
  * Intel Bluetooth: Update firmware file for Intel Bluetooth BE200
  * i915: Update MTL DMC to v2.19
  * Make email replies more resilient
  * Try both utf-8 and windows-1252 for decoding email
* Fri Nov 17 2023 tiwai@suse.com
- Update to version 20231116 (git commit 6723a8d90923):
  * iwlwifi: fix for the new FWs from core83-55 release
  * Enable deb and rpm builds on tags
  * linux-firmware: Add firmware for Cirrus CS35L41 on HP G11 Laptops
  * linux-firmware: Add firmware for Cirrus CS35L41 on 2024 ASUS Zenbook Laptops
* Thu Nov 16 2023 tiwai@suse.com
- Update to version 20231115 (git commit a07fd0b96b5a):
  * iwlwifi: add new FWs from core83-55 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core83-55 release
  * Add a workaround for gitlab.freedesktop.org pull requests
  * Add extra debugging output when processing pull requests
  * Process pull requets directly from mbox
  * linux-firmware: add firmware for mt7988 internal 2.5G ethernet phy
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX210
* Mon Nov 13 2023 tiwai@suse.com
- Update to version 20231110 (git commit 74158e7ac86d):
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * Ensure rdfind is installed
  * Add checks for destination directory being specified
  * Fix symlink creation for some files
  * Fix classification of some pull requests
  * nvidia: add GSP-RM version 535.113.01 firmware images
- Skip rdfind (not included in our distro as default):
  copy-file-skip-rdfind.patch
- Fix make-files.sh to handle symlinked directories
* Tue Nov  7 2023 tiwai@suse.com
- Update to version 20231107 (git commit a5a6dded0c7f):
  * Intel Bluetooth: Update firmware file for Intel Bluetooth BE200
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX101
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Magnetor Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for SolarF Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Solar Intel Bluetooth AX210
  * amdgpu: DMCUB updates for various AMDGPU ASICs
  * qca: add bluetooth firmware for WCN3988
  * linux-firmware: ixp4xx: Add the IXP4xx firmware
  * rtw89: 8852b: update fw to v0.29.29.5
  * rtw89: 8852b: update fw to v0.29.29.4
  * rtw89: 8851b: update fw to v0.29.41.3
  * Intel Bluetooth: Update firmware file for Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Intel Bluetooth AX211
  * Intel Bluetooth: Update firmware file for Intel Bluetooth AX210
  * Intel Bluetooth: Update firmware file for Intel Bluetooth Magnetor AX101
  * Intel Bluetooth: Update firmware file for Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Intel Bluetooth AX203
  * Intel Bluetooth: Update firmware file for Intel Bluetooth Magnetor AX201
  * Intel Bluetooth: Update firmware file for Intel Bluetooth Magnetor AX211
  * Intel Bluetooth: Update firmware file for Intel Bluetooth BE200
  * Disable deb and rpm CI other than at release
  * Use `git am` instead of `b4 shazam`
  * rtl_nic: update firmware of RTL8156B
  * Catch unicode decode errors
* Mon Oct 23 2023 tiwai@suse.com
- Update to version 20231019 (git commit d983107a2dfa)
  (bsc#1215823, CVE-2023-20592):
  * Fix the robot email script
  * linux-firmware: Update AMD cpu microcode
  * Add support for sending emails while processing a PR/patch
  * amdgpu: update SMU 13.0.0 firmware
  * linux-firmware: add Amlogic bluetooth firmware
  * Add a script for a robot to open up pull requests
  * i915: Add GuC v70.13.1 for DG2, TGL, ADL-P and MTL
  * iwlwifi: add a missing FW from core80-39 release
  * amdgpu: update raven firmware from 5.7 branch
  * amdgpu: update SDMA 5.2.7 firmware from 5.7 branch
  * amdgpu: update PSP 13.0.8 firmware from 5.7 branch
  * amdgpu: update GC 10.3.7 firmware from 5.7 branch
  * amdgpu: update DCN 3.1.6 firmware from 5.7 branch
  * amdgpu: update SDMA 5.2.6 firmware from 5.7 branch
  * amdgpu: update PSP 13.0.5 firmware from 5.7 branch
  * amdgpu: update GC 10.3.6 firmware from 5.7 branch
  * amdgpu: update VCN 4.0.0 firmware from 5.7 branch
  * amdgpu: update SMU 13.0.0 firmware from 5.7 branch
  * amdgpu: update SDMA 6.0.0 firmware from 5.7 branch
  * amdgpu: update PSP 13.0.0 firmware from 5.7 branch
  * amdgpu: update GC 11.0.0 firmware from 5.7 branch
  * amdgpu: update vega20 firmware from 5.7 branch
  * amdgpu: update beige goby firmware from 5.7 branch
  * amdgpu: update vega12 firmware from 5.7 branch
  * amdgpu: update vega10 firmware from 5.7 branch
  * amdgpu: update dimgrey cavefish firmware from 5.7 branch
  * amdgpu: update picasso firmware from 5.7 branch
  * amdgpu: update navy flounder firmware from 5.7 branch
  * amdgpu: update vangogh firmware from 5.7 branch
  * amdgpu: update green sardine firmware from 5.7 branch
  * amdgpu: update sienna cichlid firmware from 5.7 branch
  * amdgpu: update PSP 13.0.11 firmware from 5.7 branch
  * amdgpu: update GC 11.0.4 firmware from 5.7 branch
  * amdgpu: update SDMA 6.0.1 firmware from 5.7 branch
  * amdgpu: update PSP 13.0.4 firmware from 5.7 branch
  * amdgpu: update GC 11.0.1 firmware from 5.7 branch
  * amdgpu: update navi14 firmware from 5.7 branch
  * amdgpu: update renoir firmware from 5.7 branch
  * amdgpu: update navi12 firmware from 5.7 branch
  * amdgpu: update VCN 4.0.4 firmware from 5.7 branch
  * amdgpu: update SMU 13.0.7 firmware from 5.7 branch
  * amdgpu: update SDMA 6.0.2 firmware from 5.7 branch
  * amdgpu: update PSP 13.0.7 firmware from 5.7 branch
  * amdgpu: update GC 11.0.2 firmware from 5.7 branch
  * amdgpu: update yellow carp firmware from 5.7 branch
  * amdgpu: update navi10 firmware from 5.7 branch
  * amdgpu: update raven2 firmware from 5.7 branch
  * amdgpu: update SMU 13.0.10 firmware from 5.7 branch
  * amdgpu: update PSP 13.0.10 firmware from 5.7 branch
  * amdgpu: update GC 11.0.3 firmware from 5.7 branch
  * amdgpu: update aldebaran firmware from 5.7 branch
* Thu Oct 12 2023 Takashi Iwai <tiwai@suse.com>
- Add Provides to sub-packages from kernel-firmware (bsc#1214789);
  this will work around the potential conflicts of compressed vs
  uncompressed installations
* Mon Oct  9 2023 tiwai@suse.com
- Update to version 20231006 (git commit 389575a8a177) (jsc#PED-6130, jsc#PED-6081):
  * WHENCE: add symlink for BananaPi M64
  * linux-firmware: Add firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * Build debian and fedora images
  * Add new Makefile target to build a deb and rpm package
  * i915: Update MTL DMC to v2.17
  * iwlwifi: add FWs for new GL and MA device types with multiple RF modules
  * amd_pmf: Add initial PMF TA for Smart PC Solution Builder
  * linux-firmware: Update FW files for MRVL PCIE 8997 chipsets
  * rtl_bt: Update RTL8851B BT USB firmware to 0x048A_D230
  * iwlwifi: add new FWs from core81-65 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core81-65 release
- Drop fdupes to avoid missing files for split packages (bsc#1215464)
- Add conflicts to each split subpk against uncompressed raw package;
  the contents may conflict and the compressed files won't be effective
  unless the raw files get removed
- Update aliases
* Fri Sep 22 2023 tiwai@suse.com
- Update to version 20230918 (commit f48da6da5507):
  * Run merge request pipelines for pre-commit.
  * linux-firmware: amd-ucode: Add note on fam19h warnings
  * i915: update MTL HuC to version 8.5.4
  * amdgpu: update DMCUB to 0.0.183.0 for various AMDGPU ASICs
* Thu Sep 14 2023 tiwai@suse.com
- Update to version 20230907 (git commit c801b3b807d2):
  * Turn off textwidth check
  * linux-firmware: add link to sc8280xp audioreach firmware
  * qcom: sm8250: add RB5 sensors DSP firmware
  * qcom: Update vpu-1.0 firmware
  * qcom: sm8250: update DSP firmware
  * qcom: add firmware for the onboard WiFi on qcm2290 / qrb4210
  * qcom: add venus firmware files for v6.0
  * qcom: add firmware for QRB4210 platforms
  * qcom: add firmware for QCM2290 platforms
  * qcom: add GPU firmware for QCM2290 / QRB2210
  * ath10k/WCN3990: move wlanmdsp to qcom/sdm845
  * WHENCE: Don't compress qcom json files
  * WHENCE: amd-ucode: Use new RawFile keyword
  * check_whence: Recognize RawFile keyword
  * Only run ci-fairy on merge requests
  * Capture artifacts from `make dist` to save at release time.
  * Add new toplevel 'make dist' target.
  * Create symlinks for all firmware that is duplicate using rdfind
  * QCA: Update Bluetooth WCN685x 2.1 firmware to 2.1.0-00605
  * Add shellcheck pre-commit target
  * Fix carl9170fw shell scripts for shellcheck errors
  * Add a rule for automatic tagging releases by pipeline schedule
  * Add gitlab ci for calling pre-commit and ci-fairy
  * Add Dockerfile used to build CI image
  * Rewrite README in markdown
  * Wire up pre-commit to `make check`
  * Add pre-commit hooks and codespell template
  * check_whence: reformat using python black
- Drop obsoleted amd-ucode-rawfile.patch
- Fix make-files.sh to handle RawFile tag correctly
- Update aliases from 6.6-rc1
* Tue Aug 29 2023 tiwai@suse.com
- Update to version 20230829 (git commit 49f9e3479fb5):
  * i915: Update MTL DMC to v2.16
  * copy-firmware: Introduce 'RawFile' keyword
  * copy-firmware: Support additional compressor options
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: update firmware for qat_4xxx devices
  * linux-firmware: Update AMD SEV firmware
  * amdgpu: update DMCUB to 0.0.181.0 for various AMDGPU ASICs
  * rtw89: 8852b: update fw to v0.29.29.3
  * rtw89: 8851b: update fw to v0.29.41.2
  * i915: add GSC 102.0.0.1655 for MTL
  * amdgpu: DMCUB updates for various AMDGPU asics
- Switch to the compressed / split installation as default, make
  uncompressed / raw package as a multibuild flavor, instead
  as a preliminary work for dropping the big kernel-firmware
  (bsc#1214789)
- Use the standard copy-file.sh for split package installation, too
  Another scirpt, make-files.sh, is provided for generating file lists
- Ignore README in copy-file.sh:
  copy-file-ignore-README.patch
- Workaround for installing raw files for ucode-amd:
  amd-ucode-rawfile.patch
- Drop the obsolsted revert of rtw8822c_fw.bin
- Update aliases from 6.5
* Fri Aug 18 2023 tiwai@suse.com
- Update to version 20230814 (git commit 0e048b061bde):
  (bsc#1215831, CVE-2021-26345, CVE-2021-46766, CVE-2021-46774,
  CVE-2022-23820, CVE-2022-23830, CVE-2023-20519, CVE-2023-20521,
  CVE-2023-20526, CVE-2023-20533, CVE-2023-20566):
  * amdgpu: DMCUB updates for various AMDGPU asics
  * Revert "amdgpu: partially revert firmware for GC 11.0.0 and GC 11.0.2"
  * amdgpu: partially revert firmware for GC 11.0.0 and GC 11.0.2
  * cirrus: Add CS35L41 firmware for HP G11 models
  * linux-firmware: Update AMD cpu microcode
  * rtl_bt: Add firmware v2 file for RTL8852C
  * Revert "rtl_bt: Update RTL8852C BT USB firmware to 0x040D_7225"
  * amdgpu: DMCUB updates for various AMDGPU asics
  * cxgb4: Update firmware to revision 1.27.4.0
  * Mellanox: Add new mlxsw_spectrum firmware xx.2012.1012
  * linux-firmware: Add URL for latest FW binaries for NXP BT chipsets
  * rtw89: 8851b: update firmware to v0.29.41.1
  * qcom: sdm845: add RB3 sensors DSP firmware
- Drop the obsoleted patch
  amd-ucode-CVE-2023-20569.patch
* Wed Aug  9 2023 Takashi Iwai <tiwai@suse.com>
- Update AMD 19h ucode for "Inception" (bsc#1213287, CVE-2023-20569)
  amd-ucode-CVE-2023-20569.patch
* Wed Aug  2 2023 tiwai@suse.com
- Update to version 20230731 (git commit 253cc179d849):
  * amdgpu: Update DMCUB for DCN314 & Yellow Carp
  * ice: add LAG-supporting DDP package
  * i915: Update MTL DMC to v2.13
  * i915: Update ADLP DMC to v2.20
  * cirrus: Add CS35L41 firmware for Dell Oasis Models
  * copy-firmware: Fix linking directories when using compression
  * copy-firmware: Fix test: unexpected operator
  * qcom: sc8280xp: LENOVO: remove directory sym link
  * qcom: sc8280xp: LENOVO: Remove execute bits
* Mon Jul 24 2023 tiwai@suse.com
- Update to version 20230724 (git commit 59fbffa9ec8e):
  including the amd-ucode update for "ZenBleed" (CVE-2023-20593, bsc#1213286)
  * amdgpu: update VCN 4.0.0 firmware
  * amdgpu: add initial SMU 13.0.10 firmware
  * amdgpu: add initial SDMA 6.0.3 firmware
  * amdgpu: add initial PSP 13.0.10 firmware
  * amdgpu: add initial GC 11.0.3 firmware
  * linux-firmware: Update AMD fam17h cpu microcode
  * linux-firmware: Update AMD cpu microcode
  * amdgpu: update green sardine VCN firmware
  * amdgpu: update renoir VCN firmware
  * amdgpu: update raven VCN firmware
  * amdgpu: update raven2 VCN firmware
  * amdgpu: update Picasso VCN firmware
  * amdgpu: update DMCUB to v0.0.175.0 for various AMDGPU ASICs
  * Updated NXP SR150 UWB firmware
  * wfx: update to firmware 3.16.1
  * mediatek: Update mt8195 SCP firmware to support 10bit mode
  * i915: update DG2 GuC to v70.8.0
  * i915: update to GuC 70.8.0 and HuC 8.5.1 for MTL
  * cirrus: Add CS35L41 firmware for ASUS ROG 2023 Models
* Sat Jul  8 2023 tiwai@suse.com
- Update to version 20230707 (git commit d3f66064cf43):
  * Partially revert "amdgpu: DMCUB updates for DCN 3.1.4 and 3.1.5"
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * Fix qcom ASoC tglp WHENCE entry
  * check_whence: Check link targets are valid
  * iwlwifi: add new FWs from core80-39 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core80-39 release
  * qcom: Add Audio firmware for SC8280XP X13s
  * Makefile, copy-firmware: support xz/zstd compressed firmware
  * copy-firmware: silence the last shellcheck warnings
  * copy-firmware: drop obsolete backticks, quote
  * copy-firmware: tweak sed invocation
  * copy-firmware: quote deskdir and dirname
  * check_whence: error if symlinks are in-tree
  * check_whence: error if File: is actually a link
  * check_whence: strip quotation marks
  * linux-firmware: wilc1000: update WILC1000 firmware to v16.0
  * ice: update ice DDP wireless_edge package to 1.3.10.0
  * amdgpu: DMCUB updates for DCN 3.1.4 and 3.1.5
- Update aliases
* Thu Jun 22 2023 tiwai@suse.com
- Update to version 20230620 (git commit 045b2136a619):
  * amdgpu: update DMCUB to v0.0.172.0 for various AMDGPU ASICs
  * fix broken cirrus firmware symlinks
  * qcom: Update the microcode files for Adreno a630 GPUs.
  * qcom: sdm845: rename the modem firmware
  * qcom: sdm845: update remoteproc firmware
  * rtl_bt: Update RTL8852A BT USB firmware to 0xDAC7_480D
  * rtl_bt: Update RTL8852C BT USB firmware to 0x040D_7225
  * amdgpu: DMCUB updates for various AMDGPU asics
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * i915: Add HuC v8.5.0 for MTL
  * mediatek: Update mt8195 SCP firmware to support hevc
- Drop obsoleted patch for WHENCE:
  cirrus-WHENCE-link-fixes.patch
- Update aliases
* Mon Jun  5 2023 tiwai@suse.com
- Update to version 20230531 (git commit 9d4c9a52c237):
  * qcom: apq8016: add Dragonboard 410c WiFi and modem firmware
  * cirrus: Add firmware for new Asus ROG Laptops
  * brcm: Add symlinks from Pine64 devices to AW-CM256SM.txt
  * amdgpu: Update GC 11.0.1 and 11.0.4
  * rtw89: 8851b: add firmware v0.29.41.0
  * amdgpu: update yellow carp firmware for amd.5.5 release
  * amdgpu: update navi14 firmware for amd.5.5 release
  * amdgpu: update navi12 firmware for amd.5.5 release
  * amdgpu: update vega20 firmware for amd.5.5 release
  * amdgpu: update vega12 firmware for amd.5.5 release
  * amdgpu: update navi10 firmware for amd.5.5 release
  * amdgpu: update vega10 firmware for amd.5.5 release
  * amdgpu: update PSP 13.0.11 firmware for amd.5.5 release
  * amdgpu: update GC 11.0.4 firmware for amd.5.5 release
  * amdgpu: update SDMA 6.0.1 firmware for amd.5.5 release
  * amdgpu: update PSP 13.0.4 firmware for amd.5.5 release
  * amdgpu: update GC 11.0.1 firmware for amd.5.5 release
  * amdgpu: update 13.0.8 firmware for amd.5.5 release
  * amdgpu: update GC 10.3.7 firmware for amd.5.5 release
  * amdgpu: update vangogh firmware for amd.5.5 release
  * amdgpu: update VCN 4.0.4 firmware for amd.5.5 release
  * amdgpu: update SMU 13.0.7 firmware for amd.5.5 release
  * amdgpu: update PSP 13.0.7 firmware for amd.5.5 release
  * amdgpu: update GC 11.0.2 firmware for amd.5.5 release
  * amdgpu: update renoir firmware for amd.5.5 release
  * amdgpu: update VCN 4.0.0 firmware for amd.5.5 release
  * amdgpu: update SMU 13.0.0 firmware for amd.5.5 release
  * amdgpu: update PSP 13.0.0 firmware for amd.5.5 release
  * amdgpu: update GC 11.0.0 firmware for amd.5.5 release
  * amdgpu: update green sardine firmware for amd.5.5 release
  * amdgpu: update beige goby firmware for amd.5.5 release
  * amdgpu: update dimgrey cavefish firmware for amd.5.5 release
  * amdgpu: update arcturus firmware for amd.5.5 release
  * amdgpu: update vcn 3.1.2 firmware for amd.5.5 release
  * amdgpu: update psp 13.0.5 firmware for amd.5.5 release
  * amdgpu: update GC 10.3.6 firmware for amd.5.5 release
  * amdgpu: update navy flounder firmware for amd.5.5 release
  * amdgpu: update sienna cichlid firmware for amd.5.5 release
  * amdgpu: update aldebaran firmware for amd.5.5 release
  * amdgpu: DMCUB updates for various AMDGPU asics
  * ice: update ice DDP comms package to 1.3.40.0
  * cxgb4: Update firmware to revision 1.27.3.0
- Fix the broken symlink targets for cirrus firmware:
  cirrus-WHENCE-link-fixes.patch
- Clean up spec template to match with the actual output
* Tue May 23 2023 tiwai@suse.com
- Update to version 20230517 (git commit 08b854f02066):
  * rtlwifi: Add firmware v6.0 for RTL8192FU
  * rtlwifi: Update firmware for RTL8188EU to v28.0
  * cirrus: Add firmware and tuning files for HP G10 series laptops
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * WHENCE: Cleanup Realtek BT firmware provenance
  * linux-firmware: update firmware for MT7922 WiFi device
  * cnm: update chips&media wave521c firmware.
  * cirrus: Add firmware and tuning files for Lenovo ThinkPad P1 Gen 6
  * check_whence: error on directory listed as File
  * check_whence: error on duplicate file entries
  * WHENCE: comment out duplicate MediaTek firmware
  * i915: Add GuC v70.6.6 for MTL
  * amdgpu: update DCN 3.1.6 DMCUB firmware
  * rtl_bt: Update RTL8852B BT USB firmware to 0xDBC6_B20F
  * rtl_bt: Update RTL8761B BT USB firmware to 0xDFC6_D922
  * rtl_bt: Update RTL8761B BT UART firmware to 0x9DC6_D922
- Update aliases from 6.4-rc3
* Thu Apr 27 2023 tiwai@suse.com
- Update to version 20230427 (git commit fab149657d8d):
  * Group all Conexant V4L devices together
  * rtl_nic: update firmware of USB devices
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: update firmware for MT7981
  * qca: Update firmware files for BT chip WCN6750
  * mt76xx: Move the old Mediatek WiFi firmware to mediatek
  * rtl_bt: Add firmware and config files for RTL8851B
  * linux-firmware: Update AMD cpu microcode
  * linux-firmware: add firmware for MT7981
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * linux-firmware: update qat firmware
  * linux-firmware: Add firmware for Cirrus CS35L41 on Lenovo Laptops
* Mon Apr 17 2023 tiwai@suse.com
- Update to version 20230406 (git commit 86da2ac9b4e5):
  * linux-firmware: update firmware for MT7916
  * rtw89: 8852b: update format-1 fw to v0.29.29.1
  * rtw89: 8852c: update fw to v0.27.56.13
  * ath11k: WCN6855 hw2.0: update board-2.bin
  * ath11k: WCN6750 hw1.0: update to WLAN.MSL.1.0.1-01160-QCAMSLSWPLZ-1
  * ath11k: QCN9074 hw1.0: update to WLAN.HK.2.7.0.1-01744-QCAHKSWPL_SILICONZ-1
  * ath11k: IPQ8074 hw2.0: update to WLAN.HK.2.7.0.1-01744-QCAHKSWPL_SILICONZ-1
  * ath11k: IPQ8074 hw2.0: update board-2.bin
  * ath11k: IPQ6018 hw1.0: update to WLAN.HK.2.7.0.1-01744-QCAHKSWPL_SILICONZ-1
  * ath11k: IPQ6018 hw1.0: update board-2.bin
  * ath10k: QCA99X0 hw2.0: update board-2.bin
  * ath10k: QCA9984 hw1.0: update board-2.bin
  * ath10k: QCA9888 hw2.0: update board-2.bin
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * nvidia: update Tu10x and Tu11x signed firmware to support newer Turing HW
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: Amphion: Update vpu firmware
  * iwlwifi: add new FWs from core78-32 release
  * iwlwifi: update 9000-family firmwares to core78-32
  * amdgpu: Update SDMA 6.0.1 firmware
  * amdgpu: Add PSP 13.0.11 firmware
  * amdgpu: Update PSP 13.0.4 firmware
  * amdgpu: Update GC 11.0.1 firmware
  * amdgpu: Update DCN 3.1.4 firmware
  * amdgpu: Add GC 11.0.4 firmware
  * rtw88: 8822c: Update normal firmware to v9.9.15
* Fri Mar 24 2023 Takashi Iwai <tiwai@suse.com>
- Revive the old iwlwifi-*-71 ucode for compatibility with
  SLE15-SP4 kernel (bsc#1209681):
  WHENCE updated by iwlwifi-WHENCE-fix.patch
* Fri Mar 24 2023 tiwai@suse.com
- Update to version 20230320 (git commit bcdcfbcf0a8f):
  * linux-firmware: Update firmware file for Intel Bluetooth AX101
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX203
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: add firmware files for NXP BT chipsets
  * rtw89: 8852b: update format-1 fw to v0.29.29.0
  * rtw89: 8852b: add format-1 fw v0.29.26.0
  * rtw89: 8852b: rollback firmware to v0.27.32.1
  * i915: Update MTL DMC to v2.12
  * i915: Update ADLP DMC to v2.19
  * mediatek: Update mt8192/mt8195 SCP firmware to support MM21 and MT21
- Update topics list
- Drop the manual revert of 8852b firmware file, as it's merged into
  the upstream
* Tue Mar 21 2023 Takashi Iwai <tiwai@suse.com>
- Revert pssufix change that caused the package renaming and broke
  dependencies from other packages
* Mon Mar 20 2023 Takashi Iwai <tiwai@suse.com>
- Revert the broken rtw89/rtw8852b_fw.bin firmware temporarily
  (bsc#1209449)
* Tue Mar 14 2023 tiwai@suse.com
- Update to version 20230313 (git commit 5bc279fb161d):
  * iwlwifi: update core69 and core72 firmwares for So device
  * qat: update licence text
  * rtl_bt: Update RTL8822C BT USB firmware to 0x0CC6_D2E3
  * rtl_bt: Update RTL8822C BT UART firmware to 0x05C6_D2E3
  * WHENCE: remove duplicate File entries
  * WHENCE: remove trailing white space
  * linux-firmware: add fw for qat_4xxx (jsc#PED-3699)
  * Fix symlinks for Intel firmware
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * linux-firmware: update firmware for MT7921 WiFi device
  * iwlwifi: update core69 and core72 firmwares for Ty device
  * rtlwifi: Add firmware v16.0 for RTL8710BU aka RTL8188GU
  * brcm: Add nvram for the Lenovo Yoga Book X90F / X90L convertible
  * brcm: Fix Xiaomi Inc Mipad2 nvram/.txt file macaddr
  * brcm: Add nvram for the Advantech MICA-071 tablet
  * rtl_bt: Update RTL8852C BT USB firmware to 0xD7B8_FABF
  * rtl_bt: Add firmware and config files for RTL8821CS
  * rtw89: 8852b: update fw to v0.29.29.0
  * rtw89: 8852b: update fw to v0.29.26.0
  * liquidio: remove lio_23xx_vsw.bin
  * intel: avs: Add AudioDSP base firmware for CNL-based platforms
  * intel: avs: Add AudioDSP base firmware for APL-based platforms
  * intel: avs: Add AudioDSP base firmware for SKL-based platforms
  * ath11k: WCN6855 hw2.0: update to WLAN.HSP.1.1-03125-QCAHSPSWPL_V1_V2_SILICONZ_LITE-3.6510.23
  * ath11k: WCN6855 hw2.0: update board-2.bin
  * ath11k: WCN6750 hw1.0: update board-2.bin
  * ath11k: IPQ5018 hw1.0: add to WLAN.HK.2.6.0.1-00861-QCAHKSWPL_SILICONZ-1
  * ath11k: IPQ5018 hw1.0: add board-2.bin
  * ath10k: QCA6174 hw3.0: update firmware-sdio-6.bin to version WLAN.RMH.4.4.1-00174
  * ath10k: WCN3990 hw1.0: update board-2.bin
  * cnm: update chips&media wave521c firmware.
  * amdgpu: Update GC 11.0.1 firmware
  * intel: catpt: Add AudioDSP base firmware for BDW platforms
- Update topics for catpt/avs
- Update aliases
- Update spec template
* Tue Mar 14 2023 Dirk Müller <dmueller@suse.com>
- set psuffix to deduplicate src.rpms
- spec-cleaner induced cleanups
* Mon Feb 13 2023 tiwai@suse.com
- Update to version 20230210 (git commit bf4115c1aa2b):
  * linux-firmware: Update AMD cpu microcode
  * brcm: revert firmware files for Cypress devices
  * brcm: restore previous firmware file for BCM4329 device
  * rtw88: 8822c: Update normal firmware to v9.9.14
  * i915: Add DMC v2.11 for MTL (jsc#PED-1225)
  * linux-firmware: Add firmware for Cirrus CS35L41 on UM3402 ASUS Laptop
  * linux-firmware: Add missing tuning files for HP Laptops using Cirrus Amps (bsc#1203699)
  * i915: Add DMC v2.18 for ADLP (jsc#PED-1225)
* Mon Feb  6 2023 tiwai@suse.com
- Update to version 20230125 (git commit 5c11a3742947):
  (jsc#PED-1167, jsc#PED-1169, jsc#PED-1171)
  * amdgpu: Add VCN 4.0.2 firmware
  * amdgpu: Add PSP 13.0.4 firmware
  * amdgpu: Add SDMA 6.0.1 fimware
  * amdgpu: Add GC 11.0.1 firmware
  * amdgpu: Add DCN 3.1.4 firmware
  * iwlwifi: remove old intermediate 5.15+ firmwares
  * iwlwifi: remove 5.10 and 5.15 intermediate old firmwares
  * iwlwifi: remove 5.4 and 5.10 intermediate old firmwares
  * iwlwifi: remove 4.19 and 5.4 intermediate old firmwares
  * iwlwifi: remove old unsupported older than 4.14 LTS
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * amdgpu: update vangogh firmware
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * brcm: add configuration files for CyberTan WC121
  * qcom: add firmware files for Adreno A200
  * rtw89: 8852c: update fw to v0.27.56.10
  * QCA: Add Bluetooth firmware for QCA2066
* Wed Jan 18 2023 Takashi Iwai <tiwai@suse.com>
- Correct alias list for ACPI entries (bsc#1207211)
* Thu Jan 12 2023 tiwai@suse.com
- Update to version 20230110 (git commit a1ad1d5b5062):
  (preparation for jsc#PED-1167, jsc#PED-1169, jsc#PED-1171)
  * amdgpu: add VCN4.0.4 firmware from amd-5.4
  * amdgpu: add SMU13.0.7 firmware from amd-5.4
  * amdgpu: add SDMA6.0.2 firmware from amd-5.4
  * amdgpu: add PSP13.0.7 firmware from amd-5.4
  * amdgpu: add GC11.0.2 firmware from amd-5.4
  * amdgpu: add DCN3.2.1 firmware from amd-5.4
  * amdgpu: update VCN4.0.0 firmware from amd-5.4
  * amdgpu: update SMU13.0.0 firmware from amd-5.4
  * amdgpu: update SDMA6.0.0 firmware from amd-5.4
  * amdgpu: update PSP13.0.0 firmware from amd-5.4
  * amdgpu: update GC11.0.0 firmware from amd-5.4
  * iwlwifi: add new FWs from core76-35 release
  * iwlwifi: update cc/Qu/QuZ firmwares for core76-35 release
  * iwlwifi: add new FWs from core75-47 release
  * iwlwifi: update 9000-family firmwares to core75-47
  * amdgpu: update renoir DMCUB firmware
  * amdgpu: Update renoir PSP firmware
  * amdgpu: update copyright date for LICENSE.amdgpu
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * cxgb4: Update firmware to revision 1.27.1.0
  * qca: Update firmware files for BT chip WCN6750
* Wed Dec 28 2022 tiwai@suse.com
- Update to version 20221216 (git commit c9c19583f717):
  * rtw89: 8852c: update fw to v0.27.56.9
  * rtw89: 8852c: update fw to v0.27.56.8
  * amdgpu: updated navi10 firmware for amd-5.4
  * amdgpu: updated yellow carp firmware for amd-5.4
  * amdgpu: updated raven2 firmware for amd-5.4
  * amdgpu: updated raven firmware for amd-5.4
  * amdgpu: updated PSP 13.0.8 firmware for amd-5.4
  * amdgpu: updated GC 10.3.7 RLC firmware for amd-5.4
  * amdgpu: updated vega20 firmware for amd-5.4
  * amdgpu: updated PSP 13.0.5 firmware for amd-5.4
  * amdgpu: add VCN 4.0.0 firmware for amd-5.4
  * amdgpu: add SMU 13.0.0 firmware for amd-5.4
  * amdgpu: Add SDMA 6.0.0 firmware for amd-5.4
  * amdgpu: add PSP 13.0.0 firmware for amd-5.4
  * amdgpu: add GC 11.0.0 firmware for amd-5.4
  * amdgpu: add DCN 3.2.0 firmware for amd-5.4
  * amdgpu: updated vega10 firmware for amd-5.4
  * amdgpu: updated beige goby firmware for amd-5.4
  * amdgpu: updated dimgrey cavefish firmware for amd-5.4
  * amdgpu: updated vangogh firmware for amd-5.4
  * amdgpu: updated picasso firmware for amd-5.4
  * amdgpu: updated navy flounder firmware for amd-5.4
  * amdgpu: updated green sardine firmware for amd-5.4
  * amdgpu: updated sienna cichlid firmware for amd-5.4
  * amdgpu: updated arcture firmware for amd-5.4
  * amdgpu: updated navi14 firmware for amd-5.4
  * amdgpu: updated renoir firmware for amd-5.4
  * amdgpu: updated navi12 firmware for amd-5.4
  * amdgpu: updated aldebaran firmware for amd-5.4
  * sr150 : Add NXP SR150 UWB firmware
  * brcm: add/update firmware files for brcmfmac driver
  * rtl_bt: Update RTL8821C BT(USB I/F) FW to 0x75b8_f098
* Wed Nov 30 2022 tiwai@suse.com
- Update to version 20221130 (git commit 80ed874a4566):
  * amdgpu: update sdma_5.2.7 firmware
  * QCA: Add Bluetooth firmware for WCN785x This commit will add required Bluetooth firmware files for QCA WCN785x. The image version is 2.0.0-00515.
  * linux-firmware: update firmware for MT7916
  * linux-firmware: update firmware for MT7915
  * i915: Add DMC v2.08 for DG2
  * amdgpu: update green sardine DMCUB firmware
  * i915: Add DMC v2.10 for MTL
  * linux-firmware: update firmware for MT7986
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * linux-firmware: update firmware for MT7921 WiFi device
- Update constraints for 8GB (bsc#1205811)
* Mon Nov 14 2022 tiwai@suse.com
- Update to version 20221109 (git commit 60310c2deb8c):
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * amdgpu: update DMCUB firmware for DCN 3.1.6
  * rtl_bt: Update RTL8822C BT UART firmware to 0xFFB8_ABD6
  * rtl_bt: Update RTL8822C BT USB firmware to 0xFFB8_ABD3
  * WHENCE: mrvl: prestera: Add WHENCE entries for newly updated 4.1 FW images
  * mrvl: prestera: Update Marvell Prestera Switchdev FW to v4.1
  * iwlwifi: add new FWs from core74_pv-60 release
  * qcom: drop split a530_zap firmware file
  * qcom/vpu-1.0: drop split firmware in favour of the mbn file
  * qcom/venus-4.2: drop split firmware in favour of the mbn file
  * qcom/venus-4.2: replace split firmware with the mbn file
  * qcom/venus-1.8: replace split firmware with the mbn file
* Fri Nov  4 2022 tiwai@suse.com
- Update to version 20221031 (git commit 8bb75626e9dd):
  * linux-firmware: Add firmware for Cirrus CS35L41 on new ASUS Laptop
  * iwlwifi: add new PNVM binaries from core74-44 release
  * iwlwifi: add new FWs from core69-81 release
  * qcom: update venus firmware files for VPU-2.0
  * qcom: remove split SC7280 venus firmware images
  * qcom: update venus firmware file for v5.4
  * qcom: replace split SC7180 venus firmware images with symlink
  * rtw89: 8852b: update fw to v0.27.32.1
  * rtlwifi: update firmware for rtl8192eu to v35.7
  * rtlwifi: Add firmware v4.0 for RTL8188FU
  * i915: Add HuC 7.10.3 for DG2
  * linux-firmware: Add firmware for Cirrus CS35L41 on ASUS Laptops
  * linux-firmware: Add firmware for Cirrus CS35L41 on Lenovo Laptops
  * linux-firmware: Add firmware for Cirrus CS35L41 on HP Laptops
- Drop the CS35L41 firmware tarball that has been merged
- Drop obsoleted cirrus-WHENCE-update.patch
* Sat Oct 22 2022 tiwai@suse.com
- Update to version 20221017 (git commit 48407ffd7adb):
  * cnm: update chips&media wave521c firmware.
  * brcm: add symlink for Pi Zero 2 W NVRAM file
  * rtw89: 8852b: add initial fw v0.27.32.0
  * iwlwifi: add new FWs from core72-129 release
  * iwlwifi: update 9000-family firmwares to core72-129
  * rtl_bt: Update RTL8852C BT USB firmware to 0xD5B8_A40A
  * amdgpu: update GC 10.3.6 RLC firmware
  * amdgpu: update GC 10.3.7 RLC firmware
  * amdgpu: update Yellow Carp RLC firmware
  * amdgpu: update Beige Goby RLC firmware
  * amdgpu: update Dimgrey Cavefish RLC firmware
  * amdgpu: update Navy Flounder RLC firmware
  * amdgpu: update Sienna Cichlid RLC firmware
  * mediatek: Update mt8195 SOF firmware to v0.4.1
  * qcom: add squashed version of a530 zap shader
  * rtw89: 8852c: update fw to v0.27.56.1
  * rtw89: 8852c: update fw to v0.27.56.0
  * mediatek: Update mt8186 SCP firmware
- Update Cirrus CS35L41 firmware (bsc#1203699)
  cirrus-WHENCE-update.patch
- Update aliases from 6.1-rc1 kernel
* Mon Oct 10 2022 Takashi Iwai <tiwai@suse.com>
- Apply the same workaround to uncompressed flat package, too
  (bsc#1204103)
* Sat Oct  8 2022 Takashi Iwai <tiwai@suse.com>
- Workaround for update failure of kernel-firmware-qcom package
  due to the change from a directory to a symlink (bsc#1204103)
* Mon Oct  3 2022 tiwai@suse.com
- Update to version 20220930 (git commit fdf1a6525852):
  * linux-firmware: Update AMD cpu microcode
  * mediatek: mt8195: Update scp.img to v2.0.11956
  * mediatek: Add new mt8195 SOF firmware
  * mediatek: Update mt8186 SOF firmware to v0.2.1
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * rtl_bt: Update RTL8852A BT USB firmware to 0xD9B8_8207
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for MT7921 WiFi device
  * cxgb4: Update firmware to revision 1.27.0.0 (jsc#PED-1501)
  * i915: Add versionless HuC files for current platforms
  * i915: Add GuC v70.5.1 for DG1, DG2, TGL and ADL-P
  * qca: Update firmware files for BT chip WCN3991.
  * Removing crnv32
  * amdgpu: update yellow carp DMCUB firmware
  * amdgpu: add firmware for VCN 3.1.2 IP block
  * amdgpu: add firmware for SDMA 5.2.6 IP block
  * amdgpu: add firmware for PSP 13.0.5 IP block
  * amdgpu: add firmware for GC 10.3.6 IP block
  * amdgpu: add firmware for DCN 3.1.5 IP block
  * qcom: rename Lenovo ThinkPad X13s firmware paths
  * rtw89: 8852c: update fw to v0.27.42.0
  * rtw89: 8852c: update fw to v0.27.36.0
- Fix install-split.sh for dealing with a symlink of directory
* Tue Sep  6 2022 tiwai@suse.com
- Update to version 20220902 (git commit 2f2f0181581d):
  * Mellanox: Add new mlxsw_spectrum firmware xx.2010.3146
  * amdgpu: update beige goby VCN firmware
  * amdgpu: update dimgrey cavefish VCN firmware
  * amdgpu: update navy flounder VCN firmware
  * amdgpu: update sienna cichlid VCN firmware (bsc#1202707)
  * rtl_bt: Update RTL8852C BT USB firmware to 0xDFB8_5A33
  * mediatek: reference the LICENCE file for MediaTek firmwares
  * mediatek: Add new mt8186 SOF firmware
  * ice: Update package to 1.3.30.0
  * QCA: Update Bluetooth WCN685x 2.1 firmware to 2.1.0-00438
  * brcm: Add nvram for Lenovo Yoga Tablet 2 830F/L and 1050F/L tablets
  * brcm: Add nvram for the Xiaomi Mi Pad 2 tablet
  * brcm: Add nvram for the Asus TF103C tablet
  * Add amd-ucode README file
  * qca: Update firmware files for BT chip WCN6750.      This commit will update required firmware files for WCN6750.
  * amdgpu: Update Yellow Carp VCN firmware
  * qcom: Add firmware for Lenovo ThinkPad X13s
- Update aliases from 6.0-rc
- Update topics list for mtk-sof
* Fri Aug  5 2022 tiwai@suse.com
- Update to version 20220804 (git commit e6185d5197fd):
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * Mellanox: Add new mlxsw_spectrum firmware xx.2010.3020
  * linux-firmware: Add firmware for Cirrus CS35L41
  * i915: Add GuC v70.4.1 for DG2
  * i915: Add DMC v2.07 for DG2
  * amdgpu partially revert "amdgpu: update beige goby to release 22.20"
  * mediatek: Update mt8183/mt8192/mt8195 SCP firmware
  * amdgpu: update renoir to release 22.20
  * amdgpu: update beige goby to release 22.20
  * amdgpu: update yellow carp to release 22.20
  * amdgpu: update dimgrey cavefish to release 22.20
  * amdgpu: update vega20 to release 22.20
  * amdgpu: update vega12 to release 22.20
  * amdgpu: update raven to release 22.20
  * amdgpu: update navy flounder to release 22.20
  * amdgpu: update vega10 to release 22.20
  * amdgpu: update sienna cichlid to release 22.20
  * amdgpu: update navi14 to release 22.20
  * amdgpu: update green sardine to release 22.20
  * amdgpu: update vangogh to release 22.20
  * amdgpu: update navi12 to release 22.20
  * amdgpu: update navi10 to release 22.20
  * amdgpu: update picasso to release 22.20
  * amdgpu: update aldebaran to release 22.20
  * amdgpu: update psp 13.0.8 TA firmware
  * WHENCE: Fix the dangling symlinks fix
- Revert the previous rtw88/rtw8822c_fw.bin change due to regression
  on HP Pavilion 15 (bsc#1202152)
- Update alias from 5.19
* Mon Jul 18 2022 tiwai@suse.com
- Update to version 20220714 (git commit 84661a3ba62f):
  * amdgpu: update DMCUB firmware for DCN 3.1.6
  * WHENCE: Correct dangling symlinks
  * Correct WHENCE entry for wfx firmware
  * bnx2: Drop unsupported Broadcom NetXtremeII firmware
  * bnx2: drop unsupported firmwares
  * bnx2: sort firmware names in filesystem order
  * Remove old Broadcom Everest (bnx2x) v4/5 firmware
  * drop Token Ring network firmwares
  * Drop TDA7706 radio firmware
  * Drop Intel WiMax firmware
  * Drop Computone IntelliPort Plus serial firmware
  * Drop ATM Ambassador devices firmware
  * brocade: drop old unsupported firmware revs
  * amdgpu: update yellow carp DMCUB firmware
  * linux-firmware: update firmware for MT7622 WiFi device
  * linux-firmware: update firmware for MT7922 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * mediatek: Add SCP firmware for MT8186
  * rtw88: 8822c: Update normal firmware to v9.9.13
  * rtw88: 8822c: Update normal firmware to v9.9.12
- Drop obsoleted temporary patches:
  wfx-WHENCE-fix.diff
  brcm-symlink-fixes.diff
- Minor update of README.build
- Fix missing aliases for qlogic (bsc#1200889)
* Mon Jul  4 2022 tiwai@suse.com
- Update to version 20220622 (git commit 9ed4d42c51ac):
  * amdgpu: update Yellow Carp VCN firmware
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * qed: update 8.59.1.0 firmware
  * Link some devices that ship with the AW-CM256SM
  * Add initial AzureWave AW-CM256SM NVRAM file
  * Remove the Pine64 Quartz copy of the RPi NVRAM
  * qca: Update firmware files for BT chip WCN6750.
  * QCA: Update Bluetooth WCN685x 2.1 firmware to 2.1.0-00409
  * WHENCE: add symlinks for StarFive based boards
  * linux-firmware: wilc1000: update WILC1000 firmware to v15.6
  * brcm: Add NVRAM file 43455 based Wifi/BT module as used on the Quartz64 Model B from Pine64. This file is based on the existing "brcm/brcmfmac43455-sdio.raspberrypi,4-model-b.txt" NVRAM file.
  * iwlwifi: add new FWs from core70-87 release
  * iwlwifi: update 9000-family firmwares to core70-87
- Temporary fix for incorrect symlinks for brcm in WHENCE:
  brcm-symlink-fixes.diff
- Minor updates of scripts, sorting alphabetically and add version
  to Provides/Obsoletes
- Update alias
* Wed Jun  8 2022 tiwai@suse.com
- Update to version 20220607 (git commit 02c69863c885):
  * rtl_bt: Update RTL8852A BT USB firmware to 0xDFB8_0634
  * Makefile: replace mkdir by install
  * iwlwifi: remove old unsupported 3160/7260/7265/8000/8265 firmware
  * ath11k: WCN6855 hw2.0: update to WLAN.HSP.1.1-03125-QCAHSPSWPL_V1_V2_SILICONZ_LITE-3.6510.9
  * WHENCE: ath11k: move regdb.bin before board-2.bin
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.9.0.2-00157
  * ath10k: QCA9888 hw2.0: update board-2.bin
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.9.0.2-00157
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * ath10k: WCN3990 hw1.0: add board-2.bin
- Update aliases from 5.19-rc1
- Minor adjustment of spec template and makespec.sh to align with
  the latest TW format
* Tue May 17 2022 tiwai@suse.com
- Update to version 20220516 (git commit 251d29004ffc):
  * amdgpu: update beige goby firmware for 22.10
  * amdgpu: update renoir firmware for 22.10
  * amdgpu: update dimgrey cavefish firmware for 22.10
  * amdgpu: update vega20 firmware for 22.10
  * amdgpu: update yellow carp firmware for 22.10
  * amdgpu: update vega12 firmware for 22.10
  * amdgpu: update navy flounder firmware for 22.10
  * amdgpu: update vega10 firmware for 22.10
  * amdgpu: update raven2 firmware for 22.10
  * amdgpu: update raven firmware for 22.10
  * amdgpu: update sienna cichlid firmware for 22.10
  * amdgpu: update green sardine firmware for 22.10
  * amdgpu: update PCO firmware for 22.10
  * amdgpu: update vangogh firmware for 22.10
  * amdgpu: update navi14 firmware for 22.10
  * amdgpu: update navi12 firmware for 22.10
  * amdgpu: update navi10 firmware for 22.10
  * amdgpu: update aldebaran firmware for 22.10
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * mediatek: Update mt8192 SCP firmware
* Wed May 11 2022 tiwai@suse.com
- Update to version 20220509 (git commit b19cbdca78ab):
  * mediatek: Update mt8183 SCP firmware
  * ice: Update package to 1.3.28.0
  * i915: Add DMC v2.06 for DG2
  * rtl_bt: Update RTL8852A BT USB firmware to 0xDBB7_C1D9
  * amdgpu: update psp_13_0_8 firmware
  * amdgpu: update gc_10_3_7_rlc firmware
  * amdgpu: update dcn_3_1_6_dmcub firmware
  * ath11k: QCA6390 hw2.0: update to WLAN.HST.1.0.1-05266-QCAHSTSWPLZ_V2_TO_X86-1
  * qcom: add firmware files for Adreno a420 & related generations
  * qcom: add firmware files for Adreno a330
  * qcom: add firmware files for Adreno a220
  * i915: Add GuC v70.1.2 for DG2
  * rtw89: 8852c: add new firmware v0.27.20.0 for RTL8852C
  * Mellanox: Add lc_ini_bundle for xx.2010.1006
  * Mellanox: xx.2010.1502: Distribute non-xz-compressed lc_ini_bundle
  * ath10k: QCA9984 hw1.0: update board-2.bin
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.9.0.2-00156
  * ath10k: QCA9888 hw2.0: update board-2.bin
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.9.0.2-00156
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to WLAN.RM.4.4.1-00288-QCARMSWPZ-1
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * ath10k: QCA99X0 hw2.0: add board-2.bin
  * ath11k: WCN6855 hw2.0: update to WLAN.HSP.1.1-03125-QCAHSPSWPL_V1_V2_SILICONZ_LITE-3.6510.7
  * ath11k: WCN6750 hw1.0: add to WLAN.MSL.1.0.1-00887-QCAMSLSWPLZ-1
  * ath11k: WCN6750 hw1.0: add board-2.bin
  * ath11k: QCN9074 hw1.0: add to WLAN.HK.2.5.0.1-01208-QCAHKSWPL_SILICONZ-1
  * ath11k: QCN9074 hw1.0: add board-2.bin
  * ath11k: QCA6390 hw2.0: update board-2.bin
  * ath11k: IPQ8074 hw2.0: update to WLAN.HK.2.5.0.1-01208-QCAHKSWPL_SILICONZ-1
  * ath11k: IPQ8074 hw2.0: update board-2.bin
  * ath11k: IPQ6018 hw1.0: update to WLAN.HK.2.5.0.1-01208-QCAHKSWPL_SILICONZ-1
  * ath11k: IPQ6018 hw1.0: update board-2.bin
  * Mellanox: Add new mlxsw_spectrum firmware xx.2010.1502
  * amdgpu: update yellow carp DMCUB firmware
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7922)
  * linux-firmware: update firmware for MT7922 WiFi device
  * mediatek: Add mt8195 SCP firmware
  * qcom: apq8096: add modem firmware
  * qcom: apq8096: add aDSP firmware
  * rtl_bt: Add firmware and config files for RTL8852C
  * i915: Add GuC v70.1.1 for all platforms
- Update aliases
* Mon Apr 11 2022 tiwai@suse.com
- Update to version 20220411 (git commit f219d616f42b):
  * mediatek: Add mt8192 SCP firmware
  * linux-firmware: Update AMD cpu microcode
    (CVE-2021-26339, CVE-2021-26373, CVE-2021-26347, CVE-2021-26376,
    CVE-2021-26375, CVE-2021-26378, CVE-2021-26372, CVE-2021-26339,
    CVE-2021-26348, CVE-2021-26342, CVE-2021-26388, CVE-2021-26349,
    CVE-2021-26364, CVE-2021-26312, CVE-2021-26350, bsc#1199459)
  * nvidia: add GA102/GA103/GA104/GA106/GA107 signed firmware
  * brcm: rename Rock960 NVRAM to AP6356S and link devices to it
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * amdgpu: update green sardine VCN firmware
  * amdgpu: update renoir VCN firmware
  * amdgpu: update navi14 VCN firmware
  * amdgpu: update navi12 VCN firmware
  * amdgpu: update navi10 VCN firmware
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * rtw88: 8821c: Update normal firmware to v24.11.00
  * ice: Add wireless edge file for Intel E800 series driver
  * ice: update ice DDP comms package to 1.3.31.0
  * amdgpu: update PSP 13.0.8 firmware
  * amdgpu: update GC 10.3.7 firmware
  * rtl_bt: Add firmware and config files for RTL8852B
- Update aliases
* Tue Mar 15 2022 tiwai@suse.com
- Update to version 20220309 (git commit cd01f857da28):
  * iwlwifi: add new FWs from core68-60 release
  * ath11k: add links for WCN6855 hw2.1
  * ath11k: WCN6855 hw2.0: add WLAN.HSP.1.1-03125-QCAHSPSWPL_V1_V2_SILICONZ_LITE-3
  * ath11k: WCN6855 hw2.0: add board-2.bin and regdb.bin
  * ath10k/ath11k: mark notice.txt as "File:"
  * linux-firmware: add firmware for MT7986
  * amdgpu: add firmware for SDMA 5.2.7 IP block
  * amdgpu: add firmware for PSP 13.0.8 IP block
  * amdgpu: add firmware for DCN 3.1.6 IP block
  * amdgpu: add firmware for GC 10.3.7 IP block
  * rtw89: 8852a: update fw to v0.13.36.0
  * iwlwifi: update 9000-family firmwares to core68-60
  * amdgpu: update raven2 VCN firmware
  * amdgpu: update raven VCN firmware
  * amdgpu: update picasso VCN firmware
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update AMD SEV firmware
    (CVE-2021-46744, CVE-2021-26339, bsc#1199470, bsc#1199459)
  * rtw89: 8852a: update fw to v0.13.35.0
* Mon Feb 28 2022 tiwai@suse.com
- Update to version 20220224 (git commit 9cab94f59b23):
  * Mellanox: Add new mlxsw_spectrum firmware xx.2010.1406
  * wfx: update to firmware 3.14
  * wfx: add antenna configuration files
  * wfx: rename silabs/ into wfx/
  * linux-firmware: update firmware for mediatek bluetooth chip(MT7921)
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
  * linux-firmware: Intel BT 7265: Fix Security Issues
    (CVE-2021-33139,CVE-2021-33155,INTEL-SA-00604,bsc#1195786)
- Update license.txt for wfx
- Temporary fix for WHENCE for wfx:
  wfx-WHENCE-fix.diff
* Sun Feb 20 2022 tiwai@suse.com
- Update to version 20220218 (git commit c53073d4e148):
  * rtl_bt: Update RTL8852A BT USB firmware to 0xDFB7_6D7A
  * rtl_bt: Update RTL8822C BT USB firmware to 0x19B7_6D7D
  * rtl_bt: Update RTL8822C BT UART firmware to 0x15B7_6D7D
  * amdgpu: Update yellow carp firmware from 21.50
  * amdgpu: Update vega20 firmware from 21.50
  * amdgpu: Update vega12 firmware from 21.50
  * amdgpu: Update vega10 firmware from 21.50
  * amdgpu: Update vangogh firmware from 21.50
  * amdgpu: Update renoir firmware from 21.50
  * amdgpu: Update raven2 firmware from 21.50
  * amdgpu: Update raven firmware from 21.50
  * amdgpu: Update picasso firmware from 21.50
  * amdgpu: Update beige goby firmware from 21.50
  * amdgpu: Update dimgrey cavefish firmware from 21.50
  * amdgpu: Update navy flounder firmware from 21.50
  * amdgpu: Update sienna cichlid firmware from 21.50
  * amdgpu: Update navi14 firmware from 21.50
  * amdgpu: Update navi12 firmware from 21.50
  * amdgpu: Update navi10 firmware from 21.50
  * amdgpu: Update cyan skillfish2 firmware from 21.50
  * amdgpu: Update green sardine firmware from 21.50
  * amdgpu: Update arcturus firmware from 21.50
  * amdgpu: Add aldebaran firmware from 21.50
  * LICENSE.amdgpu: update copyright date
  * linux-firmware: Update AMD cpu microcode
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: Amphion: Add VPU firmwares for NXP i.MX8Q SoCs
  * i915: Add DMC firmware v2.16 for ADL-P
  * linux-firmware: mediatek: Update MT8173 VPU firmware to v1.1.7
- Add entry for amphion
- Update spec template
- Update aliases
* Wed Jan 19 2022 tiwai@suse.com
- Update to version 20220119 (git commit 0c6a7b3bf728):
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: update firmware for mediatek bluetooth chip(MT7921)
  * linux-firmware: update firmware for MT7921 WiFi device
  * Mellanox: Add new mlxsw_spectrum firmware xx.2010.1232
  * linux-firmware: add marvell CPT firmware images
  * QCA: Add Bluetooth nvm file for WCN685x
  * QCA: Update Bluetooth WCN685x 2.1 firmware to 2.1.0-00324
  * QCA: Update Bluetooth WCN685x 2.0 firmware to 2.0.0-00609
  * i915: Add GuC v69.0.3 for all platforms
- Add entry for rvu_cptpf
* Thu Jan 13 2022 tiwai@suse.com
- Update to version 20220111 (git commit 13dca280f760):
  * linux-firmware: update firmware for MT7915
  * iwlwifi: add new FWs from core63-136 release
  * iwlwifi: add new FWs from core66-88 release
  * iwlwifi: update 9000-family firmwares to core66-88
  * linux-firmware: add firmware for MT7916
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * WHENCE: add missing symlink for NanoPi R1
  * amdgpu: update yellow carp dmcub firmware
  * cxgb4: Update firmware to revision 1.26.6.0
- update aliases from 5.16 final
* Wed Jan  5 2022 tiwai@suse.com
- Update to version 20211229 (git commit 57d6b9507e28):
  * cnm: add chips&media wave521c firmware.
  * linux-firmware: update firmware for MT7921 WiFi device
  * linux-firmware: update firmware for mediatek bluetooth chip (MT7921)
  * rtw88: 8822c: Update normal firmware to v9.9.11
  * QCA: Update Bluetooth WCN685x firmware to 2.1.0-00298
  * amdgpu: update green sardine PSP firmware
  * bnx2x: Add FW 7.13.21.0
  * linux-firmware: update frimware for mediatek bluetooth chip (MT7921)
  * linux-firmware: wilc1000: update WILC1000 firmware to v15.4.1
  * rtl_bt: Update RTL8761B BT UART firmware to 0x0CA9_8A6B
  * rtl_bt: Update RTL8761B BT USB firmware to 0x09A9_8A6B
  * cxgb4: Update firmware to revision 1.26.4.0
  * rtw89: 8852a: update fw to v0.13.33.0
  * i915: Add DMC firmware v2.14 for ADL-P
  * QCA: Add Bluetooth default nvm file for WCN685x
* Wed Dec  1 2021 tiwai@suse.com
- Update to version 20211123 (git commit b0e898fbaf37):
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * amdgpu: update yellow carp dmcub firmware
  * amdgpu: update vangogh DMCUB firmware
  * Update ath10k/QCA6174/hw3.0/board-2.bin
  * mrvl: prestera: Update Marvell Prestera Switchdev v4.0
  * QCA: Add Bluetooth firmware for WCN685x
- Fix the script to adapt ZSTD compressed modules (jsc#SLE-21256)
- Update _service to follow branch main instead
- Update aliases
* Tue Nov 16 2021 tiwai@suse.com
- Update to version 20211115 (git commit f5d519563ac9):
  * linux-firmware: Update AMD cpu microcode
  * amdgpu: update raven2 firmware from 21.40
  * amdgpu: update navi14 firmware from 21.40
  * amdgpu: update raven firmware from 21.40
  * amdgpu: update navi12 firmware from 21.40
  * amdgpu: update navi10 firmware from 21.40
  * amdgpu: update vega20 firmware from 21.40
  * amdgpu: update vega12 firmware from 21.40
  * amdgpu: update vega10 firmware from 21.40
  * amdgpu: update picasso firmware from 21.40
  * amdgpu: update vangogh firmware from 21.40
  * amdgpu: update beige goby firmware from 21.40
  * amdgpu: add cyan skillfish firmware from 21.40
  * amdgpu: update dimgrey cavefish firmware from 21.40
  * amdgpu: update green sardine firmware from 21.40
  * amdgpu: update navy flounder firmware from 21.40
  * amdgpu: update renoir firmware from 21.40
  * amdgpu: update arcturus firmware from 21.40
  * amdgpu: update sienna cichlid firmware from 21.40
  * rtl_bt: Update RTL8852A BT USB firmware to 0xDBA9_6937
  * iwlwifi: add new FWs from core64-96 release
  * iwlwifi: update 9000-family firmwares to core64-96
  * amdgpu: update VCN firmware for green sardine
  * linux-firmware: update frimware for mediatek bluetooth chip (MT7921)
- Update aliases
* Wed Oct 27 2021 tiwai@suse.com
- Update to version 20211027 (git commit 1d00989a6596):
  * linux-firmware: Update AMD cpu microcode
  * QCA: Update Bluetooth firmware for WCN685x
  * bnx2x: Add FW 7.13.20.0
  * Mellanox: Add new mlxsw_spectrum firmware xx.2010.1006
  * linux-firmware: Update NXP Management Complex firmware to version 10.28.1
  * linux-firmware: update firmware for MT7921 WiFi device
  * rtw89: 8852a: update fw to v0.13.30.0
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
- Update topics and aliases for rtw88 and rtw89
* Thu Sep 30 2021 tiwai@suse.com
- Update to version 20210928 (git commit 7a30050592e2):
  * brcm: Add 43455 based AP6255 NVRAM for the ACEPC T8 Mini PC
  * linux-firmware: Update firmware file for Intel Bluetooth 9462
  * amdgpu: update VCN firmware for dimgrey cavefish
  * amdgpu: update VCN firmware for navy flounder
  * amdgpu: update VCN firmware for sienna cichlid
  * amdgpu: update VCN firmware for vangogh
  * amdgpu: update VCN firmware for renoir
  * amdgpu: update VCN firmware for picasso
  * amdgpu: update VCN firmware for raven2
  * amdgpu: update VCN firmware for raven
  * amdgpu: Add initial firmware for Beige Goby
  * cxgb4: Update firmware to revision 1.26.2.0
  * linux-firmware: update frimware for mediatek bluetooth chip (MT7921)
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * qed: Add firmware 8.59.1.0
  * linux-firmware: Update firmware file for Intel Bluetooth AX211
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
  * iwlwifi: add FWs for new So device types with multiple RF modules
  * amdgpu: add initial firmware for Yellow Carp
  * i915: Update ADLP DMC v2.12
  * linux-firmware: add frimware for mediatek bluetooth chip (MT7922)
  * linux-firmware: Update AMD SEV firmware (bsc#1186938)
  * Revert "iwlwifi: add FW for new So/Gf device type"
- Update aliases
* Thu Sep  2 2021 tiwai@suse.com
- Update to version 20210901 (git commit 6f5aada830d6):
  * linux-firmware: update frimware for mediatek bluetooth chip (MT7921)
  * rtl_bt: Update RTL8852A BT USB firmware to 0xD9A9_1D69
  * rtl_bt: Update RTL8822C BT UART firmware to 0x05A9_1A4A
  * rtl_bt: Update RTL8822C BT USB firmware to 0x09A9_1A4A
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.3326
  * iwlwifi: add FW for new So/Gf device type
  * rtl_bt: Update RTL8852A BT USB firmware to 0xD9A9_127B
  * rtl_nic: update firmware of RTL8153C
  * ice: update package file to 1.3.26.0
- Update aliases
* Mon Aug 16 2021 tiwai@suse.com
- Update to version 20210812 (git commit 24c4a85d8514):
  * amdgpu: revert back to older raven2 sdma firmware
  * amdgpu: revert back to older raven sdma firmware
  * amdgpu: revert back to older picasso sdma firmware
  * amdgpu: add initial vangogh support
  * amdgpu: update vega20 firmware from 21.30
  * amdgpu: update vega12 firmware from 21.30
  * amdgpu: update vega10 firmware from 21.30
  * amdgpu: update renoir firmware from 21.30
  * amdgpu: update raven2 firmware from 21.30
  * amdgpu: update raven firmware from 21.30
  * amdgpu: update polaris12 firmware from 21.30
  * amdgpu: update picasso firmware from 21.30
  * amdgpu: update dimgrey cavefish firmware from 21.30
  * amdgpu: update navy flounder firmware from 21.30
  * amdgpu: update sienna cichlid firmware from 21.30
  * amdgpu: update navi14 firmware from 21.30
  * amdgpu: update navi12 firmware from 21.30
  * amdgpu: update navi10 firmware from 21.30
  * amdgpu: update green sardine firmware from 21.30
  * amdgpu: update arcturus firmware from 21.30
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: update frimware for mediatek bluetooth chip (MT7921)
  * linux-firmware: add firmware for MT7922
  * QCA : Updated firmware files for WCN3991
  * i915: Add v2.03 DMC for RKL
  * i915: Add v2.12 DMC for TGL
  * qca: Add firmware files for BT chip WCN6750.
* Fri Jul 23 2021 tiwai@suse.com
- Update to version 20210719 (git commit 5de082d4d0f2):
  * iwlwifi: add ty firmware from Core63-43
- Reduce the LZMA2 dictionary size (bsc#1188662)
* Fri Jul 16 2021 tiwai@suse.com
- Update to version 20210716 (git commit b7c134f0d349):
  * linux-firmware: update NXP 8897/8997 firmware images
  * rtlwifi: de-dupe rtl8723b WiFi firmware
  * rtlwifi: de-dupe rtl8192e WiFi firmware
  * linux-firmware: update frimware for mediatek bluetooth chip (MT7921)
  * cxgb4: Update firmware to revision 1.26.0.0
  * firmware/i915/guc: Add HuC v7.9.3 for TGL & DG1
  * firmware/i915/guc: Add GuC v62.0.3 for ADL-P
  * firmware/i915/guc: Add GuC v62.0.0 for all platforms
- Make TW packages only installable on post-UsrMerge systems;
  the packages for Leap are found in OBS Kernel:stable:Backport repo,
  instead
- Update aliases from 5.14-rc1
* Wed Jul  7 2021 tiwai@suse.com
- Update to version 20210629 (git commit d79c26779d45):
  * amdgpu: update vcn firmware for green sardine for 21.20
  * amdgpu: update vcn firmware for renoir for 21.20
  * amdgpu: update vcn firmware for navi14 for 21.20
  * amdgpu: update vcn firmware for navi12 for 21.20
  * amdgpu: update vcn firmware for navi10 for 21.20
  * amdgpu: add initial dimgrey cavefish firmware from 21.20
  * amdgpu: update sienna cichlid firmware from 21.20
  * amdgpu: update vega20 firmware from 21.20
  * amdgpu: update Picasso firmware from 21.20
  * amdgpu: update navi14 firmware from 21.20
  * amdgpu: update green sardine firmware from 21.20
  * amdgpu: update vega12 firmware from 21.20
  * amdgpu: update navi12 firmware from 21.20
  * amdgpu: update vega10 firmware from 21.20
  * amdgpu: update renoir firmware from 21.20
  * amdgpu: update navi10 firmware from 21.20
  * amdgpu: update raven2 firmware from 21.20
  * amdgpu: update arcturus firmware from 21.20
  * amdgpu: update raven firmware from 21.20
  * amdgpu: update navy flounder firmware from 21.20
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * rtl_bt: Update RTL8852A BT USB firmware to 0xD9A8_A0CD
  * linux-firmware: update firmware for MT7921 WiFi device to 20210612122753
  * rtl_bt: Update RTL8822C BT(UART I/F) FW to 0x05A8_C6B4
  * QCA: Update Bluetooth firmware for QCA6174
- Add missing CA0132 firmware files into kernel-firmware-sound
  (boo#1187825)
- Update aliases
* Thu Jun 17 2021 tiwai@suse.com
- Update to version 20210609 (git commit 0f66b74b6267):
  * cypress: update firmware for cyw54591 pcie
  * cypress: update firmware for cyw4373 sdio
  * cypress: update firmware for cyw43570 pcie
  * cypress: update firmware for cyw4356 sdio
  * cypress: update firmware for cyw4354 sdio
  * cypress: update firmware for cyw43455 sdio
  * cypress: update firmware for cyw43430 sdio
  * cypress: update firmware for cyw43340 sdio
  * cypress: update firmware for cyw43012 sdio
  * rtl_bt: Add rtl8761bu firmware
  * rtl_bt: Add rtl8761b firmware
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.2946
  * mediatek: update MT7915 firmware to 20201105
  * rtl_bt: Update RTL8822C BT(UART I/F) FW to 0x05A8_A0CB
  * rtl_bt: Update RTL8822C BT(USB I/F) FW to 0x09A8_A0CB
  * linux-firmware: update firmware for MT7921 WiFi device
  * QCA: Add Bluetooth firmware for WCN685x
  * QCA: Update Bluetooth firmware for QCA6174
  * QCA: Update Bluetooth firmware for QCA6390
  * cxgb4: Update firmware to revision 1.25.6.0
* Wed May 26 2021 tiwai@suse.com
- Update to version 20210518 (git commit f8462923ed8f):
  * nvidia: fix symlinks for tu104/tu106 acr unload firmware
  * rtw88: 8822c: Update normal firmware to v9.9.10
  * iwlwifi: update 8000 family firmwares
  * iwlwifi: update 9000-family firmwares to core60-51
  * iwlwifi: add new FWs from core60-51 release
  * nvidia: Update Tegra194 XUSB firmware to v60.09
  * nvidia: Update Tegra186 XUSB firmware to v55.18
  * nvidia: Update Tegra210 XUSB firmware to v50.26
  * linux-firmware: update firmware for mhdp8546
- Update module aliases
* Fri May  7 2021 tiwai@suse.com
- Update to version 20210503 (git commit ecdfcf8e2ca1):
  * i915: Add ADL-P DMC Support
  * amdgpu: add new polaris 12 MC firmware
  * firmware: nvidia: Add VIC firmware for Tegra194
  * qcom: add gpu firmwares for sc7280
  * brcm: Add a link to enable khadas VIM2's WiFi
  * rtw89: 8852a: update fw to v0.13.8.0
  * rtl_bt: Update RTL8852A BT USB firmware to 0xD9A8_7893
  * qcom: Add venus firmware files for VPU-2.0
  * qcom: update venus firmware files for v5.4
- Move adreno and modem firmware into kernel-firmware-qcom
  subpackage
- Update license list and module aliases
* Thu Apr 29 2021 tiwai@suse.com
- Update to version 20210426 (git commit fa0efeff4894):
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Intel BT 7265: Fix Security Issues
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
  * mrvl: prestera: Add Marvell Prestera Switchdev firmware 3.0 version
  * rtw88: 8822c: Update normal firmware to v9.9.9
  * brcm: add missing symlink for Pi Zero W NVRAM file
  * amdgpu: update arcturus firmware from 21.10
  * amdgpu: update navy flounder firmware from 21.10
  * amdgpu: update sienna cichlid firmware from 21.10
  * amdgpu: update vega20 firmware from 21.10
  * amdgpu: update picasso firmware from 21.10
  * amdgpu: update navi14 firmware from 21.10
  * amdgpu: update green sardine firmware from 21.10
  * amdgpu: update vega12 firmware from 21.10
  * amdgpu: update navi12 firmware from 21.10
  * amdgpu: update vega10 firmware from 21.10
  * amdgpu: update renoir firmware from 21.10
  * amdgpu: update navi10 firmware from 21.10
  * amdgpu: update raven2 firmware from 21.10
  * amdgpu: update raven firmware from 21.10
  * rtl_nic: add new firmware for RTL8153 and RTL8156 series
* Mon Apr 19 2021 tiwai@suse.com
- Update to version 20210419 (git commit 940b7f42d45d):
  * cxgb4: Update firmware to revision 1.25.4.0
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.2438
  * brcm: Link CM4's WiFi firmware with DMI machine name.
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * amdgpu: update navi14 smc firmware
  * amdgpu: update navi10 SMC firmware
  * QCA: Update Bluetooth firmware for QCA6174
  * WHENCE: link to similar config file for rtl8821a support
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.14.A.6
  * amdgpu: add arcturus firmware
  * rtl_bt: Add rtl8723bs_config-OBDA0623.bin symlink
  * brcm: Add nvram for the Chuwi Hi8 (CWI509) tablet
  * brcm: Add nvram for the Predia Basic tablet
  * qcom: sm8250: update remoteproc firmware
  * qcom: update a650 firmware files
  * rtl_bt: Update RTL8822C BT(UART I/F) FW to 0x59A_76A3
  * amdgpu: update sienna cichlid firmware for 20.50
  * amdgpu: update vega20 firmware for 20.50
  * amdgpu: update picasso firmware for 20.50
  * amdgpu: update navi14 firmware for 20.50
  * amdgpu: update vega12 firmware for 20.50
  * amdgpu: update navi12 firmware for 20.50
  * amdgpu: update vega10 firmware for 20.50
  * amdgpu: update renoir firmware for 20.50
  * amdgpu: update navi10 firmware for 20.50
  * amdgpu: update raven2 firmware for 20.50
  * amdgpu: update raven firmware for 20.50
  * amdgpu: add initial support for navy flounder
- Update aliases
* Thu Mar 18 2021 tiwai@suse.com
- Update to version 20210315 (git commit 3568f962908c):
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * rtw88: 8822c: Update normal firmware to v9.9.6
  * iwlwifi: add new FWs from core59-66 release
  * iwlwifi: update 9000-family firmwares
  * iwlwifi: update 7265D firmware
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.2406
  * linux-firmware: add frimware for mediatek bluetooth chip (MT7921)
  * rtw89: 8852a: add firmware v0.9.12.2
  * WHENCE: add missing symlink for BananaPi M3
  * Add symlink for BananaPi M2 to brcmfmac43430-sdio config
  * brcm: Fix Raspberry Pi 4B NVRAM file
  * silabs: add new firmware for WF200
  * amdgpu: add initial firmware for green sardine
  * rtw88: RTL8822C: Update normal firmware to v9.9.5
- Drop obsoleted patch:
  Revert-brcm-rpi4-boardflags3-bit.patch
- Update topics and aliases
* Tue Feb 16 2021 tiwai@suse.de
- Correct the RPi4 brcm config to recover the WiFi breakage
  (bsc#1182320):
  Revert-brcm-rpi4-boardflags3-bit.patch
* Tue Feb  9 2021 tiwai@suse.com
- Update to version 20210208 (commit b79d2396bc63):
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.2304
  * linux-firmware: add firmware for MT7921
  * rtw88: RTL8821C: Update firmware to v24.8
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * i915: Add DMC v2.01 for ADL-S
  * i915: Add HuC v7.7.1 for DG1
  * i915: Add GuC v49.0.1 for DG1
  * qcom: Add venus firmware files for VPU-1.0
  * qcom: Add SM8250 Compute DSP firmware
  * qcom: Add SM8250 Audio DSP firmware
  * qcom: add firmware files for Adreno a650
* Wed Jan 27 2021 tiwai@suse.com
- Update to version 20210119 (git commit 05789708b79b):
  * brcm: Link RPi4's WiFi firmware with DMI machine name.
  * brcm: Add NVRAM for Vamrs 96boards Rock960
  * brcm: Update Raspberry Pi 3B+/4B NVRAM for downstream changes
  * cypress: Fix link direction
  * cypress: Link the new cypress firmware to the old brcm files
  * brcm: remove old brcm firmwares that have newer cypress variants
  * rtl_bt: Update RTL8822C BT(UART I/F) FW to 0x059A_25CB
  * rtl_bt: Update RTL8822C BT(USB I/F) FW to 0x099a_7253
  * rtl_bt: Add firmware and config files for RTL8852A BT USB chip
  * rtl_bt: Update RTL8821C BT(USB I/F) FW to 0x829a_7644
- Fix install-split.sh to deal with the quoted spaces
- Update aliases
* Mon Dec 28 2020 tiwai@suse.com
- Update to version 20201218 (git commit 646f159690e2):
  * make AP6212 in bananpi m2 plus/zero work
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: add firmware for Lontium LT9611UXC DSI to HDMI bridge
  * mediatek: update MT8173 VPU firmware to v1.1.6
  * QCA : Updated firmware files for WCN3991
- Remove the already upstreamed extrawhence entry
- Update topic entry for lt9611uxc
- Update aliases from 5.10.x kernels
* Tue Dec 15 2020 seife+obs@b1-systems.com
- add banana pi brcm wireless symlinks to extrawhence
* Thu Dec  3 2020 tiwai@suse.com
- Update to version 20201130 (git commit 7455a3606674):
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * linux-firmware: Update firmware file for Intel Bluetooth AX210
  * i915: Add GuC firmware v49.0.1 for all platforms
  * i915: Remove duplicate KBL DMC entry
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.2018
* Mon Nov 23 2020 tiwai@suse.de
- Fix build with older distros due to missing _firmwaredir
* Sun Nov 22 2020 tiwai@suse.com
- Update to version 20201120 (bc9cd0b7b0e9):
  including AMDGPU update (bsc#1179062) and ath11k addition (bsc#1178274)
  * linux-firmware: Update AMD SEV firmware
  * amdgpu: add sienna cichlid firmware for 20.45
  * amdgpu: update vega20 firmware for 20.45
  * amdgpu: update vega12 firmware for 20.45
  * amdgpu: update vega10 firmware for 20.45
  * amdgpu: update renoir firmware for 20.45
  * amdgpu: update navi14 firmware for 20.45
  * amdgpu: update navi12 firmware for 20.45
  * amdgpu: update navi10 firmware for 20.45
  * amdgpu: update raven2 firmware for 20.45
  * amdgpu: update raven firmware for 20.45
  * rtlwifi: v88.2 firmware files for RTL8192CU
  * rtw88: RTL8822C: Update firmware to v9.9.4
  * Revert "rtw88: RTL8822C: Update firmware to v9.9.4"
  * vpdma: Move firmware to ti directory
  * amdgpu: update picasso VCN firmware
  * amdgpu: update raven2 VCN firmware
  * amdgpu: update raven VCN firmware
  * rtw88: RTL8822C: Update firmware to v9.9.4
  * rtl_bt: Update RTL8822C BT(USB I/F) FW to 0x099A_281A
  * QCA: Update Bluetooth firmware for QCA6390
  * qcom : updated venus firmware files for v5.4
  * QCA : Fixed BT SSR due to command timeout / IO fatal error
  * ath11k: QCA6390 hw2.0: add to WLAN.HST.1.0.1-01740-QCAHSTSWPLZ_V2_TO_X86-1
  * ath11k: QCA6390 hw2.0: add board-2.bin
  * ath11k: IPQ8074 hw2.0: add to WLAN.HK.2.1.0.1-01238-QCAHKSWPL_SILICONZ-2
  * ath11k: IPQ8074 hw2.0: add board-2.bin
  * ath11k: IPQ6018 hw1.0: add to WLAN.HK.2.1.0.1-01238-QCAHKSWPL_SILICONZ-2
  * ath11k: IPQ6018 hw1.0: add board-2.bin
  * ath10k: QCA6174 hw3.0: add firmware-sdio-6.bin version WLAN.RMH.4.4.1-00077
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.9.0.2-00131
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.9.0.2-00131
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to WLAN.RM.4.4.1-00157-QCARMSWPZ-1
- ath11k is split into its own subpackage due to its size
- Update topics list and aliases accordingly
* Thu Oct 29 2020 tiwai@suse.com
- Update to version 20201023 (git commit dae4b4cd0841):
  * cypress: add Cypress firmware and clm_blob files
  * rtl_bt: Update RTL8821C BT FW to 0xAA6C_A99E
  * ath10k: add SDIO firmware for QCA9377 WiFi
  * ice: update package file to 1.3.16.0
  * mediatek: separate venc service thread
  * QCA : Updated firmware file for WCN3991
  * iwlwifi: update and add new FWs from core56-54 release
  * iwlwifi: update 3168, 7265D, 8000C and 8265 firmwares
  * i915: Add DG1 DMC v2.02
  * qcom : updated venus firmware files for v5.4
- Add _constraints to fix the build error (bsc#1178242)
* Mon Oct 19 2020 Ludwig Nussel <lnussel@suse.de>
- use %%_firmwaredir
* Mon Oct 12 2020 tiwai@suse.de
- Use fdupes -s (bsc#1177428);
  this seems fixing the mess up of hard-linked files by the package
  update
* Sun Oct 11 2020 tiwai@suse.de
- Fix symlink creations for split packages (bsc#1177554);
  also show the copy/link status verbosely at packge build
* Mon Oct  5 2020 tiwai@suse.de
- Placeholder for SLE15-SP3 package sync:
  bsc#1143331, bsc#1160204, bsc#1154395 bsc#1155307, jsc#SLE-8379
* Mon Oct  5 2020 tiwai@suse.com
- Update to version 20201005 (git commit 58d41d0facca):
  * ice: Add comms package file for Intel E800 series driver
  * copy-firmware: Always write Link: entries
  * amdgpu: update vega20 firmware for 20.40
  * amdgpu: update vega12 firmware for 20.40
  * amdgpu: update vega10 firmware for 20.40
  * amdgpu: update renoir firmware for 20.40
  * amdgpu: update raven2 firmware for 20.40
  * amdgpu: update raven firmware for 20.40
  * amdgpu: update picasso firmware for 20.40
  * amdgpu: update navi14 firmware for 20.40
  * amdgpu: update navi12 firmware for 20.40
  * amdgpu: update navi10 firmware for 20.40
  * linux-firmware: Add new VPDMA firmware 1b8.bin
  * QCA : Updated firmware files for WCN3991
- Drop the AMDGPU Picasso workaround (bsc#1174278)
* Thu Oct  1 2020 tiwai@suse.com
- Update to version 20200928 (git commit b78a66c909c7):
  * linux-firmware: Update firmware for Cadence MHDP8546 DP bridge
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265 (D1)
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.1312
  * linux-firmware: nvidia: move firmware symlinks to WHENCE
  * linux-firmware: move i915 firmware symlinks to WHENCE
  * linux-firmware: move iwlwifi-7265D-10.ucode symlink to WHENCE
  * linux-firmware: Update Marvell Switchdev firmware with ABI changes
* Fri Sep 25 2020 tiwai@suse.de
- Force bzip2 compression for compatibility (boo#1176981):
  for keeping the compatibility with older distros (like Leap 15.1)
  that can't deal with lzma-compressed rpm files
* Mon Sep 21 2020 tiwai@suse.com
- Update to version 20200916 (git commit 00a84c516078):
  * linux-firmware: Update AMD SEV firmware
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.1310
  * mediatek: update MT7915 firmware to 20200819
  * brcm: Fix a stale symlink for RPi3 model b+
  * qcom: Add updated a5xx and a6xx microcode
  * wl18xx: update firmware file 8.9.0.0.83
* Tue Sep  1 2020 tiwai@suse.com
- Update to version 20200827 (git commit 7a237c6ee2c7):
  * linux-firmware: mt7615: update firmware to 20200814 version
  * amdgpu: add navi12 firmware from 20.30
  * amdgpu: update navi10 firmware for 20.30
  * brcm: Add brcmfmac43455-sdio.raspberrypi,3-model-a-plus.txt symlink
  * rtl_bt: Update RTL8822C BT UART firmware to 0x0599_8A4F
  * i915: Add DMC firmware 2.02 for RKL
  * i915: Add DMC firmware 2.08 for TGL
  * i915: Add HuC firwmare v7.5.0 for TGL
* Tue Aug 11 2020 tiwai@suse.com
- Update to version 20200807 (git commit c331aa9c49ce):
  * amdgpu: update vega20 firmware for 20.30
  * amdgpu: update vega12 firmware for 20.30
  * amdgpu: update vega10 firmware for 20.30
  * amdgpu: update renoir firmware for 20.30
  * amdgpu: update raven2 firmware for 20.30
  * amdgpu: update raven firmware for 20.30
  * amdgpu: update picasso firmware for 20.30
  * amdgpu: update navi14 firmware for 20.30
  * amdgpu: update navi10 firmware for 20.30
  * linux-firmware: update NXP SDSD-8997 firmware image
  * Mellanox: Add new mlxsw_spectrum firmware xx.2008.1036
  * linux-firmware: Update AMD SEV firmware
  * QCA: Add correct bin file for WCN3991
- Still keep the revert of AMDGPU Picasso firmware due to the
  regression (bsc#1174278)
- Move a big prestera firmware file in platform subpackage into the
  own subpackage, kernel-firmware-prestera
- Update aliases from 5.8 kernel packages
* Sun Jul 19 2020 tiwai@suse.com
- Update to version 20200716 (git commit 1d1c80b69653):
  * Update to 20200629111339 version to aligh SDK. Mainly fix DFS false alarm.
  * rtl_nic: update firmware for RTL8125B
  * Update binary firmware for MT7663 based devices to include firmware offload feature and low power feature.
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: wilc1000: add wilc1000 v15.4 FW
  * QCA: Update Bluetooth firmware for QCA6390
- Revert the previous update of AMDGPU firmware due to regression
  (bsc#1174278); back to the state of 887d2a103c2b
* Mon Jul 13 2020 tiwai@suse.com
- Update to version 20200702 (git commit 74ac3b5a7e79):
  * amdgpu: add UVD firmware for SI asics
  * QCA: Update WCN3991 FW files
  * amdgpu: update renoir firmware from 20.20 release
  * amdgpu: update picasso firmware from 20.20 release
  * amdgpu: update raven2 firmware from 20.20 release
  * amdgpu: update raven firmware from 20.20 release
  * amdgpu: add vega20 TA firmware from 20.20 release
  * amdgpu: update vega20 firmware from 20.20 release
  * amdgpu: update vega12 firmware from 20.20 release
  * amdgpu: update vega10 firmware from 20.20 release
  * amdgpu: update navi10 firmware from 20.20 release
  * amdgpu: update navi14 firmware from 20.20 release
  * rtl_nic: add firmware for RTL8125B
* Mon Jun 15 2020 tiwai@suse.com
- Update to version 20200610 (git commit 887d2a103c2b):
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * Mellanox: Add new mlxsw_spectrum firmware xx.2007.1168
  * rtw88: RTL8822C: update firmware version to v9.9
  * cxgb4: Update firmware to revision 1.24.17.0
  * mrvl: add firmware for Prestera ASIC devices
- Update topics list for prestra f/w (maybe better to split to a
  new subpkg?)
- Update copyright notice in template
- Update aliases from 5.7 kernels
* Thu Jun  4 2020 Thorsten Kukuk <kukuk@suse.com>
- Don't require coreutils, only mkdir and touch are used
* Sat May 23 2020 tiwai@suse.com
- Update to version 20200519 (git commit 8ba6fa665c52):
  * iwlwifi: update and add new FWs from core50-70 and core52-81 releases
  * rtw88: RTL8821C: add firmware file v24.5
  * iwlwifi: update FWs to core47-142 release
  * iwlwifi: update 8265 FW
- Update modaliases for Intel SST
* Mon May 18 2020 tiwai@suse.com
- Update to version 20200517 (git commit f8d32e4cc99b):
  * rtw88: update firmware information and README
  * linux-firmware: add firmware for MT7915E
  * QCA: Add Bluetooth firmware for QCA9377
  * linux-firmware: add rebb firmware for mt7663
* Sat Apr 25 2020 tiwai@suse.com
- Update to version 20200424 (git commit b2cad6a2d733):
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * Use Link function for brcmfmac43362-sdio.lemaker,bananapro.txt
  * Add symlink for Dell XPS 15 9550 Broadcom Bluetooth patch-ram file
  * rtl_bt: Update RTL8822C BT FW to 0x0999_3AA1
  * cxgb4: Update T6 config file
  * amdgpu: update vega20 firmware for 20.10
  * amdgpu: update vega12 firmware for 20.10
  * amdgpu: update vega10 firmware for 20.10
  * amdgpu: update renoir firmware for 20.10
  * amdgpu: update raven2 firmware for 20.10
  * amdgpu: update raven firmware for 20.10
  * amdgpu: update picasso firmware for 20.10
  * amdgpu: update navi10 firmware for 20.10
  * amdgpu: update navi14 firmware for 20.10
  * amdgpu: add navi14 TA firmware from 20.10
  * cxgb4: Update firmware to revision 1.24.14.0
* Wed Apr 15 2020 tiwai@suse.de
- Update aliases per 5.6 and 5.7 kernels
* Tue Apr 14 2020 tiwai@suse.com
- Update to version 20200413 (git commit 64dba0fedb22):
  * linux-firmware: add firmware for MT7663 Wifi/BT combo device
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * qcom: Add SDM845 Adreno ZAP shader firmware
  * qca: Enable transparent WBS for WCN3991
  * QCA: Add Bluetooth firmware for QCA6390
  * mediatek: Add mt8183 SCP firmware
* Thu Mar 19 2020 tiwai@suse.com
- Update to version 20200316 (git commit 8eb0b281511d):
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * amdgpu: update vega20 firmware from 19.50
  * amdgpu: update vega12 firmware from 19.50
  * amdgpu: update vega10 firmware from 19.50
  * rtl_bt: Add firmware and configuration files for RTL8822C BT UART chip
  * i915: Add DMC firmware v2.06 for TGL
  * i915: add HuC firmware v7.0.12 for TGL
* Sun Mar  8 2020 tiwai@suse.com
- Update to version 20200302 (git commit 0148cfefcbf9):
  * check_whence: python3/utf-8 support
  * Makefile: improve `make check` usefulness
  * mediatek: Remove in-tree symlinks
  * qca: Fix blueooth firmware name for QCA6174
  * mediatek: move MT8173 VPU FW to subfolder
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * qca: Add firmware files for BT chip wcn3991.
  * nvidia: add TU116/117 signed firmware
  * drm/amdgpu: update to latest 19.50 firmware for raven
  * mediatek: update MT8173 VPU firmware to v1.1.4
* Fri Feb  7 2020 tiwai@suse.com
- Update to version 20200207 (git commit 6f89735800fe):
  * rtl_nic: update firmware for RTL8153A
  * rtl_bt: Update RTL8822C BT FW to V0x0998_C2B4
  * linux-firmware: add firmware for MT7622
  * linux-firmware: add version 2 for MT7615E
  * amdgpu: update to latest navi10 firmware from 19.50
  * Revert "radeon: update oland rlc microcode from amdgpu"
  * amlogic: update video decoder firmwares
  * amdgpu: add renoir firmware for 19.50
  * amdgpu: update raven2 firmware for 19.50
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.12.A.13
  * qca: update bluetooth firmware for QCA6174
- Update topics and alias list
* Mon Jan 27 2020 tiwai@suse.com
- Update to version 20200122 (git commit 1eb2408c6fea):
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * nvidia: add TU102/TU104/TU106 signed firmware
* Mon Jan 20 2020 tiwai@suse.com
- Update to version 20200114 (git commit 9c340bd1bdab):
  * amdgpu: update navi10 firmware for 19.50
  * amdgpu: Add navi10 TA ucode
  * mediatek: update MT8173 VPU firmware to v1.1.3
* Wed Jan  8 2020 tiwai@suse.com
- Update to version 20200107 (git commit 67d4ff59bf33):
  * Mellanox: Add new mlxsw_spectrum firmware xx.2000.2714
  * radeon: update oland rlc microcode from amdgpu
  * amdgpu: update vega20 microcode for 19.50
  * amdgpu: update vega12 microcode for 19.50
  * amdgpu: update vega10 microcode for 19.50
  * amdgpu: update picasso microcode for 19.50
  * amdgpu: update raven2 microcode for 19.50
  * amdgpu: update raven microcode for 19.50
  * amdgpu: update navi10 microcode for 19.50
  * amdgpu: update navi14 microcode for 19.50
  * amdgpu: add TA microcode for Raven asics
  * qed: Add firmware 8.42.2.0
  * Adjust WHENCE entry to check_whence doesn't complain
  * qcom: Switch SDM845 WLAN firmware
  * linux-firmware: add NXP firmware licence file
* Mon Dec 23 2019 tiwai@suse.com
- Update to version 20191220 (git commit 6871bffa79ed):
  * ath10k: WCN3990 hw1.0: add firmware WLAN.HL.2.0-01387-QCAHLSWMTPLZ-1
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.9.0.2-00070
  * ath10k: QCA988X hw2.0: update firmware-5.bin to 10.2.4-1.0-00047
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.9.0.2-00070
  * ath10k: QCA9887 hw1.0: update firmware-5.bin to 10.2.4-1.0-00047
  * ath10k: QCA6174 hw3.0: update board-2.bin
* Wed Dec 18 2019 tiwai@suse.com
- Update to version 20191218 (git commit c4586ffaac0c):
  * linux-firmware: Update AMD cpu microcode
  * inside-secure: add new "mini" firmware for the EIP197 driver
  * WHENCE: Add raspberry-pi4 SDIO file
  * qcom: update venus firmware files for v5.4
  * cxgb4: Update firmware to revision 1.24.11.0
  * brcm: Add BCM43455 NVRAM for Raspberry Pi 4 B
  * qcom: Add SDM845 Compute DSP firmware
  * qcom: Add SDM845 Audio DSP firmware
  * qcom: Add SDM845 modem firmware
- Update topics and aliases for 5.5 kernels
* Tue Nov 19 2019 tiwai@suse.com
- Update to version 20191118 (git commit e8a0f4c93147):
  * rtl_nic: add firmware rtl8168fp-3
  * linux-firmware: Update NXP Management Complex firmware to version 10.18.0
* Sun Nov 17 2019 tiwai@suse.com
- Update to version 20191113 (git commit c62c3c26a5e7):
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * amdgpu: update navi14 vcn firmware
  * amdgpu: update navi10 vcn firmware
* Mon Nov 11 2019 tiwai@suse.com
- Update to version 20191108 (git commit f1100ddf581f):
  * i915: Add HuC firmware v7.0.3 for TGL
  * i915: Add GuC firmware v35.2.0 for TGL
  * i915: Add HuC firmware v9.0.0 for EHL
  * i915: Add GuC firmware v33.0.4 for EHL
  * rtw88: RTL8723D: add firmware file v48
  * qed: Add firmware 8.40.33.0
  * amdgpu: add new navi14 wks gfx firmware for 19.30
  * amdgpu: update navi14 firmware for 19.30
  * amdgpu: update raven firmware for 19.30
  * linux-firmware: Add firmware file for Intel Bluetooth AX201
* Wed Oct 23 2019 tiwai@suse.de
- Fix the missing ast and qla2xx firmwares due to typos in
  extrawhence file
* Wed Oct 23 2019 tiwai@suse.com
- Update to version 20191023 (git commit: ad7a8b22b1d0):
  * Mellanox: Add new mlxsw_spectrum2 firmware 29.2000.2308
  * Mellanox: Add new mlxsw_spectrum firmware 13.2000.2308
  * rtl_nic: add firmware files for RTL8153
  * rtl_bt: Update configuration file for BT part of RTL8822CU
  * bnx2x: Add FW 7.13.15.0.
- Update topics.list and modaliases for r8152 and ice
* Wed Oct 23 2019 tiwai@suse.com
- Update to version 20191022 (git-commit: 2b016afc348b):
  * linux-firmware: Update AMD cpu microcode
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * amdgpu: add initial navi14 firmware form 19.30
  * rtlwifi: rtl8821ae: Add firmware for the RTL8812AE variant.
  * ice: Fix up WHENCE entry and symlink
  * nvidia: Update Tegra210 XUSB firmware to v50.24
  * nvidia: Add XUSB firmware for Tegra194
  * Remove duplicate symlinks
  * copy-firmware: Create symlinks from WHENCE file
  * Make symlinks consistent
  * amdgpu: update vega20 ucode for 19.30
  * amdgpu: update vega12 ucode for 19.30
  * amdgpu: update vega10 ucode for 19.30
  * amdgpu: update picasso ucode for 19.30
  * amdgpu: update raven2 ucode for 19.30
  * amdgpu: update raven ucode for 19.30
  * amdgpu: add new raven rlc firmware
  * ice: Add package file for Intel E800 series driver
  * amdgpu: add initial navi10 firmware
  * drm/i915/firmware: Add v9.0.0 of HuC for Icelake
  * drm/i915/firmware: Add v4.0.0 of HuC for Cometlake
  * drm/i915/firmware: Add v4.0.0 of HuC for Geminilake
  * drm/i915/firmware: Add v2.0.0 of HuC for Broxton
  * drm/i915/firmware: Add v4.0.0 of HuC for Kabylake
  * drm/i915/firmware: Add v2.0.0 of HuC for Skylake
  * drm/i915/firmware: Add v33 of GuC for CML
  * drm/i915/firmware: Add v2.04 of DMC for TGL
  * drm/i915/firmware: Add v1.09 of DMC for ICL
  * qcom: add firmware files for Adreno a630
- Update module aliases and topics list
- Update install-split.sh to deal with the proper symlinks
- Add verbose mode to install-split.sh
* Mon Sep 23 2019 tiwai@suse.com
- Update to version 20190909 (git-commit 6c6918ad8ae0):
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * nvidia: Add XUSB firmware for Tegra186
  * Add symlinks for Tegra VIC firmware binaries
  * rtl_bt: Update RTL8723D BT FW to 0x828A_96F1
  * rtl_nic: add firmware rtl8125a-3
  * linux-firmware: Add firmware file for Intel Bluetooth AX201
  * Chelsio driver loads firmware configuration file to allow firmware
    to distribute resources before chip bring up. Chelsio NIC driver,
    cxgb4 searches for firmware config file at /lib/firmware/cxgb4/
    directory.
- Add dependency on dracut >= 049 (boo#1151552) to compressed f/w
  packages
* Wed Aug 28 2019 tiwai@suse.com
- Update to version 20190827 (git-commit 7307a29961ad):
  * brcm: Add 43455 based AP6255 NVRAM for the Minix Neo Z83-4 Mini PC
  * brcm: Add 43340 based AP6234 NVRAM for the PoV TAB-P1006W-232 tablet
  * iwlwifi: update FWs to core45-152 release
  * check_whence: Add copy-firmware.sh to the list of ignored files
  * rtl_bt: Update RTL8822C BT FW to V0x098A_94A4
  * linux-firmware: Update firmware file for Intel Bluetooth AX200
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * Mellanox: Add new mlxsw_spectrum firmware 13.2000.1886
* Wed Aug 21 2019 tiwai@suse.com
- Update to version 20190815 (git-commit 07b925b450bf):
  * Install only listed firmware files
  * rtw88: add a README file
  * rtw88: RTL8822C: add WoW firmware v7.3
  * rtw88: RTL8822C: update rtw8822c_fw.bin to v7.3
  * ath10k: QCA9984 hw1.0: update board-2.bin
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.9.0.2-00046
  * ath10k: QCA988X hw2.0: update firmware-5.bin to 10.2.4-1.0-00045
  * ath10k: QCA9888 hw2.0: update board-2.bin
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.9.0.2-00040
  * ath10k: QCA9887 hw1.0: update firmware-5.bin to 10.2.4-1.0-00045
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to WLAN.RM.4.4.1-00140-QCARMSWPZ-1
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * cxgb4: update firmware to revision 1.24.3.0
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.10.A.38
  * nvidia: add missing entries in WHENCE
  * linux-firmware: Update NXP Management Complex firmware to version 10.16.2
  * iwlwifi: update -48 FWs for Qu and cc
  * iwlwifi: update FWs for 3168, 7265D, 9000, 9260, 8000, 8265 and cc
  * drm/i915/firmware: Add v33 of GuC for ICL
  * drm/i915/firmware: Add v33 of GuC for KBL
  * drm/i915/firmware: Add v33 of GuC for SKL
  * drm/i915/firmware: Add v33 of GuC for GLK
  * drm/i915/firmware: Add v33 of GuC for BXT
- Drop iwlwifi revert patch, as the fix will go into 5.2.x kernel
  (bsc#1142128):
  WHENCE-iwlwifi-9xxx-46-revert.patch
- Drop the deprecated upstream fix:
  0001-nvidia-add-missing-entries-in-WHENCE.patch
- Drop the local copy of copy-file.sh that is already included in
  the latest linux-git tarball
* Mon Aug 19 2019 tiwai@suse.de
- Re-group some entries for USB hotpluggable network drivers into
  kernel-firmware-usb-network subpackage, while moving ath10k and
  mwifiex firmware into the own subpackage, too
* Thu Jul 25 2019 tiwai@suse.de
- Move documents and license texts into the proper section
- Remove spurious non-firmware files
- Restructure the packaging for reducing the storage footprint
  (bsc#1143959):
  the firmware files are split into several subpackages, so that user
  doesn't need to install unnecessary files.  Each package has
  supplements entries that are generated from the static list (that
  was created from the current and old TW kernel binaries).
  There is a catch-all package, kernel-firmware-all, and this
  provides/obsoletes the former kernel-firmware package.  And each
  firmware file is compressed in XZ format for the new kernel (5.3 or
  later).
  For the systems with older kernels, we still provide the old'n'good
  kernel-firmware.rpm, containing everything in the raw format, too.
  This kernel-firmware.rpm will be obsoleted once when
  kernel-firmware-all above is installed.
  The build of both flavors are done in the multibuild.  Without the
  flavor, the raw kernel-firmware.rpm and ucode-amd.rpm are built,
  while the new kernel firmware packages are built in "compressed"
  flavor (-M compressed).
- Upstream fix for missing WHENCE entries:
  0001-nvidia-add-missing-entries-in-WHENCE.patch
* Fri Jul 19 2019 tiwai@suse.de
- Revert the iwlwifi 9000 and 9260 *-46.ucode firmware files that
  are broken on some machines to 20190618 state (bsc#1142128):
  WHENCE-iwlwifi-9xxx-46-revert.patch
* Mon Jul 15 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190712:
  * linux-firmware: Update firmware file for Intel Bluetooth AX201
  * linux-firmware: Update firmware file for Intel Bluetooth 22161
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * amdgpu: update vega10 VCE firmware
  * amdgpu: update picasso vcn firmware
  * amdgpu: update raven vcn firmware
  * amdgpu: update tonga to latest 19.20 firmware
  * amdgpu: update vega12 to latest 19.20 firmware
  * amdgpu: partially revert 2579167548be33afb1fe2a9a5c141561ee5a8bbe
  * amdgpu: update vega10 to latest 19.20 firmware
  * amdgpu: update polaris12 to latest 19.20 firmware
  * amdgpu: update raven2 to latest 19.20 firmware
  * amdgpu: update raven to latest 19.20 firmware
  * amdgpu: update picasso to latest 19.20 firmware
* Tue Jul  9 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190628:
  * linux-firmware: rsi: add firmware image for redpine 9116 chipset
  * linux-firmware: Add firmware file for Intel Bluetooth AX201
  * iwlwifi: add new firmwares for integrated 22000 series
  * iwlwifi: update FW for 22000 to Core45-96
  * iwlwifi: update FWs for 9000 series to Core45-96
  * iwlwifi: update Core45 FWs for 22260, 9000 and 9260
  * iwlwifi: udpate -36 firmware for 8000 series
* Wed Jun 19 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190618:
  * cavium: Add firmware for CNN55XX crypto driver.
  * linux-firmware: Update firmware file for Intel Bluetooth 22161
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update AMD SEV firmware (CVE-2019-9836, bsc#1139383)
  * linux-firmware: update licence text for Marvell firmware
* Mon Jun 10 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190607:
  * linux-firmware: update firmware for mhdp8546
  * linux-firmware: rsi: update firmware images for Redpine 9113 chipset
  * imx: sdma: update firmware to v3.5/v4.5
  * nvidia: update GP10[2467] SEC2 RTOS with the one already used on GP108
* Fri May 24 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190514:
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
  * linux-firmware: Update firmware file for Intel Bluetooth 22161
  * amlogic: add video decoder firmwares
  * iwlwifi: update -46 firmwares for 22260 and 9000 series
  * iwlwifi: add firmware for 22260 and update 9000 series -46 firmwares
  * iwlwifi: add -46.ucode firmwares for 9000 series
* Fri May  3 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190502:
  * amdgpu: update vega20 to the latest 19.10 firmware
  * amdgpu: update vega12 to the latest 19.10 firmware
  * amdgpu: update vega10 to the latest 19.10 firmware
  * amdgpu: update polaris11 to the latest 19.10 firmware
  * amdgpu: update polaris10 to the latest 19.10 firmware
  * amdgpu: update raven2 to the latest 19.10 firmware
  * amdgpu: update raven to the latest 19.10 firmware
  * amdgpu: update picasso to the latest 19.10 firmware
  * linux-firmware: update fw for qat devices
  * Mellanox: Add new mlxsw_spectrum firmware 13.2000.1122
  * drm/i915/firmware: Add ICL HuC v8.4.3238
  * drm/i915/firmware: Add ICL GuC v32.0.3
  * drm/i915/firmware: Add GLK HuC v03.01.2893
  * drm/i915/firmware: Add GLK GuC v32.0.3
  * drm/i915/firmware: Add KBL GuC v32.0.3
  * drm/i915/firmware: Add SKL GuC v32.0.3
  * drm/i915/firmware: Add BXT GuC v32.0.3
* Mon Apr 15 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190409:
  * linux-firmware: Add firmware file for Intel Bluetooth 22161
  * cxgb4: update firmware to revision 1.23.4.0 (bsc#1136334)
  * linux-firmware: Update NXP Management Complex firmware to version 10.14.3
  * linux-firmware: add firmware for MT7615E
  * mediatek: update MT8173 VPU firmware to v1.1.2 [decoder] Enlarge struct vdec_pic_info to support more capture buffer plane and capture buffer format change.
  * linux-firmware: update Marvell 8797/8997 firmware images
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.10.A.23
  * cxgb4: update firmware to revision 1.23.3.0
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
  * linux-firmware: Update firmware file for Intel Bluetooth 9260
  * linux-firmware: Update firmware file for Intel Bluetooth 9560
* Tue Mar 12 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190312:
  * drm/amdgpu: update picasso to latest from 18.50 branch
  * drm/amdgpu: update polaris12 to latest from 18.50 branch
  * drm/amdgpu: update vega20 to latest from 18.50 branch
  * rtw88: RTL8822C: update rtw8822c_fw.bin to v5.0
  * rtl_bt: Update firmware for BT part of RTL8822C
  * linux-firmware: update Marvell 8787/8801/8887 firmware images
  * linux-firmware: update Marvell 8897/8997 firmware images
  * nfp: update Agilio SmartNIC firmware to rev 2.1.16.1
  * QCA: Add the fw files for BT Chip QCA6174.
* Thu Feb 28 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190221:
  * linux-firmware: Add AMD SEV firmware
  * WHENCE: Correct errant entries
  * amdgpu: update raven2 rlc firmware
  * amdgpu: drop raven2_sdma1.bin
  * linux-firmware: Update firmware file for Intel Bluetooth,9560
  * linux-firmware: Update firmware file for Intel Bluetooth,9260
  * qca: Add firmware files for BT chip wcn3990.
  * nvidia: add TU10x typec controller firmware
* Wed Feb 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190212:
  * bnx2x: Add FW 7.13.11.0. (bsc#1132303,bsc#1136498)
  * amdgpu: add firmware for vega20 from 18.50
  * amdgpu: bump year on license
  * linux-firmware: update Marvell PCIe-USB8997 firmware image
  * linux-firmware: update Marvell SD8897-B0 firmware image
  * linux-firmware: add Marvell SD8977 firmware image
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.9.0.2-00021
  * ath10k: QCA988X hw2.0: update firmware-5.bin to 10.2.4-1.0-00043
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.9.0.2-00024
  * ath10k: QCA6174 hw3.0: update board-2.bin
* Mon Jan 21 2019 tiwai@suse.de
- Remove brcm RPi f/w that are already included in the upstream tree
* Fri Jan 18 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190118 (bsc#1110720,FATE#325946,bsc#1104289,
  bsc#1128292):
  * brcm: Add BCM43455 NVRAM for Raspberry Pi 3 B+
  * brcm: Fix filename for BCM43430 NVRAM for the Raspberry Pi 3 Model B
  * amdgpu: add raven2 fw for 18.50 release
  * amdgpu: add picasso fw for 18.50 release
  * Revert "brcm: Add BCM43455 NVRAM for Raspberry Pi 3 B+"
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * linux-firmware: Update firmware file for Intel Bluetooth,9260
  * linux-firmware: Update firmware file for Intel Bluetooth,9560
  * brcm: Add BCM43430 NVRAM for the Raspberry Pi 3 Model B
  * brcm: Add BCM43455 NVRAM for Raspberry Pi 3 B+
  * linux-firmware: update Marvell USB8801 B0 firmware image
  * iwlwifi: update firmwares for 9000 series
  * cxgb4: update firmware to revision 1.22.9.0
* Tue Jan 15 2019 Matthias Brugger <mbrugger@suse.com>
- Fix firmware for bcm43430 and bcm43455 (fate#326215)
  * rename brcmfmac43450 and brcfmac43455 to the compatible name
    used by brcmf_of_probe
  * delete brcmfmac43455-sdio.clm_blob as it was not accepted upstream
* Fri Jan 11 2019 Matthias Brugger <mbrugger@suse.com>
- Add firmware for bcm43430 and bcm43455 (fate#326215)
  * brcmfmac43430-sdio.raspberrypi-rpi.txt
  * brcmfmac43455-sdio.clm_blob
  * brcmfmac43455-sdio.raspberrypi-rpi.txt
* Thu Dec 20 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 20181218: (FATE#326045,FATE#325856,FATE#326294)
  * Revert "amdgpu: update vega10 fw for 18.50 release"
  * brcm: Add 4330 NVRAM for the Prowise PT301 tablet
  * brcm: Add 43430 NVRAM for the Chuwi Vi8 Plus tablet
  * brcm: Add 43340 based AP6234 NVRAM for the Meegopad T08 HDMI stick
  * brcm: Add 43430a0 based AP6212 NVRAM for the Jumper EZpad mini 3 tablet
  * brcm: Add 43430a0 based AP6212 NVRAM for the Onda V80 Plus tablet
  * brcm: Add 4356 based AP6356 NVRAM for the GPD win handheld
  * brcm: Add brcmfmac43362-sdio.lemaker,bananapro.txt symlink
  * brcm: Add 43362 based AP6210 NVRAM for the Cubietech Cubietruck
  * WHENCE: Put quotes around brcmfmac NVRAM filenames
  * check_whence.py: Add support for filenames with spaces in them
  * rtl_bt: Add firmware and configuration files for the Bluetooth part of RTL8723BS
* Mon Dec 17 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 20181217:
  * iwlwifi: update firmwares for 8000 series
  * iwlwifi: add -43.ucode for 9000 series
  * iwlwifi: update -41.ucode for 9000 series
  * brcm: provide new firmwares for BCM4366 chipset
  * Mellanox: Add new mlxsw_spectrum firmware 13.1910.622
  * cavium: Update firmware for CNN55XX crypto driver
  * amdgpu: update vega12 fw for 18.50 release
  * amdgpu: update vega10 fw for 18.50 release
  * amdgpu: update raven fw for 18.50 release
  * amdgpu: update polaris11 fw for 18.50 release
  * amdgpu: update polaris10 fw for 18.50 release
  * amdgpu: add firmware for vega12
  * amdgpu: Add new polaris MC firmwares
  * amdgpu: Add new polaris SMC firmwares
  * linux-firmware: Update AMD cpu microcode
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.10.A.13
  * microchip: add firmware for VSC8574 and VSC8584 Ethernet PHYs
  * linux-firmware: intel: Update Cannonlake audio firmware.
  * firmware/huc/bxt: Add huC Update for BXT
  * nfp: update Agilio SmartNIC firmware to rev 2.1.16
  * cxgb4: update firmware to revision 1.21.5.0
* Wed Nov  7 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 20181026: (bsc#1122456)
  * qed: Add 8.37.7.0 firmware image
  * amdgpu: add raven dmcu firmware
  * amdgpu: update raven firmware to 18.40
  * amdgpu: update fiji firmware to 18.40
  * amdgpu: update tonga firmware to 18.40
  * amdgpu: update carrizo firmware to 18.40
  * amdgpu: update polaris10 firmware to 18.40
  * amdgpu: update vega10 firmware to 18.40
  * linux-firmware: add firmware for mt7650e
  * linux-firmware: add MC firmware for NXP DPAA2 SoCs
  * linux-firmware: liquidio: fix GPL compliance issue
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * linux-firmware: Update firmware file for Intel Bluetooth,9260
  * linux-firmware: Update firmware file for Intel Bluetooth,9560
  * linux-firmware: add firmware for mt7610e
  * Update Intel OPA hfi1 firmware
  * ath10k: QCA9984 hw1.0: update board-2.bin
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.6.0.1-00003
  * ath10k: QCA988X hw2.0: update firmware-5.bin to 10.2.4-1.0-00041
  * ath10k: QCA9888 hw2.0: update board-2.bin
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.6-00140
  * ath10k: QCA9887 hw1.0: update firmware-5.bin to 10.2.4-1.0-00041
  * ath10k: QCA9377 hw1.0: add firmware-6.bin to WLAN.TF.2.1-00021-QCARMSWP-1
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to RM.4.4.1.c2-00057-QCARMSWP-1
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * ath10k: QCA4019 hw1.0: update firmware-5.bin to 10.4-3.6-00140
  * nfp: Add Agilio BPF firmware rev 2.0.6.124
  * rtw88: Add firmware file for driver rtw88
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.9.A.37
  * iwlwifi: add -41.ucode firmwares for 9000 series
  * iwlwifi: update firmwares for 9000 series
  * iwlwifi: update firmwares for 7000, 8000 and 9000 series
  * nfp: update Agilio SmartNIC firmware to rev 2.1.13
* Tue Oct  2 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 20181001:
  * ti-connectivity: add firmware for CC2560(A) Bluetooth
  * linux-firmware: mediatek: add firmware for mt7668u Bluetooth
  * nvidia: add GV100 signed firmware
  * firmware/icl/dmc: Add v1.07 of DMC for Icelake
  * linux-firmware: add Marvell SD8997 firmware image
  * qca: update BT firmware files for QCA ROME chip.
* Wed Sep 19 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 20180913:
  * brcm: update firmware for bcm43362 sdio
  * Mellanox: Add new mlxsw_spectrum firmware 13.1703.4
  * rtl_bt: Add firmware and configuration files for the Bluetooth part of RTL8822CU
  * nvidia: switch GP10[2467] to newer scrubber/ACR firmware (from GP108)
* Wed Aug 29 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 20180825:
  * amdgpu: sync up polaris10 firmware with 18.30 release
  * amdgpu: sync up vega10 firmware with 18.30 release
  * amdgpu: sync up raven firmware with 18.30 release
  * amdgpu: sync up polaris12 firmware with 18.30 release
  * amdgpu: sync up tonga firmware with 18.30 release
  * amdgpu: sync up polaris11 firmware with 18.30 release
  * amdgpu: sync up fiji firmware with 18.30 release
  * linux-firmware: add firmware for mhdp8546
  * qed: Add firmware 8.37.7.0
* Wed Aug 15 2018 mpluskal@suse.com
- Update to version 20180814:
  * linux-firmware:Update firmware patch for Intel Bluetooth 7265 (D1)
  * linux-firmware: Update firmware file for Intel Bluetooth,9560
  * linux-firmware: Update firmware file for Intel Bluetooth,9260
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * linux-firmware: add firmware for mt76x0
  * qcom: update venus firmware files for v5.2
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.9.A.31
* Tue Jul 31 2018 mpluskal@suse.com
- Update to version 20180730:
  * linux-firmware: add firmware for mt76x2u
  * wl18xx: update firmware file 8.9.0.0.79
  * Mellanox: Add new mlxsw_spectrum firmware 13.1702.6
  * WHENCE: Remove reference to amdgpu/vegam_me_2.bin
  * linux-firmware: mediatek: add MT7622 Bluetooth firmwares and license file
  * brcm: add 43430 based AP6212 and 1DX NVRAM
  * linux-firmware: update Marvell USB8801 B0 firmware image
* Thu Jul 19 2018 tiwai@suse.de
- Remove useless check_whence.py that leads to unnecessary python
  dependency (bsc#1101818);
  also removing the python3 hack at prep, too
* Wed Jul 18 2018 mpluskal@suse.com
- Update to version 20180717 (bsc#1091203):
  * amdgpu: update copyright date
  * amdgpu: add initial VegaM firmware
  * amdgpu: sync up vega10 firmware with 18.20 release
  * amdgpu: sync up raven firmware with 18.20 release
  * amdgpu: sync up polaris12 firmware with 18.20 release
  * amdgpu: sync up polaris11 firmware with 18.20 release
  * amdgpu: sync up polaris10 firmware with 18.20 release
  * amdgpu: sync up verde firmware with 18.20 release
  * amdgpu: sync up pitcairn firmware with 18.20 release
  * amdgpu: sync up tahiti firmware with 18.20 release
  * amdgpu: sync up oland firmware with 18.20 release
  * amdgpu: sync up hainan firmware with 18.20 release
  * amdgpu: sync up kaveri firmware with 18.20 release
  * amdgpu: sync up mullins firmware with 18.20 release
  * amdgpu: sync up kabini firmware with 18.20 release
  * amdgpu: sync up hawaii firmware with 18.20 release
  * amdgpu: sync up bonaire firmware with 18.20 release
  * WHENCE: Fix typo Version
  * cxgb4: update firmware to revision 1.20.8.0
* Fri Jun  8 2018 mpluskal@suse.com
- Update to version 20180606:
  * brcm: update firmware for bcm4356 pcie
  * brcm: update firmware for bcm4354 sdio
  * brcm: update firmware for bcm43362 sdio
  * brcm: update firmware for bcm43340 sdio
  * brcm: update firmware for bcm43430 sdio
  * Update Cypress license termination clause
  * amdgpu: update vega10 VCE firmware to version 55.3
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265 (D0)
  * linux-firmware:Update firmware patch for Intel Bluetooth 7265 (D1)
  * qcom: add venus firmware files for v5.2
  * linux-firmware: liquidio: update vswitch firmware to v1.7.2
* Mon Jun  4 2018 tiwai@suse.de
- Use the upstream version of AMD ucode for family 17h
  (CVE-2017-5715, bsc#1095735)
* Tue May 29 2018 mpluskal@suse.com
- Update to version 20180525:
  * Update AMD cpu microcode for family 15h (CVE-2017-5715,
    bsc#1095735)
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * qed: Add firmware 8.37.2.0
* Mon May 21 2018 mpluskal@suse.com
- Update to version 20180518:
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * linux-firmware: Update firmware patch for Intel Bluetooth 7260 (B5/B6)
  * linux-firmware: Update firmware patch for Intel Bluetooth 7260 (B3/B4)
  * linux-firmware: Update firmware file for Intel Bluetooth,9260
  * linux-firmware:Update firmware patch for Intel Bluetooth 7265 (D1)
  * linux-firmware: Update firmware file for Intel Bluetooth,9560
  * linux-firmware: Update AMD cpu microcode
  * amdgpu: sync up polaris12 firmware with 18.10 release
  * amdgpu: sync up polaris11 firmware with 18.10 release
  * amdgpu: sync up polaris10 firmware with 18.10 release
  * amdgpu: sync up vega10 firmware with 18.10 release
  * amdgpu: sync up carrizo firmware with 18.10 release
  * amdgpu: sync up topaz firmware with 18.10 release
  * amdgpu: sync up stoney firmware with 18.10 release
  * amdgpu: sync up tonga firmware with 18.10 release
  * amdgpu: sync up fiji firmware with 18.10 release
  * amdgpu: sync up raven firmware with 18.10 release
  * nfp: Add symlink for Agilio CX 1x40GbE flower firmware
  * nfp: update Agilio SmartNIC flower firmware to rev AOTC-2.9.A.16
  * linux-firmware: liquidio: update firmware to v1.7.2
* Wed May  9 2018 mpluskal@suse.com
- Update to version 20180507:
  * linux-firmware: update Marvell USB8997 firmware image to add WPA2 vulnerability fix
  * linux-firmware: update Marvell SD8897-B0 firmware image to add WPA2 vulnerability fix
  * Update Intel OPA hfi1 firmware
  * qed: Add firmware 8.33.12.0
  * linux-firmware: Add firmware file for Intel Bluetooth,9560
  * linux-firmware: Add firmware file for Intel Bluetooth,9260
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * cxgb4: update firmware to revision 1.19.1.0
  * nfp: add symlink for mixed mode Agilio CX 2x25GbE cards
  * nfp: update Agilio SmartNIC flower firmware to rev 5701
* Tue Apr 17 2018 mpluskal@suse.com
- Update to version 20180416:
  * linux-firmware: update wil6210 firmware to 5.2.0.18
  * linux-firmware: rsi: update firmware images for Redpine 9113 chipset
  * iwlwifi: update firmwares for 3160, 3168 and 7265
  * iwlwifi: add some new FW versions and update older ones
* Fri Apr 13 2018 meissner@suse.com
- fixed new style modalias detection too for AMD CPUs in ucode-amd,
  it can only use 1 : (bsc#1084687)
* Tue Apr  3 2018 mpluskal@suse.com
- Update to version 20180402:
  * amdgpu: update vce firmware for Polaris
  * linux-firmware: Add firmware file for Intel Bluetooth,9560
  * linux-firmware: Add firmware file for Intel Bluetooth,9260
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * nfp: update Agilio SmartNIC firmware to rev 2.0.7
  * cxgb4: update firmware to revision 1.18.9.0
  * linux-firmware: intel: Update Geminilake audio firmware
  * linux-firmware: intel: Update Kabylake audio firmware
  * linux-firmware: intel: Update Broxton audio firmware
  * linux-firmware: intel: Update Skylake audio firmware
* Fri Mar 23 2018 mpluskal@suse.com
- Update to version 20180320:
  * BCM-0bb4-0306: Update to Cypress license in WHENCE
  * linux-firmware: intel: Update Kabylake audio firmware
* Wed Mar 21 2018 meissner@suse.com
- detect new style modalias too for AMD CPUs in ucode-amd
  (bsc#1084687)
* Wed Mar 14 2018 mpluskal@suse.com
- Update to version 20180312:
  * Mellanox: Add new mlxsw_spectrum firmware 13.1620.192
  * qed: Add firmware 8.33.11.0
  * BCM-0bb4-0306: Cypress Bluetooth firmware for HTC Vive
  * linux-firmware:Update firmware patch for Intel Bluetooth 7265 (D1)
  * qed: Add firmwares 8.20.0.0 8.18.9.0 and 8.14.6.0
  * iwlwifi: update firmware version 34 for 9000 series
* Wed Mar  7 2018 mpluskal@suse.com
- Update to version 20180222:
  * ath10k: QCA9984 hw1.0: update firmware-5.bin to 10.4-3.5.3-00053
  * ath10k: QCA988X hw2.0: update firmware-5.bin to 10.2.4-1.0-00037
  * ath10k: QCA9888 hw2.0: update firmware-5.bin to 10.4-3.5.3-00053
  * ath10k: QCA9887 hw1.0: update firmware-5.bin to 10.2.4-1.0-00037
  * ath10k: QCA9377 hw1.0: update firmware-5.bin to WLAN.TF.1.0-00002-QCATFSWPZ-5
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to WLAN.RM.4.4.1-00079-QCARMSWPZ-1
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * ath10k: QCA4019 hw1.0: update firmware-5.bin to 10.4-3.5.3-00053
  * rtl_bt: Add firmware and configuration files for the Bluetooth parts of RTL8821C and RTL8723D
  * qed: Add firmwares 8.30.12.0 and 8.10.9.0
  * nfp: update Agilio SmartNIC firmware to rev 2.0.4
* Fri Feb  9 2018 mpluskal@suse.com
- Update to version 20180201:
  * linux-firmware: Add firmware file for Intel Bluetooth,9560
  * linux-firmware: Add firmware file for Intel Bluetooth,9260
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * wl127x/wl128x: update PLT firmwares
  * linux-firmware: intel: Update Kabylake audio firmware
- Mark license files as such
* Mon Jan 22 2018 mpluskal@suse.com
- Update to version 20180119:
  * amdgpu: update uvd firmware for polaris asics
  * amdgpu: update vce firmware for Fiji
  * amdgpu: update vcn firmware for raven
  * amdgpu: update vce and uvd firmware for Vega10
  * mediatek: update MT8173 VPU firmware to 1.0.8 [decoder h264] Fix h264 decoder output delay for some low latency bitstreams
  * cxgb4: update firmware to revision 1.17.14.0
  * linux-firmware: update Marvell PCIe-USB8897/8997 firmware image to add WPA2 vulnerability fix
  * linux-firmware: intel: Update Geminilake audio firmware
* Thu Jan  4 2018 mpluskal@suse.com
- Update to version 20180104:
  * wl18xx: update firmware file 8.9.0.0.76
  * wl127x/wl128x: update firmwares
  * rtlwifi: rtl8723de: Add firmware for new driver/device
  * linux-firmware: DMC firmware for cannonlake v1.07
* Mon Dec 25 2017 meissner@suse.com
- Add microcode_amd_fam17h.bin (bsc#1068032 CVE-2017-5715)
* Sat Dec 23 2017 mpluskal@suse.com
- Update to version 20171221:
  * nvidia: add GP108 signed firmware
  * linux-firmware: liquidio: add v1.7.0 vswitch firmware
  * brcm: add CYW4373 firmwares and Cypress license file
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
  * linux-firmware: Add firmware file for Intel Bluetooth 9260
  * linux-firmware: Add firmware file for Intel Bluetooth 9560
  * Revert commits a42f895, c113d33, 041aff8, 73d13b5
  * linux-firmware: Update firmware patch for Intel Bluetooth 8260
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
  * linux-firmware: Add firmware file for Intel Bluetooth 9260
  * linux-firmware: Add firmware file for Intel Bluetooth 9560
  * linux-firmware: intel: Add Cannonlake audio firmware
  * nfp: add firmware for tc-flower
  * nfp: change firmware directory layout
  * nfp: update firmware for Agilio CX SmartNICs
* Mon Dec  4 2017 mpluskal@suse.com
- Update to version 20171204:
  * amdgpu: add firmware for Raven
  * amdgpu: update vega10 vce firmware
  * linux-firmware: DMC firmware for skylake v1.27
* Thu Nov 30 2017 dimstar@opensuse.org
- Change the shebang of check_whence.py (installed as a
  non-executable) to point to python3.
* Thu Nov 30 2017 mpluskal@suse.com
- Update to version 20171125:
  * brcm: update firmware for bcm4358
  * brcm: update firmware for bcm4356
  * brcm: update firmware for bcm4354
  * brcm: introduce firmware for bcm43430 revision 0
  * brcm: update firmware for bcm4339
  * Mellanox: Add new mlxsw_spectrum firmware 13.1530.152
  * WHENCE: Add missing entry for mlxsw_spectrum firmware
  * WHENCE: Fix typo in entry for iwlwifi-8265-34.ucode
  * s2255drv: f2255usb: firmware version 1.2.8
  * amdgpu: add new CP firmware for polaris chips
  * qed: Add firmware 8.33.1.0
  * qcom: add venus firmware files for v4.2
  * qcom: add firmware files for Adreno a530
  * iwlwifi: add firmware version 34 for new 9000 series
  * linux-firmware: liquidio: update firmware to v1.7.0
  * linux-firmware: intel: Update Geminilake audio firmware
  * iwlwifi: add firmware version 33 for new 9000 series
  * iwlwifi: add new firmware version 34 for 8000C and 8265
  * iwlwifi: update firmwares for 3160, 3168, 7260, 7265 and 7265D
  * iwlwifi: update firmwares for 3160, 3168, 7265D, 8000C and 8265
  * linux-firmware: DMC firmware for kabylake v1.04
  * linux-firmware: update Marvell PCIe-USB8997 firmware image
  * linux-firmware: GuC firmware for kabylake v9.39
  * linux-firmware: GuC firmware for Broxton v9.29
  * linux-firmware: GuC firmware for Skylake v9.33
  * linux-firmware/i915: Add Cannonlake DMC version 1.06
  * linux-firmware/i915: Add Geminilake DMC version 1.04
  * WHENCE: Add new qed firmware
  * WHENCE: Add new radeon firmware
  * WHENCE: Fix syntax error for iwlwifi-8265-31.ucode entry
  * Revert "ath10k: QCA988X hw2.0: update firmware to 10.2.4.70.63-2"
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to WLAN.RM.4.4.1-00051-QCARMSWP-1
  * cxgb4: update firmware to revision 1.16.63.0
  * linux-firmware: update Marvell PCIe-USB8997 firmware image
  * linux-firmware: update Marvell PCIe-USB8897-A2 firmware image
  * Drop intel wifi firmwares and WHENCE-iwlwifi-update.patch as
  they are upstreamed
* Mon Nov 20 2017 tiwai@suse.de
- Remove iwlwifi-*-34.ucode since they seem breaking with 4.13.x
  TW kernel (bsc#1068838)
* Wed Nov 15 2017 tiwai@suse.de
- Update Intel WiFi firmwares:
  the files are still not included in linux-firmware.git, hence
  applied individually.
  * For security updates (CVE-2017-13080 CVE-2017-13081 bsc#1066295)
  * For new chipset models (FATE#322675)
  iwlwifi-3160-17.ucode
  iwlwifi-3168-29.ucode
  iwlwifi-7260-17.ucode
  iwlwifi-7265-17.ucode
  iwlwifi-7265D-29.ucode
  iwlwifi-8000C-31.ucode
  iwlwifi-8000C-34.ucode
  iwlwifi-8265-31.ucode
  iwlwifi-8265-34.ucode
  iwlwifi-9000-pu-b0-jf-b0-33.ucode
  iwlwifi-9260-th-b0-jf-b0-33.ucode
  WHENCE-iwlwifi-update.patch
* Tue Oct 10 2017 msuchanek@suse.com
- Update to version 20171009 (bsc#1024476, bnc#1052392):
  * cxgb4: update firmware to revision 1.16.63.0
  * ath10k: QCA6174 hw3.0: update firmware-6.bin to WLAN.RM.4.4.1-00051-QCARMSWP-1
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * Revert "ath10k: QCA988X hw2.0: update firmware to 10.2.4.70.63-2"
* Thu Sep  7 2017 mpluskal@suse.com
- Update to version 20170906:
  * Update Intel OPA hfi1 firmware
  * amdgpu: update psp and acg_smu firmware for vega10
  * rtlwifi: rtl8822be: Add firmware for new driver/device
  * qcom: add firmware files for Adreno A3xx
* Mon Aug 28 2017 mpluskal@suse.com
- Update to version 20170823:
  * Update Intel OPA hfi1 firmware
  * iwlwifi: update -27 firmware for 3168, 7265D, 8000C and 8265
  * iwlwifi: add new firmware for 3168, 7265D, 8000C and 8265
  * linux-firmware: intel: Add Kabylake IPU3 firmware
  * linux-firmware: intel: Update Kabylake audio firmware
  * linux-firmware: intel: remove old skylake firmware
  * linux-firmware: intel: remove old broxton firmware
  * linux-firmware: liquidio: update firmware to v1.6.1
  * amdgpu: add initial vega10 firmware
  * amdgpu: add initial uvd and vce firmware for vega10
  * cavium: Add firmware for CNN55XX crypto driver.
* Fri Aug 18 2017 msuchanek@suse.com
- Do not do any supplements or deduplication of files between kernel-binary and
  kernel-firmware (bsc#1054239).
  * remove firmware.sh
* Tue Jun 27 2017 mpluskal@suse.com
- Update to version 20170622:
  * ath10k: QCA4019 hw1.0: update board-2.bin
  * ath10k: QCA4019 hw1.0: update firmware to 10.4-3.4-00082
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * ath10k: QCA6174 hw3.0: add WLAN.RM.4.4-00022-QCARMSWPZ-2
  * ath10k: QCA9377 hw1.0: update board-2.bin
  * ath10k: QCA9887 hw1.0: update firmware to 10.2.4-1.0-00029
  * ath10k: QCA9888 hw2.0: update board-2.bin
  * ath10k: QCA9888 hw2.0: update firmware to 10.4-3.5.1-00014
  * ath10k: QCA988X hw2.0: update firmware to 10.2.4.70.63-2
  * ath10k: QCA9984 hw1.0: update board-2.bin
  * ath10k: QCA9984 hw1.0: update firmware to 10.4-3.4-00082
  * ath10k: update year in license
* Thu Jun 22 2017 mpluskal@suse.com
- Update to version 20170615:
  * Mellanox: Add firmware for mlxsw_spectrum
  * linux-firmware: add firmware image for Redpine 9113 chipset
  * linux-firmware: liquidio: update firmware to v1.6.0
  * qcom: add venus firmware files for v1.8
  * linux-firmware: intel: Update Kabylake audio firmware
  * qla2xxx: Update firmware version to 8.07.00
  * firmware: tegra: Add VIC firmware
  * imx: Add SDMA firmware for Freescale i.MX6/7 SoCs.
  * linux-firmware: wilc1000: Add unified firmware for wilc1000 WLAN
- Run spec-cleaner
  * Correct uppercase license information
  * Remove duplicite entries for iwl1000-ucode
* Tue Jun  6 2017 tiwai@suse.de
- Remove exclude i586 and s390 that was carried from SLE package,
  which results in breaking i586 imaging.
* Thu Jun  1 2017 tiwai@suse.de
- Cleanup spec file to reduce superfluous lines (bsc#1041354).
- Remove the superfluous isci/* devel sources
- Sync changelogs with SLE (bsc#1041354)
- Update qlogic qla2xxx firmware to 08.04.00 (bsc#993846)
- Exclude i586 and s390 builds on OBS as well
* Thu Jun  1 2017 mpluskal@suse.com
- Update to version 20170530 (bsc#1039310):
  * linux-firmware: add wil6210 firmware 4.1.0.55
  * cxgb4: update firmware to revision 1.16.45.0.
* Mon May 22 2017 tiwai@suse.de
- Update to version 20170522 (commit df40d15d6ad6) (bsc#1039785):
  * Update firmware for 3168
  * qed: Add firmware 8.20.0.0
  * Update Intel OPA hfi1 firmware (fate#319251)
* Tue May 16 2017 mpluskal@suse.com
- Update to version 20170511:
  * cxgb4: update firmware to revision 1.16.43.0
  * linux-firmware: add Marvell USB8997 firmware image
  * iwlwifi: update -22 firmware for 3168
* Fri Apr 28 2017 trenn@suse.de
- Remove hfi1_platform.dat manually (fate#321476 and 321477)
* Mon Apr 24 2017 mpluskal@suse.com
- Update to version 20170422:
  * linux-firmware: liquidio: update firmware to v1.5.1
  * linux-firmware: update Marvell SD8887 firmware image
  * linux-firmware: update Marvell SD8897-B0 firmware image
  * rtl_bt: Update firmware for BT part of rtl8822be
* Wed Apr  5 2017 mpluskal@suse.com
- Update to version 20170404 (fate#321702):
  * linux-firmware: intel: Update Broxton audio firmware
  * nfp: Add firmware 0.6.1
  * mediatek: update MT8173 VPU firmware for unsupported VP9 profiles
  * nvidia: add GP10B signed firmware
  * nvidia: fix GP107 signed firmware
- Add kernel-firmware-rpmlintrc as some firmware is binary
* Thu Mar 16 2017 mpluskal@suse.com
- Update to version 20170314:
  * linux-firmware: update Marvell SD8897-B0 firmware image
  * linux-firmware: update Marvell PCIe-USB8997 firmware image
  * linux-firmware: update Marvell PCIe-USB8997 wifi-only firmware image
  * linux-firmware: Update firmware patch for Intel Bluetooth, 7265
  * linux-firmware: Update firmware patch for Intel Bluetooth,8260
  * linux-firmware: Update firmware file for Intel Bluetooth,8265
  * brcm: update firmware for BCM43340/1 SDIO devices
  * ath10k: QCA6174 hw3.0: update board-2.bin
  * qed: Add firmware 8.15.3.0
* Sat Mar  4 2017 mpluskal@suse.com
- Update to version 20170303:
  * linux-firmware/i915: Fix Corrupted GuC files.
  * cxgb4: update firmware to revision 1.16.33.0
  * nvidia: add GM20B PMU firmware
  * nvidia: add GP102/GP104/GP106/GP107 signed firmware
  * linux-firmware: intel: Add Geminilake audio firmware
* Fri Feb 24 2017 mpluskal@suse.com
- Update to version 20170223:
  * amdgpu: add smc firmware for new polaris variants
  * Revert "amdgpu: update VI smc/mc firmware"
  * Revert "amdgpu: update VI gfx/sdma firmware"
* Sat Feb 18 2017 mpluskal@suse.com
- Update to version 20170217:
  * linux-firmware: liquidio: update firmware to v1.4.2
  * iwlwifi: update -17 firmware for 3260, 7260 and 7265
  * iwlwifi: update -22 firmware for 7265D and up
  * iwlwifi: add -27 firmware for 3168, 7265D, 8000C and 8265
  * linux-firmware/i915: Add HuC 1.07.1398 for SKL
  * linux-firmware/i915: Add HuC 1.07.1398 for broxton
  * linux-firmware/i915: HuC on 2.0.1810 for Kabylake
  * linux-firmware/i915: GuC firmware for Broxton v8.7
  * linux-firmware/i915: GuC firmware for Kabylake v9.14
  * radeon/amdgpu: update license copyright dates
  * radeon: add new firmware for SI chips
  * rtlwifi: rtl8723bs: Add firmware for new driver
  * qla2xxx: Update firmware version to 8.06.00
  * amdgpu: add firmware for polaris12 asics
  * amdgpu: update VI gfx/sdma firmware
  * amdgpu: update VI smc/mc firmware
  * update WHENCE for new amdgpu/polaris12_*.bin firmware
  * linux-firmware: add firmware for mt76x2
* Sat Jan 14 2017 mpluskal@suse.com
- Update to version 20170113 (FATE#321353):
  * WHENCE: Add new amdgpu firmware
  * WHENCE: Add new snd_intel_sst_core
  * LICENCE.siano: Add copyright years
  * linux-firmware: update firmware file for atusb
  * Update Intel OPA hfi1 firmware
  * cxgb4: Update firmware to revision 1.16.26.0.
  * linux-firmware: intel: Update Skylake audio firmware
  * linux-firmware: intel: Update Broxton audio firmware
  * linux-firmware: Fix DDC file format for Intel Bluetooth 8260/8265
  * brcm: add firmware for the BCM4356 SDIO device
  * brcm: add firmware for the BCM4358 PCIe device.
  * wl127x/wl128x: update firmwares
  * atusb: Document that dfu-util needs to be run before device enters runtime mode
  * Fix permissions on ti-connectivity firmware from 05e9fe59
* Sat Dec  3 2016 mpluskal@suse.com
- Update to version 20161130 (bsc#1010690):
  * linux-firmware: update BYT audio firmware
  * rtlwifi: Add updates for RTL8723BE and RTL8821AE
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265 (C0)
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265 (D1)
  * linux-firmware: Update firmware patch for Intel Bluetooth 7260 (B5/B6)
  * linux-firmware: Update firmware file for Intel Bluetooth 8260
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
* Wed Nov 23 2016 mpluskal@suse.com
- Update to version 20161121:
  * mediatek: update MT8173 VPU firmware for idle state
  * amdgpu: add new smc firmware for newer tonga and iceland chips
  * linux-firmware: rockchip: update dptx firmware to v3.1
  * rockchip/dptx: update WHENCE to version 3.1
* Sat Oct  8 2016 afaerber@suse.de
- Update to version 20161005:
  * Remove unused 'LICENCE.mwl8335'
  * WHENCE: Adjust some licence file references to satisfy check_whence.py
  * WHENCE: Fix metadata for snd-soc-skl firmware
  * WHENCE: List new radeon CI and SI smc firmware
  * WHENCE: List symlink 'qat_mmp.bin'
  * WHENCE: Add reference to 'qca/NOTICE.txt'
  * README: Say that files must be listed in WHENCE, and how to check it
  * radeon: update SMC firmware for SI parts
  * radeon: update SMC firmware for CI parts
  * amdgpu: update SMC firmware for VI parts
- Add Provides for brcmfmac43430-sdio.bin formerly in bcm43xx-firmware
- Package new GPL-2 file
* Wed Sep 14 2016 mpluskal@suse.com
- Update to version 20160913:
  * linux-firmware: update Marvell 8897-B0 firmware images to 7.p66
  * linux-firmware: update Marvell 8897-B0 firmware images to 7.p77
  * ath10k: QCA988X hw2.0: update firmware to 10.2.4.70.54
  * ath10k: QCA6174: update board files
  * rt2870sta: Update rt3071.bin to match rt2870.bin
  * rtl_bt: Add firmware and config file for RTL8822BE
  * mediatek: Update firmware for decoder and MDP
  * linux-firmware: add Marvell PCIe8997 firmware images
  * linux-firmware: update WHENCE file for Marvell firmware versions
  * amdgpu: update UVD firmware for VI devices
* Thu Aug 25 2016 mpluskal@suse.com
- Update to version 20160824:
  * linux-firmware/i915: Restore DMC 1.23
  * linux-firmware: intel: Update Kabylake audio firmware
  * linux-firmware: intel: Update Broxton audio firmware
  * linux-firmware: rockchip: update dptx firmware to v2.9
  * usb: host: xhci-rcar: update firmware for R-Car H3 and M3-W
  * qed: Add firmware 8.10.10.0
  * ath10k: QCA4019 hw1.0: add firmware and board files
  * ath10k: QCA9887 hw1.0: add firmware and board files
  * ath10k: QCA9888 hw2.0: add firmware and board files
  * ath10k: QCA9984 hw1.0: add firmware and board files
  * ath10k: QCA988X hw2.0: update firmware to 10.2.4.70.54
  * ath10k: QCA6174: update board files
* Wed Aug 17 2016 acho@suse.com
- Update qlogic  qed/qede - update FW to version 8.10.5.0 (bsc#993873).
* Sun Aug  7 2016 mpluskal@suse.com
- Update to version 20160804:
  * usbdux: usbduxsigma: created matching binary of the firmware
  * linux-firmware: rockchip: update dptx firmware to v2.6
  * amdgpu: update stoney UVD firmware
  * linux-firmware: intel: Update Skylake audio firmware
* Wed Jul 13 2016 mpluskal@suse.com
- Update to version 20160712:
  * nvidia: Add GP100 signed firmware
  * iwlwifi: add new -17 firmware for iwlmvm devices
  * iwlwifi: add new -22 firmware for 7265D and up
  * amdgpu: update vce firmware for VI asics
  * linux-firmware: intel: Add Kabylake audio firmware
  * Add dptx firmware for rockchip rk3399
* Wed Jun 29 2016 mpluskal@suse.com
- Update to version 20160628:
  * wl18xx: update firmware file
  * linux-firmware: intel: Update Skylake audio firmware
  * linux-firmware: Add firmware file for Intel Bluetooth 8265
  * amdgpu: Update UVD firmware for Polaris
  * amdgpu: update polaris ucode
* Fri Jun 10 2016 mpluskal@suse.com
- Update to version 20160609:
  * linux-firmware: update audio firmware for Braswell platform
  * radeon: add new CI smc firmware
  * radeon: add new SI smc firmware
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265 (D1)
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265 (C0/D0)
  * linux-firmware: Update firmware file for Intel Bluetooth 8260
* Sat Jun  4 2016 mpluskal@suse.com
- Update to version 20160602:
  * qed: Add FW 8.10.5.0
  * linux-firmware: intel: Add Broxton audio firmware
  * linux-firmware: Update firmware patch for Intel Bluetooth 7260 (B3/B4)
  * linux-firmware: Update firmware patch for Intel Bluetooth 7260 (B5/B6)
* Thu Jun  2 2016 bpoirier@suse.com
- Update Chelsio cxgb4 firmware to version 1.15.37.0 (bsc#975328)
* Thu May 26 2016 mmarek@suse.com
- Update to version 20160516git / commit 80d463be829a (fate#320305).
  - Intel SKL audio update
  - rt2800usb / rt2800pci update
  - amdgpu update
- Obsolete the SP1 compat-wireless-firmware package (bsc#975894).
* Tue May 24 2016 mpluskal@suse.com
- Update to version 20160516:
  * linux-firmware: intel: Update Skylake audio firmware
  * linux-firmware: update rt2860.bin, rt2800pci driver
  * linux-firmware: update rt2870.bin, rt2800usb driver
  * amdgpu: update firmware
* Wed May  4 2016 mpluskal@suse.com
- Update to version 20160503 :
  * radeon: update CIK UVD firmware
  * ath10k: QCA6174 hw2.1: update firmware-5.bin to SW_RM.1.1.1-00157-QCARMSWPZ-1
  * ath10k: QCA6174 hw2.1: add board-2.bin
  * ath10k: QCA6174 hw3.0: add board-2.bin
  * ath10k: QCA9377 hw1.0: add firmware and board files
* Fri Apr 22 2016 mpluskal@suse.com
- Update to version 20160421 (fate#fate#320305):
  * amdgpu: update CZ to new UVD fw that supports 40 sessions
  * linux-firmware: Update firmware file for Intel Bluetooth 8265
* Thu Apr 14 2016 mpluskal@suse.com
- Update to version 20160412:
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265 (D1)
  * usb: host: xhci-plat: add firmware for the R-Car M3-W xHCI controllers
* Sun Apr  3 2016 mpluskal@suse.com
- Update to version 20160330  (fate#fate#320305):
  * wl18xx: update firmware file
  * linux-firmware: intel: Update Skylake audio firmware
  * linux-firmware/i915: Major GuC release for Skylake - ver 6.1
  * linux-firmware: Update AMD microcode patch firmware
  * Update radeon ucode images
  * Update amdgpu ucode images
  * Add amdgpu ucode images for Polaris family asics
  * radeon: revert last kaveri mec ucode update
- Add _service to make updating more easy
* Fri Jan 15 2016 mmarek@suse.cz
- Update to version 20160112git (commit 40e9ae8) (fate#320305):
  * Update firmware patch for Intel Bluetooth 7265 (D1)
  * rtlwifi: v35 firmware for rtl8723bu
  * qed: Add firmware 8.7.3.0.
  * Clarified licensing terms for the current ath9k_htc firmware
  * brcm: add firmware for BCM4350 rev 5
  * fix permissions on brcm/brcmfmac4371-pcie.bin
  * add a symlink from qat_mmp.bin to its new file name
  * add fw for new qat devices
  * WHENCE: Add version information for hfi1
  * Update Skylake audio firmware
  * moxa: Refer to LICENCE.moxa for mxuport driver
  * moxa: Add firmware for Moxa 11x0 USB Serial devices
  * iwlwifi: replace 7265D-10.ucode by 7265-10.ucode
  * Update Intel OPA hfi1 firmware
  * update Marvell USB8797-B0 firmware image
  * update Marvell 8897-B0 firmware images to 7.p53
  * update Marvell 8897-B0 firmware images to 7.p18
  * add Marvell SD/USB8801 B0 firmware images
- Fix the Supplements dependency of ucode-amd.
* Mon Jan 11 2016 bruno@ioda-net.ch
- Update to version 20151207git (commit bbe4917)
  * WHENCE: use https://linuxtv.org for LinuxTV URLs
  * Add firmware for mt7601u. version 34.
  * brcm: add initial firmware for bcm4371 11ac wifi device
  * brcm: update firmware for bcm43602 device
  * WHENCE: Remove claim that qed and bfa/bna firmware came from
    kernel source
  * WHENCE: Correct filename of qed firmware
  * fix permissions on qed_init_values_zipped-8.4.2.0.bin
  * qla2xxx: Update firmware version to 8.03.00
  * bnx2x: Add FW 7.13.1.0.
  * Merge tag 'iwlwifi-fw-2015-11-18'
  * iwlwifi: add new -16 firmware for iwlmvm devices
  * linux-firmware: Update firmware patch for Intel Bluetooth 7265
    (C0/D0)
  * qed: Add FW 8.4.2.0
  * fix WHENCE, which for some reason became executable
- Use of spec-cleaner
- Fix boo#961416
- Added complete instructions for contributors how to get
  the tar.xz done
* Thu Dec 10 2015 tiwai@suse.de
- Fix dependencies for initrd macros (boo#958562)
- Fix missing dependency for ucode-amd, too (boo#958562)
- Call missing initrd macro at postun (boo#958562)
* Mon Nov  9 2015 tiwai@suse.de
- Updat to version 20151109git (commit bfeee58b5020)
  * radeon/amdgpu: update to latest firmware
  * remove executable bit from some firmware
  * add Skylake audio firmware
  * brcm: update firmware for the BCM4356 PCIe device
  * brcm: adding firmware for BCM4350 PCIe device
  * New minor DMC release for Skylake - ver1_23 (already existed
    in the package, old tarball dropped)
  * Removing old Skylake DMC
  * Add FW binary used by mwlwifi driver
  * ath10k: QCA99X0 hw2.0: add firmware 10.4.1.00030-1 and board.bin
  * ath10k: QCA6174 hw3.0: add WLAN.RM.2.0-00180-QCARMSWPZ-1
  * ath10k: QCA6174 hw2.1: add firmware WLAN.RM.1.1-00141 and board.bin
  * ath10k: QCA988X hw2.0: add firmware 10.2.4.70.9-2
  * ath10k: QCA988X hw2.0: add board.bin
  * Add firmware patch for Intel Bluetooth 7265 (D1)
  * brcmfmac: firmware refresh for BCM43602 PCIE devices
  * add support for the R-Car H3 xHCI controllers
  * Refresh / fix WHENCE and license descriptions
* Tue Oct 27 2015 tiwai@suse.de
- Update Skylake DMC firmware to 1.23 (boo#952134)
* Fri Sep 25 2015 tiwai@suse.de
- Update toversion 20150925git (commit f88e5c2e2)
  * Intel Bluetooth 7260/7265 f/w updates
  * qmss accumulator pdsp firmware for keystone SoCs
  * New minor DMC release for Skylake - ver1_22
  * New minor DMC release for Broxton - ver1_06
* Mon Sep 14 2015 dchang@suse.com
- cxgb4: update firmware to revision 1.14.4.0 for T4 and T5
  (bsc#945218)
  - Replaced cxgb4-update-firmware-to-revision-1.13.32.0-for-T4-a.patch
    with cxgb4-update-firmware-to-revision-1.14.4.0.patch
  - Replaced t4fw-1.13.32.0.bin and t5fw-1.13.32.0.bin with
    t4fw-1.14.4.0.bin and t5fw-1.14.4.0.bin
* Mon Sep  7 2015 tiwai@suse.de
- Update to version 20150907git (commit 6ebf5d57) (boo#944661):
  * amdgpu: add firmware for VI asics
  * ar3k: add to support AR3012 v2.1 firmware
  * Add Intel OPA hfi1 firmware
  * New major GuC/DMC releases for Skylake
  * New minor DMC release for Broxton - ver1_05
  * update firmware to revision 1.14.4.0
  * tegra: Update XHCI firmware to v50.10 for T210
  * wilc1000: add firmware for wilc1000 802.11n driver
  * usbdux: usbduxsigma firmware updates
  * Update to QAT dh895xxcc UOF firmware and a new QAT MMP FW
  * rtl_bt: correct RTL8723A firmware file
  * bnx2x: Update to FW version 7.12.30
  * tegra: add GK20A FECS/GPCCS firmware
* Tue Aug 11 2015 dchang@suse.com
- Update symlinks in cxgb4 subdirectory. (bsc#924378 FATE#318565)
* Wed Aug  5 2015 dchang@suse.com
- Update Chelsio cxgb4 firmware to revision 1.13.32.0 for T4 and T5
  (bsc#924378 FATE#318565)
  - Add t4fw-1.13.32.0.bin and t5fw-1.13.32.0.bin
* Wed Jul 15 2015 tiwai@suse.de
- Update to version 20150715git (commit 69640304) (boo#937628):
  * Intel BT 8260 firmware
  * Add firmware for Cavium LiquidIO 210NV, 210SV, and 410NV cards
  * Audio firmware for Braswell
  * qca: add BT firmware files to support QCA ROME chips
  * cxgb4: Add BT adapter PHY firmware
  * add firmware for atusb driver
  * radeon: add firmware for VCE1.0 hardware
  * iwlwifi: add new -13 firmware for iwlmvm devices
  * i915 Skylake DMC/GuC firmwares
* Fri Jun 26 2015 glin@suse.com
- Update QLogic bna firmware (bsc#922050, FATE#318601)
  + ctfw-3.2.5.1.bin, ct2fw-3.2.5.1.bin
- Exclude i586 and s390
* Tue Jun 16 2015 tiwai@suse.de
- Update to version 20150616git (commit 3161bfa479d5) (boo#934932):
  Update firmware patch for Intel Bluetooth 7260 (B3/B4)
  Update firmware patch for Intel Bluetooth 7260 (B5/B6)
  Update firmware patch for Intel Bluetooth 7265 (C0/D0)
  Update firmware patch for Intel Bluetooth 7265 (C0/D0)
  wl18xx: update firmware file, remove conf file
  Add Realtek Bluetooth HCD firmware
  brcm: add brcmfmac43241b5-sdio.bin to WHENCE
  Fix nvidia/tegra210/xusb.bin permissions
  brcm: add firmware for BCM4324(1) B5 chipset
  brcm: replace non-working firmware for BCM4339
  brcm: add firmware for BCM43570 PCIe device
  brcm: add firmware for BCM43569 USB device
  iwlwifi: update -12.ucode for 3160 / 7260 / 7265 / 7265D
  ath3k: update AR3012 2.2.1 firmware with v.170
  WHENCE: note nvidia xusb.bin firmware versions
  tegra: Add XHCI firmware v50.07 for T210
  cxgb4: update firmware to revision 1.13.32.0 for T4 and T5
  brcm: add firmware for BCM43340/1 SDIO devices
  brcm: add firmware for BCM4339 SDIO device
  brcm: add firmware for BCM43455 SDIO device
  brcm: add firmware files for BCM43602 PCIe device
  brcm: add firmware for BCM4356 PCIe device
  brcm: add firmware for BCM43242 USB device
  radeon: Update Kaveri MEC firmware to #396
  ath10k: add firmware 10.2.4.45 as firmware-4.bin
  Add v1.4.0 firmware for ath9k_htc.
  ath9k_htc: revert versions in WHENCE to 1.3.1
  iwlwifi: update -10.ucode for 3160 / 7260 / 7265 / 7265D
  firmware: tegra: Add XHCI firmware v45.46 for T124
  ath9k_htc: update versions in WHENCE
  rtl_nic: update firmware for RTL8168H and RTL8107E
  Fix qat_895xcc.bin permissions
  Add QLogic BR Series Adapter Firmware
  Fix firmware files with executable permission set
  iwlwifi: update -10.ucode for 3160 / 7260 / 7265 / 7265D
* Mon Mar 23 2015 mmarek@suse.cz
- Fix the filelist of amd-ucode.
* Mon Feb  9 2015 duwe@suse.com
- David Woodhouse is not maintaining this all by himself any more,
  switch to proper upstream repository and get a fresh snapshot.
  (bumping version to 20150209git)
* Sat Dec 13 2014 dimstar@opensuse.org
- Require coreutils for %%pre scripts. In some instances (mainly
  kiwi builds) this package can end up being installed before
  coreutils, having some errors spit in the %%pre phase.
* Sat Nov 22 2014 tiwai@suse.de
- Updated to git snapshot 20141122:
  Realtek WiFi and Ethernet updates and Intel BT updates
  (bnc#906212)
* Mon Sep  8 2014 eich@suse.com
- Add ast_dp501_fw.bin (bnc#871134 & bnc#895608)
  file generated from an array in a header file of xf86-video-ast:
  MIT/X11 License
* Wed Sep  3 2014 tiwai@suse.de
- Sync with SLE12 package
  * Includes previously cherry-picked QLogic firmware (bnc#879633)
  * Intel BT firmware updates
  * cxgb4 firmware update to revision 1.11.27.0
  * bnx2x firmware version 7.10.51 (bnc#887382)
  * dvb-fe-xc5000c-4.1.30.7.fw for xc5000 (bnc#884321)
  * Drop the obsoleted mkinitrd scripts
  * Use standard macros, posttrans for initrd updates
- Update to git snapshot 20140903:
  * Another Intel BT firmware updates (bnc#894810)
* Thu Jul  3 2014 mmarek@suse.cz
- Drop firmware signatures (bnc#867199)
* Tue Jun 24 2014 tiwai@suse.de
- Updated to git snapshot 20140624:
  including previous intel firmware files
* Fri Apr  4 2014 tiwai@suse.de
- Add Intel 7265 BT firmware (FATE#316958):
  ibt-hw-37.8.10-fw-1.10.2.27.d.bseq
  ibt-hw-37.8.bseq
* Fri Apr  4 2014 mmarek@suse.cz
- Regenerate the initrd in %%posttrans (fate#313506)
* Tue Apr  1 2014 mmarek@suse.cz
- Sign firmware files in the buildservice (bnc#867199)
* Mon Mar 24 2014 tiwai@suse.de
- Add Intel 7265 WiFi firmware (FATE#316958)
* Wed Mar 19 2014 tiwai@suse.de
- Update to git snapshot 20140319 (bnc#869039,bnc#869180)
  * brcm: add firmware for the BCM43362 WLAN device
  * iwlwifi: update firmware for 7260 / 3160 devices
  * WHENCE: Fix oddly capitalised instances of 'File'
  * wl18xx: add version 3 of the wl18xx firmware
  * rtlwifi: Add firmware for rtl8192ee
  * myri10ge: update firmware to 1.4.57
  * bnx2x: Update to FW 7.8.19
  * Remove executable permissions from firmware files
  * rtlwifi: Add firmware for rtl8821ae
  * radeon: add ucode for HAWAII GPUs
  * rtlwifi: Add firmware for r8723au
  * iwlwifi: update firmware for 7260 / 3160 devices
  * iwlwifi: update firmware for 7260 / 3160 devices
  * linux-firmware: 3.2.3.0 Firmware for Brocade Adapters
  * cxgb4: Updated T4 firmware, add T5 firmware
  * qla2xxx: Update ql2{4,5}00_fw.bin to version 7.01.00
  * linux-firmware: Update Intel Bluetooth devices firmware patch files
  * firmware: cw1200: Add firmware for the ST-E CW1200 WLAN chipset.
  * emi62: Provide the correct bitstream
  * linux-firmware: add Marvell SD8897-B0 firmware combo image
  * linux-firmware: update Marvell PCIe/USB 8897-B0 firmware combo image
  * rtlwifi: Add new firmware files for rtl8188eu
  * rtlwifi: Add new firmware files for rtl8192cu
  * brcm: add firmware file for the BCM4335 SDIO chipset
  * brcm: add firmware for newer version of BCM43241 SDIO chipset
  * brcm: add firmware file for BCM43241 SDIO chipset
  * brcm: rename firmware names expressing host interface type
  * ti-connectivity: add wl1251 firmware and license
  * linux-firmware: Add Brocade FC/FCOE Adapter firmware files
  * radeon: add ucode for KAVERI GPUs
  * radeon: add smc ucode for BONAIRE
  * linux-firmware: Add firmware patch file for Intel Bluetooth device(3160)
  * linux-firmware: add version information for Intel Bluetooth firmware
  * cw1200: Add SDD file for the Sagrad SG901-1091/1098 WLAN modules.
  * Fix filename for Intel Bluetooth firmware
  * linux-firmware: update Intel Bluetooth firmware patch file
  * moxa: Fix firmware file names.
  * moxa: Add firmware for some of the Moxa USB-Serial hubs
  * radeon: add ucode for KABINI GPUs
  * radeon: add ucode for BONAIRE GPUs
  * radeon: add smc ucode for radeon GPUs
- Remove obsoleted iwlwifi-4965 and carl9170w sources
* Wed Jan 22 2014 bpoirier@suse.de
- linux-firmware: 3.2.3.0 Firmware for Brocade Adapters (bnc#855232
  FATE#315938)
  Limited to the bna firmware.
* Thu Dec 19 2013 meissner@suse.com
- fixed last submission to actually build.
* Tue Dec 10 2013 trenn@suse.de
- Add mkinitrd script to add AMD microcode to initrd.
  This is needed because microcode driver is built in or gets loaded
  automatically via udev early. Therefore the microcode has to be available
  in initrd already.
  This must not be mixed up with early micorcode loading. This feature will
  not be implemented via mkinitrd. Dracut is doing early microcode loading.
- bnc#847158
- mkinitrd scripts:
  - mkinitrd_setup-amd_microcode.sh
    Adding microcode to the initrd
  - mkinitrd_boot-amd_microcode.sh
    Triggering the reload at boot
* Mon Dec  9 2013 trenn@suse.de
- Correct Supplements string so that the package gets correctly installed
  on machines with AMD CPUs
  bnc#847158
* Mon Oct 21 2013 jeffm@suse.com
- Use qlogic firmware from linux-firmware instead of the separate
  archive (bnc#846629).
* Mon Jul 29 2013 jeffm@suse.com
- Updated to git snapshot 2013/07/14
  - Radeon ucode update:
  - radeon: add ucode for KABINI GPUs
  - radeon: add ucode for BONAIRE GPUs
  - radeon: add smc ucode for radeon GPUs
* Wed Jul 24 2013 jeffm@suse.com
- Moved amd-ucode from microcode_ctl into new ucode-amd package.
* Fri Jul 19 2013 jeffm@suse.com
- Remove carl9170fw source files from package
* Mon Jul 15 2013 jeffm@suse.com
- Updated to git snapshot 2013/7/10
  - Add AMD microcode patch firmware files
  - Add Intel Bluetooth firmware patch files
  - Add firmware files for Creative CA0132 HD-audio codec
  - Add firmware files for mtk mt7630/mt7650 chipsets
  - Add firmware for mwl8k 8764 chip
  - Add go7007 firmware.
  - Add symlinks for old go7007 firmware filenames
  - Fix formatting of LICENCE.ca0132
  - Increment ap firmware API for mwl8k 8366 chip
  - Move sd8688*.bin images into mrvl/ tree
  - Revert "carl9170: Add checksum during installation, as preferred by the driver"
  - add Marvell PCIe8897-B0 WLAN firmware image
  - add Marvell SD8797-B0 firmware image
  - ar3k: add Bluetooth support for QCA98XX/QCA24XX
  - bnx2x: update fw to 7.8.17
  - cx231xx/cx23885: Remove incorrect Conexant CX23885 firmware
  - iwlwifi: add firmware for 7260 / 3160 devices
  - netxen_nic: Add FTP location of phanfw.bin in WHENCE file
  - netxen_nic: Update QLogic phanfw.bin to version 4.0.590
  - radeon: add ucode for OLAND GPUs
  - radeon: add ucode for SUN/HAINAN GPUs
  - radeon: add updated ucode for UVD
  - rp2: Initial commit of Comtrol RocketPort 2 microcode
  - rtl_nic: Add firmware rtl8168g-3
  - rtl_nic: add firmware rtl8106e-2
  - rtl_nic: add firmware rtl8411-2
  - rtl_nic: update firmware for RTL8168G
  - rtlwifi/rtl8188ee: Add firmware for new driver
  - tg3: Add EEE support firmware for 57766 cards
  - update Marvell SD8797-B0 firmware image
  - wl127x/wl128x: update firmwares
  - wl18xx: add default configuration binary
  - wl18xx: add version 2 of the wl18xx firmware
* Thu Feb 21 2013 Larry.Finger@lwfinger.net
- fix previous fix to build on factory/12.3
* Thu Feb 14 2013 Larry.Finger@lwfinger.net
- Updated to git snapshot 2013/1/14
  - carl9170: add firmware
  - qla2xxx: Update ql2400_fw.bin and ql2500_fw.bin to version 5.08.00
  - brcm: Add ucode support for bcm4313 iPA variant
  - linux-firmware: Add Marvell USB8797-B0 firmware image, Version 14.69.11.p179
  - s5p-mfc: Add s5p-mfc.fw for Exynos4 series
  - s5p-mfc: Add s5p-mfc-v6.fw for Exynos5 series
  - ar5523: Add firmware for new driver
  - Update patch and syscfg files for QCA9564
  - rtl_nic: Update firmware for RTL8168G to Version: 0.0.3
  - cxgb4: Update firmware to revision 1.6.2.0
  - bnx2x: Update fw to 7.8.2
  - r8712u: Revert to firmware from vendor driver v7_0.20100831
  - Update rampatch file for AR9462
  - netxen_nic: Update QLogic phanfw.bin to version 4.0.588
  - rtl8723e: Add firmware for new driver
  - ath6k: add firmware for AR6004 hw1.3
  - Marvell SD8787: update to v14.66.9.p96
  - Marvell SD8686: update to v9.70.20.p0
  - iwlwifi: update firmware for 6205 to version 18.168.6.1
* Fri Aug 24 2012 mmarek@suse.cz
- Package also license files (bnc#776576)
* Thu Jul 26 2012 jeffm@suse.com
- Updated to git snapshot 2012/7/19
  - brcm: add bcm4334 firmware for brcmfmac
  - r8712u: Update to latest firmware
  - rtl_nic: update firmware for RTL8168G
  - Add syscfg and patch files for AR3002 2.2.1
  - rtl_nic: add new firmware for RTL8168G, RTL8106E, RTL8411, RTL8168F
  - ar3k: add patch and sysconfig for Qualcomm Atheros AR9462
  - rtlwifi: rtl8192ce: rtl8192se: rtl8192de: Update to
    rtl_92ce_92se_92de_linux_mac80211_0004.0816.2011 driver
  - wl18xx: add firmware for WiLink8 WLAN chips
  - wl127x/wl128x: add new firmware series as version 5
  - rt2800pci:Firmware update v1
  - cxgb4: update firmware to revision 1.4.23.0
* Mon Jul  9 2012 jslaby@suse.de
- add carl9170-1.fw (bnc#763568)
* Tue Jun  5 2012 jeffm@suse.com
- Updated to git snapshot 2012/5/21
  - Many updates and additions
  - Replaced by git version:
  - iwlwifi-105-6.ucode
  - iwlwifi-135-6.ucode
  - iwlwifi-2000-6.ucode
  - iwlwifi-2030-6.ucode
  - bnx2/bnx2-mips-06-6.2.3.fw
  - bnx2/bnx2-mips-09-6.2.1b.fw
  - t4fw.bin (also updated to 1.4.16.0)
  - Removed:
  - brcm/bcm4329-fullmac-4.txt (was a development board)
  - mwl8335_duplex.fw (driver never included)
  - Renamed:
  - libertas/lbtf_usb.bin -> lbtf_usb.bin (as requested by driver)
* Tue May  8 2012 jslaby@suse.cz
- Add 4 iwlwifi firmware files. (bnc#760857)
  iwlwifi-105-6.ucode
  iwlwifi-135-6.ucode
  iwlwifi-2000-6.ucode
  iwlwifi-2030-6.ucode
* Fri Mar  2 2012 jlee@novell.com
- Add 2 new bnx2 firmware files. (bnc#746686)
  bnx2/bnx2-mips-06-6.2.3.fw
  bnx2/bnx2-mips-09-6.2.1b.fw
* Wed Dec 14 2011 coolo@suse.com
- as spdx.org has no concept of firmware, we decided to mark it as
  SUSE-Firmware
* Tue Oct 25 2011 coolo@suse.com
- update from git, ftp.kernel.org is stil down. Some smaller updates
* Thu Aug 25 2011 mls@suse.de
- fix supplements generation with rpm-4.9
* Fri Aug 12 2011 dmueller@suse.de
- add provides/obsoletes for ath3k-firmware
- Update to 20110731:
  * iwlwifi-6000g2a-5.ucode: Updated to v17.168.5.3
  * ath6kl - Atheros support for AR6003 WiFi-Bluetooth combo module
  * drxk - Micronas DRX-K demodulator driver
  * ene-ub6250 -- ENE UB6250 SD card reader driver
- update qlogic firmware to 5.06.00 (bnc#702696)
- add iwlwifi-4965-1.ucode (was additionally in iwl4965-ucode
  package before)
- Add latest firmware (1.3.10.0) for cxgb4 from Chelsio git (bnc#711432)
* Tue Aug  9 2011 mmarek@suse.cz
- Remove the PE520.cis symlink, it was only needed for SLE11-SP2.
* Thu Aug  4 2011 dmueller@suse.de
- add provides/obsoletes for
  iwl100-ucode, iwl1000-ucode, iwl6000-ucode, iwl6050-ucode,
  iwl6000g2-ucode
* Mon Jul 25 2011 mmarek@novell.com
- Add symlink for cis/PE520.cis (bnc#707960#c8)
* Thu Jul 14 2011 dmueller@suse.de
- update to 20110709:
  * provides more stable iwlwifi drivers
  * remove the need for symlinking bcm43xx-0.fw
* Tue Jul 12 2011 mmarek@novell.com
- Revert the workaround for bnc#673054, the files exist in the
  tarball now.
* Tue Jul 12 2011 mmarek@novell.com
- Fix firmware.sh for 3.0
* Thu Feb 24 2011 gregkh@suse.de
- create symlinks for Broadcom driver (bnc#673054)
* Sat Feb  5 2011 johannesobermayr@gmx.de
- Add scm service for automatical updates
* Wed Dec 15 2010 gregkh@suse.de
- update to 20101214 version for 2.6.37+ kernel
* Wed Nov 24 2010 coolo@novell.com
- update to 20101113 tarball for 2.6.36+ kernel
* Thu Jul  1 2010 gregkh@suse.de
- update to the 20100617 tarball, which has lots of updates that
  the 2.6.34 kernel needs (bnc#619225).
* Fri May 14 2010 mmarek@suse.cz
- Do not install files already installed by the kernel (bnc#598624).
* Fri May 14 2010 mmarek@suse.cz
- firmware-supplements.sh: Fallback to the last installed kernel.
* Wed May 12 2010 mmarek@suse.cz
- Run firmware-supplements.sh at build time. It's not a perfect
  solution, because kernel-default has a different set of modules
  among architectures, but better than a manually updated file.
* Fri Apr 23 2010 mmarek@suse.cz
- Update firmware-supplements.txt using module aliases from
  kernel-desktop-2.6.34-5.2.i586 (bnc#598624).
* Fri Apr 23 2010 mmarek@suse.cz
- Silence the firmware-supplements.sh script.
* Thu Mar  4 2010 coolo@novell.com
- hacking find_supplements macro
* Thu Mar  4 2010 coolo@novell.com
- update supplements.txt
* Thu Mar  4 2010 coolo@novell.com
- update to 20100227 snapshot (no changelog provided)
* Tue Dec 15 2009 gregkh@suse.de
- update to 20091215 snapshot
- added RealTek 8192E firmware
* Mon Oct 12 2009 mmarek@suse.cz
- provide/obsolete iwl1000-ucode.
* Mon Oct  5 2009 mmarek@suse.cz
- Add a script to semi-automatically generate modalias supplements.
* Mon Oct  5 2009 mmarek@suse.cz
- provide obsoleted packages.
* Thu Oct  1 2009 mmarek@suse.cz
- update to 20090821
  * includes newer iwlwifi firmware (bnc#537112)
- use fdupes
* Mon Aug  3 2009 gregkh@suse.de
- add obsoletes for ralink-firmware (bnc#503836)
* Thu Apr 23 2009 gregkh@suse.de
- initial package
